@@ -29,16 +29,9 @@
 /*******************************************************************/
 
 #include "conf.h"
-
 #include <stdio.h>
-#include <math.h>
 
 
-
-#ifndef _GETOPT_H
-#include "../pub/getopt.h"
-#endif
-
 #ifdef HAVE_STDLIB_H
 #include <stdlib.h>
 #endif
@@ -160,13 +153,11 @@ extern int errno;
 #include <sys/paths.h>
 #endif
 
-#ifdef HAVE_SYS_MALLOC_H
+#ifdef HAVE_MALLOC_H
 #ifdef DARWIN
 #include <sys/malloc.h>
 #include <sys/paths.h>
-#endif
 #else
-#ifdef HAVE_MALLOC_H
 #ifndef OPENBSD
 #ifdef __FreeBSD__
 #include <stdlib.h>
@@ -209,8 +200,6 @@ extern int errno;
 #include <pwd.h>
 #include <grp.h>
 
-
-
 #ifdef HAVE_SYS_SOCKIO_H
 # include <sys/sockio.h>
 #endif
@@ -239,9 +228,7 @@ extern int errno;
 #endif
 #endif
 
-#ifdef HAVE_PCRE
-# include <pcreposix.h>
-#elif HAVE_RXPOSIX_H
+#ifdef HAVE_RXPOSIX_H
 # include <rxposix.h>
 #elif  HAVE_REGEX_H
 # include <regex.h>
@@ -267,9 +254,6 @@ extern int errno;
 # include <sched.h>
 #endif
 
-#ifdef WITH_SELINUX
-# include <selinux/selinux.h> 
-#endif
 
 /*******************************************************************/
 /* Various defines                                                 */
@@ -278,13 +262,10 @@ extern int errno;
 #define true  1
 #define false 0
 #define CF_BUFSIZE 4096
-#define CF_EXPANDSIZE (2*CF_BUFSIZE)
-#define CF_ALLCLASSSIZE (4*CF_BUFSIZE)
+#define CF_EXPANDSIZE 2*CF_BUFSIZE
 #define CF_BUFFERMARGIN 32
-#define CF_BLOWFISHSIZE 16
-#define CF_SMALLBUF 128
 #define CF_MAXVARSIZE 1024
-#define CF_NONCELEN (CF_BUFSIZE/16)
+#define CF_NONCELEN CF_BUFSIZE/16
 #define CF_MAXLINKSIZE 256
 #define CF_MAXLINKLEVEL 4
 #define CF_MAXARGS 31
@@ -295,27 +276,17 @@ extern int errno;
 #define CF_MACROALPHABET 61    /* a-z, A-Z plus a bit */
 #define CF_MAXSHELLARGS 30
 #define CF_SAMEMODE 0
-#define CF_SAME_OWNER ((uid_t)-1)
-#define CF_UNKNOWN_OWNER ((uid_t)-2)
-#define CF_SAME_GROUP ((gid_t)-1)
-#define CF_UNKNOWN_GROUP ((gid_t)-2)
+#define CF_SAME_OWNER (uid_t)-1
+#define CF_UNKNOWN_OWNER (uid_t)-2
+#define CF_SAME_GROUP (gid_t)-1
+#define CF_UNKNOWN_GROUP (gid_t)-2
 #define CF_NOSIZE    -1
 #define CF_EXTRASPC 8      /* pads items during AppendItem for eol handling in editfiles */
-#define CF_INFINITY ((int)999999999)
+#define CF_INFINITY (int)999999999
 #define CF_TICKS_PER_DAY 86400 /* 60 * 60 *24 */
-#define CF_TICKS_PER_HOUR 3600 /* 60 * 60 */
-#define CF_HALF_HOUR 1800      /* 60 * 30 */ 
 #define CF_NOT_CONNECTED -1
 #define CF_RECURSION_LIMIT 100
 #define CF_MONDAY_MORNING 342000
-#define CF_NOVAL -0.7259285297502359
-#define CF_UNUSED_CHAR (char)127
-
-#define CF_MAXDIGESTNAMELEN 7
-#define CF_CHKSUMKEYOFFSET  CF_MAXDIGESTNAMELEN+1
-
-#define CF_IFREQ 2048    /* Reportedly the largest size that does not segfault 32/64 bit*/
-#define CF_ADDRSIZE 128
 
 #define CF_METHODEXEC 0
 #define CF_METHODREPLY  1
@@ -326,15 +297,11 @@ extern int errno;
 /* Need this to to avoid conflict with solaris 2.6 and db.h */
 
 #ifdef SOLARIS
-# ifndef u_int32_t
-#  define u_int32_t uint32_t
-#  define u_int16_t uint16_t
-#  define u_int8_t uint8_t
-# endif
+# define u_int32_t uint32_t
+# define u_int16_t uint16_t
+# define u_int8_t uint8_t
 #endif
 
-#include <db.h>
-
 
 /*******************************************************************/
 /* Class array limits                                              */
@@ -349,20 +316,13 @@ extern int errno;
 
 /*******************************************************************/
 
-#define CF_PERFORMANCE   "performance.db"
-#define CF_CHKDB         "checksum_digests.db"
-#define CF_AVDB_FILE     "cf_observations.db"
-#define CF_OLDAVDB_FILE  "cf_learning.db"
+#define CF_AVDB_FILE     "cf_learning.db"
 #define CF_STATEDB_FILE  "cf_state.db"
-#define CF_OLDLASTDB_FILE "cf_lastseen.db"
-#define CF_LASTDB_FILE   "cf_LastSeen.db"
-
+#define CF_LASTDB_FILE   "cf_lastseen.db"
 #define CF_STATELOG_FILE "state_log"
-#define CF_ENVNEW_FILE   "env_data.new"
+#define CF_ENVNEW_FILE  "env_data.new"
 #define CF_ENV_FILE      "env_data"
-
 #define CF_TCPDUMP_COMM "/usr/sbin/tcpdump -t -n -v"
-#define CF_SCLI_COMM "/usr/local/sbin/scli"
 
 
 #define CF_INPUTSVAR "CFINPUTS"          /* default name for file path var */
@@ -383,17 +343,9 @@ extern int errno;
 #define CF_NOUSER -99
 #define CF_RSA_PROTO_OFFSET 24
 #define CF_PROTO_OFFSET 16
-#define CF_INBAND_OFFSET 8
 #define CF_SMALL_OFFSET 2
-
-/* digest sizes */
 #define CF_MD5_LEN 16
 #define CF_SHA_LEN 20
-#define CF_SHA1_LEN 20
-#define CF_SHA224_LEN 28
-#define CF_SHA256_LEN 32
-#define CF_SHA384_LEN 48
-#define CF_SHA512_LEN 64
 
 #define CF_DONE 't'
 #define CF_MORE 'm'
@@ -437,27 +389,7 @@ extern int errno;
 #define CF_WEEK   (7.0*24.0*3600.0)
 #define CF_MEASURE_INTERVAL (5.0*60.0)
 
-#define CF_OBSERVABLES 91
-
-struct QPoint
-   {
-   double q;
-   double expect;
-   double var;
-   };
-
-struct Event
-   {
-   time_t t;
-   struct QPoint Q;
-   };
-
 struct Averages
-   {
-   struct QPoint Q[CF_OBSERVABLES];
-   };
-
-struct OldAverages /* For conversion to new db */
    {
    double expect_number_of_users;
    double expect_rootprocs;
@@ -466,7 +398,8 @@ struct OldAverages /* For conversion to new db */
    double expect_loadavg;
    double expect_incoming[ATTR];
    double expect_outgoing[ATTR];
-   double expect_pH[PH_LIMIT];      
+   double expect_pH[PH_LIMIT];
+      
    double var_number_of_users;
    double var_rootprocs;
    double var_otherprocs;
@@ -475,18 +408,20 @@ struct OldAverages /* For conversion to new db */
    double var_incoming[ATTR];
    double var_outgoing[ATTR];
    double var_pH[PH_LIMIT];
+
+      /* tcpdump data - tag them on here ... */
+      
    double expect_netin[CF_NETATTR];
    double expect_netout[CF_NETATTR];
    double var_netin[CF_NETATTR];
    double var_netout[CF_NETATTR];
    };
 
-/******************************************************************/
 
-struct LockData
+struct LastSeen
    {
-   pid_t pid;
-   time_t time;
+   double expect_lastseen;
+   time_t lastseen;      
    };
 
 /*******************************************************************/
@@ -509,7 +444,6 @@ struct LockData
    (including indirect blocks). */
 
 
-#define SMALL_BLOCK_BUF_SIZE 512
 
 #ifndef HAVE_ST_BLOCKS
 # define ST_BLKSIZE(statbuf) DEV_BSIZE
@@ -560,8 +494,6 @@ enum PROTOS
    cfd_sauth,
    cfd_ssynch,
    cfd_sget,
-   cfd_version,
-   cfd_sopendir,
    cfd_bad
    };
 
@@ -663,9 +595,7 @@ enum builtin
    fn_islink,
    fn_isplain,
    fn_execresult,
-   fn_execshellresult,
    fn_returnszero,
-   fn_returnszeroshell,
    fn_iprange,
    fn_hostrange,
    fn_isdefined,
@@ -687,10 +617,6 @@ enum builtin
    fn_selectpl,
    fn_selectpn,
    fn_selectpna,
-   fn_greaterthan,
-   fn_lessthan,
-   fn_readtcp,
-   fn_printfile
    };
 
 /*******************************************************************/
@@ -731,8 +657,7 @@ enum actions
    filters,
    strategies,
    packages,
-   methods,
-   scli
+   methods
    };
 
 /*******************************************************************/
@@ -939,7 +864,6 @@ enum vnames
    cfcr,
    cfn,
    cfdblquote,
-   cfcolon,
    cfquote,
    cfdollar,
    cfrepchar,
@@ -964,7 +888,6 @@ enum vnames
    cfdefcopy,
    cfredef,
    cfdefpkgmgr,
-   cfabortclasses,
    nonexistentvar
    };
 
@@ -1070,7 +993,6 @@ enum editnames
    AppendIfNoSuchLinesFromFile,
    IncrementPointer,
    ReplaceLineWith,
-   ExpandVariables,
    DeleteToLineMatching,
    HashCommentToLineMatching,
    PercentCommentToLineMatching,
@@ -1085,10 +1007,8 @@ enum editnames
    GotoLastLine,
    BreakIfLineMatches,
    BeginGroupIfNoMatch,
-   BeginGroupIfMatch,
    BeginGroupIfNoLineMatching,
    BeginGroupIfNoSuchLine,
-   BeginGroupIfLineMatching,
    EndGroup,
    Append,
    Prepend,
@@ -1114,11 +1034,9 @@ enum editnames
    BeginGroupIfFileIsNewer,
    BeginGroupIfFileExists,
    BeginGroupIfNoLineContaining,
-   BeginGroupIfLineContaining,
    BeginGroupIfDefined,
    BeginGroupIfNotDefined,
    AutoCreate,
-   WarnIfFileMissing,
    ForEachLineIn,
    EndLoop,
    ReplaceLinesMatchingField,
@@ -1144,8 +1062,7 @@ enum editnames
    EditFilter,
    DefineInGroup,
    EditIfElapsed,
-   EditExpireAfter,
-   EditSplit
+   EditExpireAfter
    };
 
 enum RegExpTypes
@@ -1175,7 +1092,7 @@ enum SignalNames
    cfsys,
    cfpipe,
    cfalrm,
-   cfterm
+   cfterm,
    };
 
 #define highest_signal 64
@@ -1189,8 +1106,7 @@ enum cfoutputlevel
    cfverbose,
    cfeditverbose,
    cferror,
-   cflogonly,
-   cfloginform
+   cflogonly
    };
 
 /*******************************************************************/
@@ -1218,8 +1134,7 @@ enum cmpsense   /* For package version comparison */
    cmpsense_lt,
    cmpsense_ge,
    cmpsense_le,
-   cmpsense_ne,
-   cmpsense_none
+   cmpsense_ne
    };
 
 /*******************************************************************/
@@ -1228,25 +1143,11 @@ enum pkgmgrs    /* Available package managers to query in packages: */
    {
    pkgmgr_rpm,
    pkgmgr_dpkg,
-   pkgmgr_sun,
-   pkgmgr_aix,
-   pkgmgr_portage,
-   pkgmgr_freebsd,
    pkgmgr_none
    };
 
 /*******************************************************************/
 
-enum pkgactions /* What to do with a package if it is found/not found */
-    {
-    pkgaction_install,
-    pkgaction_remove,
-    pkgaction_upgrade,
-    pkgaction_none
-    };
-
-/*******************************************************************/
-
 typedef char flag;
 
 enum socks
@@ -1275,70 +1176,13 @@ enum iptypes
    tcpmisc
    };
 
-enum observables
-    {
-    ob_users,
-    ob_rootprocs,
-    ob_otherprocs,
-    ob_diskfree,
-    ob_loadavg,
-    ob_netbiosns_in,
-    ob_netbiosns_out,
-    ob_netbiosdgm_in,
-    ob_netbiosdgm_out,
-    ob_netbiosssn_in,
-    ob_netbiosssn_out,
-    ob_irc_in,
-    ob_irc_out,
-    ob_cfengine_in,
-    ob_cfengine_out,
-    ob_nfsd_in,
-    ob_nfsd_out,
-    ob_smtp_in,
-    ob_smtp_out,
-    ob_www_in,
-    ob_www_out,
-    ob_ftp_in,
-    ob_ftp_out,
-    ob_ssh_in,
-    ob_ssh_out,
-    ob_wwws_in,
-    ob_wwws_out,
-    ob_icmp_in,
-    ob_icmp_out,
-    ob_udp_in,
-    ob_udp_out,
-    ob_dns_in,
-    ob_dns_out,
-    ob_tcpsyn_in,
-    ob_tcpsyn_out,
-    ob_tcpack_in,
-    ob_tcpack_out,
-    ob_tcpfin_in,
-    ob_tcpfin_out,
-    ob_tcpmisc_in,
-    ob_tcpmisc_out,
-    ob_spares
-    };
-
-
-struct sock
-   {
-   char *portnr;
-   char *name;
-   enum observables in;
-   enum observables out;
-   };
-
-
 /*******************************************************************/
 
 struct cfagent_connection
    {
    int sd;
-      int trust;            /* true if key being accepted on trust */
-   int protoversion;
-   int family;                              /* AF_INET or AF_INET6 */
+   int trust;
+   int family;     /* AF_INET or AF_INET6 */
    char localip[CF_MAX_IP_LEN];
    char remoteip[CF_MAX_IP_LEN];
    unsigned char *session_key;
@@ -1489,7 +1333,6 @@ struct Mountables
    char			readonly;	/* y/n - true false */
    char			*filesystem;
    char			*mountopts;
-   char                 *classes;
    struct Mountables	*next;
    };
 
@@ -1498,15 +1341,15 @@ struct Mountables
 struct Tidy
    {
    int          maxrecurse;              /* sets maxval */
-   char         done;                    /* Too intensive in Tidy Pattern */
+   char         done;       /* Too intensive in Tidy Pattern */
    char         *scope;
-   char         *path;
+   char        *path;
    char         xdev;
-   int          ifelapsed;
-   int          expireafter;
+   int ifelapsed;
+   int expireafter;
 
-   struct Item        *exclusions;
-   struct Item        *ignores;      
+   struct Item *exclusions;
+   struct Item *ignores;      
    struct TidyPattern *tidylist;
    struct Tidy        *next;   
    };
@@ -1522,7 +1365,6 @@ struct Tidy
          struct Item        *filters;
 	 char               *classes;
 	 char               *defines;
-         char               tidied;
 	 char		    *elsedef;
          char               compress;
          char               travlinks;
@@ -1554,7 +1396,6 @@ struct MiscMount
    char *scope;
    char *from;
    char *onto;
-   char *mode;
    char *options;
    char *classes;
    int ifelapsed;
@@ -1674,7 +1515,7 @@ struct Image
    mode_t minus;
    struct UidList *uid;
    struct GidList *gid;
-   char   *action;                           /* fix / warn /silent */
+   char   *action;                                   /* fix / warn */
    char   *classes;
    char   *defines;
    char   *elsedef;
@@ -1828,14 +1669,12 @@ struct Link
 struct Edit
    {
    char done;     /* Have this here, too dangerous in Edlist */
-   char warn;
    char *scope;
    char *fname;
    char *defines;
    char *elsedef;
    mode_t umask;
    char useshell;
-   char split;
    char *repository;
    int   recurse;
    char  binary;   /* y/n */
@@ -1935,7 +1774,6 @@ struct ShellComm
    char              *defines;
    char              *elsedef;
    char              preview;
-   char              noabspath;
    int ifelapsed;
    int expireafter;
    };
@@ -1978,23 +1816,11 @@ struct Package      /* For packages: */
    char              *ver;
    enum cmpsense     cmp;
    enum pkgmgrs      pkgmgr;
-   enum pkgactions   action;
    struct Package    *next;
    int ifelapsed;
    int expireafter;
    };
 
-
-/*******************************************************************/
-/* Checksum database structures                                    */
-/*******************************************************************/
-
-struct Checksum_Value
-   {
-   unsigned char mess_digest[EVP_MAX_MD_SIZE+1];  /* Content digest */
-   unsigned char attr_digest[EVP_MAX_MD_SIZE+1];  /* Attribute digest */
-   };
-
 /*******************************************************************/
 /* Ultrix/BSD don't have all these from sys/stat.h                 */
 /*******************************************************************/
@@ -2133,4 +1959,6 @@ struct Checksum_Value
 /* All prototypes                                                   */
 /********************************************************************/
 
+#include <math.h>
+#include <db.h>
 #include "prototypes.h"
