@@ -32,6 +32,7 @@
 /*                                                                 */
 /*******************************************************************/
 
+#include "../pub/getopt.h"
 #include "cf.defs.h"
 #include "cf.extern.h"
 
@@ -39,26 +40,28 @@
 /* Functions internal to cfengine.c                                */
 /*******************************************************************/
 
-int main (int argc,char *argv[]);
-void Initialize (int argc, char **argv);
-void PreNetConfig (void);
-void ReadRCFile (void);
-void EchoValues (void);
-void CheckSystemVariables (void);
-void SetReferenceTime (int setclasses);
-void SetStartTime (int setclasses);
-void DoTree (int passes, char *info);
-enum aseq EvaluateAction (char *action, struct Item **classlist, int pass);
-void CheckOpts (int argc, char **argv);
-int GetResource (char *var);
-void Syntax (void);
-void EmptyActionSequence (void);
-void GetEnvironment (void);
-int NothingLeftToDo (void);
-void SummarizeObjects (void);
-void SetContext (char *id);
-void DeleteCaches (void);
-void QueryCheck(void);
+int main ARGLIST((int argc,char *argv[]));
+void Initialize ARGLIST((int argc, char **argv));
+void PreNetConfig ARGLIST((void));
+void ReadRCFile ARGLIST((void));
+void EchoValues ARGLIST((void));
+void CheckSystemVariables ARGLIST((void));
+void SetReferenceTime ARGLIST((int setclasses));
+void SetStartTime ARGLIST((int setclasses));
+void DoTree ARGLIST((int passes, char *info));
+enum aseq EvaluateAction ARGLIST((char *action, struct Item **classlist, int pass));
+void CheckOpts ARGLIST((int argc, char **argv));
+int GetResource ARGLIST((char *var));
+void BuildClassEnvironment ARGLIST((void));
+void Syntax ARGLIST((void));
+void EmptyActionSequence ARGLIST((void));
+void GetEnvironment ARGLIST((void));
+int NothingLeftToDo ARGLIST((void));
+void SummarizeObjects ARGLIST((void));
+void SetContext ARGLIST((char *id));
+void DeleteCaches ARGLIST((void));
+void CheckForMethod ARGLIST((void));
+void CheckMethodReply ARGLIST((void));
 
 /*******************************************************************/
 /* Level 0 : Main                                                  */
@@ -75,8 +78,6 @@ signal (SIGTERM,HandleSignal);                   /* Signal Handler */
 signal (SIGHUP,HandleSignal);
 signal (SIGINT,HandleSignal);
 signal (SIGPIPE,HandleSignal);
-signal (SIGUSR1,HandleSignal);
-signal (SIGUSR2,HandleSignal);
 
 Initialize(argc,argv); 
 SetReferenceTime(true);
@@ -94,18 +95,15 @@ PreNetConfig();
 
 ReadRCFile(); /* Should come before parsing so that it can be overridden */
 
- if (IsPrivileged() && !MINUSF && !PRSCHEDULE)
+ if (IsPrivileged() && !MINUSF && !PRMAILSERVER)
     {
     SetContext("update");
-
     if (ParseInputFile("update.conf"))
        {
        CheckSystemVariables();
-
-       if (!PARSEONLY && (QUERYVARS == NULL))
+       if (!PARSEONLY)
           {
-          DoTree(2,"Update");
-          DoAlerts();
+          DoTree(1,"Update");
           EmptyActionSequence();
           DeleteClassesFromContext("update");
           DeleteCaches();
@@ -113,10 +111,6 @@ ReadRCFile(); /* Should come before parsing so that it can be overridden */
 
        VIMPORT = NULL;
        }
-    else
-       {
-       Verbose("Skipping update.conf (-F=%d)\n",MINUSF);
-       }
     
     if (ERRORCOUNT > 0)
        {
@@ -140,17 +134,38 @@ ReadRCFile(); /* Should come before parsing so that it can be overridden */
  ParseInputFile(VINPUTFILE);
  CheckFilters();
  EchoValues();
- 
-/* CheckForMethod(); Move to InitializeAction */
+ CheckForMethod();
  
  if (PRSYSADM)                                           /* -a option */
     {
     printf("%s\n",VSYSADM);
     exit (0);
     }
-
- if (PRSCHEDULE)
+ 
+ if (PRMAILSERVER)
     {
+    if (GetMacroValue(CONTEXTID,"smtpserver"))
+       {
+       printf("%s\n",GetMacroValue(CONTEXTID,"smtpserver"));
+       }
+    else
+       {
+       printf("No SMTP server defined\n");
+       }
+    printf("%s\n",VSYSADM);
+    printf("%s\n",VFQNAME);
+    printf("%s\n",VIPADDRESS);
+    
+    if (GetMacroValue(CONTEXTID,"EmailMaxLines"))
+       {
+       printf("%s\n", GetMacroValue(CONTEXTID,"EmailMaxLines"));
+       }
+    else
+       {
+       /* User has not expressed a preference -- let cfexecd decide */
+       printf("%s", "-1\n");
+       }
+    
     for (ip = SCHEDULE; ip != NULL; ip=ip->next)
        {
        printf("[%s]\n",ip->name);
@@ -172,12 +187,10 @@ ReadRCFile(); /* Should come before parsing so that it can be overridden */
  
  CfOpenLog();
  CheckSystemVariables();
-
+ 
  SetReferenceTime(false); /* Reset */
-
- QueryCheck();
-
- DoTree(3,"Main Tree"); 
+ 
+ DoTree(2,"Main Tree"); 
  DoAlerts();
  
  CheckMethodReply();
@@ -207,13 +220,14 @@ void Initialize(int argc,char *argv[])
 strcpy(VDOMAIN,CF_START_DOMAIN);
 
 PreLockState();
-
+ 
 ISCFENGINE = true;
 VFACULTY[0] = '\0';
 VSYSADM[0] = '\0';
 VNETMASK[0]= '\0';
 VBROADCAST[0] = '\0';
 VMAILSERVER[0] = '\0';
+VDEFAULTROUTE[0] = '\0';
 ALLCLASSBUFFER[0] = '\0';
 VREPOSITORY = strdup("\0");
 
@@ -231,8 +245,8 @@ strcpy(VNFSTYPE,"nfs");
 IDClasses();
  
 /* Note we need to fix the options since the argv mechanism doesn't */
-/* work when the shell #!/bla/cfengine -v -f notation is used.      */
-/* Everything ends up inside a single argument! Here's the fix      */
+ /* work when the shell #!/bla/cfengine -v -f notation is used.      */
+ /* Everything ends up inside a single argument! Here's the fix      */
 
 cfargc = 1;
 cfargv[0]="cfagent";
@@ -266,43 +280,15 @@ for (i = 1; i < argc; i++)
  VEXPIREAFTER = VDEFAULTEXPIREAFTER;
  VIFELAPSED = VDEFAULTIFELAPSED;
  TRAVLINKS = false;
-
- /* XXX Initialize workdir for non privileged users */
-
- strcpy(CFWORKDIR,WORKDIR);
-
- if (getuid() > 0)
-    {
-    char *homedir;
-    if ((homedir = getenv("HOME")) != NULL)
-       {
-       strcpy(CFWORKDIR,homedir);
-       strcat(CFWORKDIR,"/.cfagent");
-       }
-    }
  
- sprintf(ebuff,"%s/state/cf_procs",CFWORKDIR);
- 
- if (stat(ebuff,&statbuf) == -1)
-    {
-    CreateEmptyFile(ebuff);
-    }
-
- sprintf(ebuff,"%s/state/cf_rootprocs",CFWORKDIR);
+ sprintf(ebuff,"%s/state/cf_procs",WORKDIR);
  
  if (stat(ebuff,&statbuf) == -1)
     {
     CreateEmptyFile(ebuff);
     }
  
- sprintf(ebuff,"%s/state/cf_otherprocs",CFWORKDIR);
- 
- if (stat(ebuff,&statbuf) == -1)
-    {
-    CreateEmptyFile(ebuff);
-    }
-
- strcpy(VLOGDIR,CFWORKDIR); 
+ strcpy(VLOGDIR,WORKDIR); 
  strcpy(VLOCKDIR,VLOGDIR);  /* Same since 2.0.a8 */
  
  OpenSSL_add_all_algorithms();
@@ -315,10 +301,6 @@ for (i = 1; i < argc; i++)
  seed = ElfHash(s);
  srand48((long)seed);  
  CheckOpts(cfargc,cfargv);
-
- AddInstallable("no_default_route");
- CfenginePort();
- StrCfenginePort();
 }
 
 /*******************************************************************/
@@ -353,7 +335,7 @@ if ((sp=getenv(CF_INPUTSVAR)) != NULL)
    }
 else
    {
-   snprintf(comm,CF_BUFSIZE,"%s/%s",CFWORKDIR,VPRECONFIG);
+   snprintf(comm,CF_BUFSIZE,"%s/%s",WORKDIR,VPRECONFIG);
    
    if (stat(comm,&buf) == -1)
       {
@@ -361,7 +343,7 @@ else
       return;
       }
    
-   snprintf(comm,CF_BUFSIZE,"%s/%s %s",CFWORKDIR,VPRECONFIG,CLASSTEXT[VSYSTEMHARDCLASS]);
+   snprintf(comm,CF_BUFSIZE,"%s/%s %s",WORKDIR,VPRECONFIG,CLASSTEXT[VSYSTEMHARDCLASS]);
    }
 
  if (S_ISDIR(buf.st_mode) || S_ISCHR(buf.st_mode) || S_ISBLK(buf.st_mode))
@@ -395,11 +377,6 @@ while (!feof(pp))
       break;
       }
    
-   if (strstr(ebuff,"cfengine-preconf-abort"))
-      {
-      exit(2);
-      }
-
    if (ferror(pp))  /* abortable */
       {
       CfLog(cferror,"Error running preconfig\n","ferror");
@@ -432,7 +409,7 @@ void ReadRCFile()
 filename[0] = buffer[0] = class[0] = variable[0] = value[0] = '\0';
 LINENUMBER = 0;
 
-snprintf(filename,CF_BUFSIZE,"%s/inputs/%s",CFWORKDIR,VRCFILE);
+snprintf(filename,CF_BUFSIZE,"%s/inputs/%s",WORKDIR,VRCFILE);
 if ((fp = fopen(filename,"r")) == NULL)      /* Open root file */
    {
    return;
@@ -544,7 +521,7 @@ void GetEnvironment()
   time_t now = time(NULL);
   
 Verbose("Looking for environment from cfenvd...\n");
-snprintf(env,CF_BUFSIZE,"%s/state/%s",CFWORKDIR,CF_ENV_FILE);
+snprintf(env,CF_BUFSIZE,"%s/state/%s",WORKDIR,CF_ENV_FILE);
 
 if (stat(env,&statbuf) == -1)
    {
@@ -583,8 +560,7 @@ while (!feof(fp))
    class[0] = '\0';
    name[0] = '\0';
    value[0] = '\0';
-
-   fgets(class,CF_BUFSIZE-1,fp);
+   fscanf(fp,"%256s",class);
 
    if (feof(fp))
       {
@@ -593,8 +569,7 @@ while (!feof(fp))
 
    if (strstr(class,"="))
       {
-      sscanf(class,"%255[^=]=%255[^\n]",name,value);
-
+      sscanf(class,"%255[^=]=%255s",name,value);
       if (!GetMacroValue(CONTEXTID,name))
          {
          AddMacroValue(CONTEXTID,name,value);
@@ -617,7 +592,7 @@ void EchoValues()
 { struct Item *ip,*p2;
   char ebuff[CF_EXPANDSIZE];
 
-ebuff[0] = '\0';
+Verbose("Accepted domain name: %s\n\n",VDOMAIN); 
 
 if (GetMacroValue(CONTEXTID,"OutputPrefix"))
    {
@@ -696,46 +671,19 @@ if (DEBUG || D2 || D3)
       printf ("%s ",ip->name);
       }
    printf("\n");
-   if (VDEFAULTROUTE != NULL)
-      {
-      if (IsDefinedClass(VDEFAULTROUTE->classes))
-         {
-         printf("\nDefault route for packets %s\n\n",VDEFAULTROUTE->name);
-         }
-      }
+   printf("\nDefault route for packets %s\n\n",VDEFAULTROUTE);
    printf("\nFile repository = %s\n\n",VREPOSITORY);
    printf("\nNet interface name = %s\n",VIFDEV[VSYSTEMHARDCLASS]);
    printf("------------------------------------------------------------\n");
-   ListDefinedImports();
-   printf("------------------------------------------------------------\n");
    ListDefinedVariables();
    printf("------------------------------------------------------------\n");
-   ListDefinedStrategies();
-   printf("------------------------------------------------------------\n");
-   ListACLs();
-   printf("------------------------------------------------------------\n");
-   ListFilters();
-   printf("------------------------------------------------------------\n");   
-   ListDefinedIgnore();
-
-   printf("------------------------------------------------------------\n");
-   printf("------------------------------------------------------------\n");
    ListDefinedAlerts();
    printf("------------------------------------------------------------\n");
-   ListDefinedDisable();
+   ListDefinedStrategies();
    printf("------------------------------------------------------------\n");
-   ListFiles();
-   ListDefinedMakePaths();
+   ListDefinedResolvers();
    printf("------------------------------------------------------------\n");
-   ListFileEdits();
-   printf("------------------------------------------------------------\n");
-   ListDefinedImages();
-   printf("------------------------------------------------------------\n");
-   ListDefinedLinks();
-   printf("------------------------------------------------------------\n");
-   ListDefinedLinkchs();
-   printf("------------------------------------------------------------\n");
-   ListDefinedMethods();
+   ListDefinedRequired();
    printf("------------------------------------------------------------\n");
    ListDefinedMountables();
    printf("------------------------------------------------------------\n");
@@ -743,21 +691,38 @@ if (DEBUG || D2 || D3)
    printf("------------------------------------------------------------\n");
    ListUnmounts();
    printf("------------------------------------------------------------\n");
-   ListDefinedPackages();
+   ListDefinedMakePaths();
+   printf("------------------------------------------------------------\n");
+   ListDefinedImports();
+   printf("------------------------------------------------------------\n");
+   ListFiles();
+   printf("------------------------------------------------------------\n");
+   ListACLs();
+   printf("------------------------------------------------------------\n");
+   ListFilters();
+   printf("------------------------------------------------------------\n");   
+   ListDefinedIgnore();
+   printf("------------------------------------------------------------\n");
+   ListFileEdits();
    printf("------------------------------------------------------------\n");
    ListProcesses();
    printf("------------------------------------------------------------\n");
-   ListDefinedRequired();
-   printf("------------------------------------------------------------\n");
-   ListDefinedResolvers();
-   printf("------------------------------------------------------------\n");
-   ListDefinedSCLI();
-   printf("------------------------------------------------------------\n");
-   ListDefinedScripts();
+   ListDefinedImages();
    printf("------------------------------------------------------------\n");
    ListDefinedTidy();
    printf("------------------------------------------------------------\n");
-
+   ListDefinedDisable();
+   printf("------------------------------------------------------------\n");
+   ListDefinedLinks();
+   printf("------------------------------------------------------------\n");
+   ListDefinedLinkchs();
+   printf("------------------------------------------------------------\n");
+   ListDefinedScripts();
+   printf("------------------------------------------------------------\n");
+   ListDefinedPackages();
+   printf("------------------------------------------------------------\n");
+   ListDefinedMethods();
+   printf("------------------------------------------------------------\n");
 
    
    if (IGNORELOCK)
@@ -782,41 +747,15 @@ if (VACTIONSEQ == NULL)
    Warning("perhaps cfagent.conf/update.conf have not yet been set up?");
    }
 
-ACTION = none;
-
 sprintf(id,"%d",geteuid());   /* get effective user id */
 
-ebuff[0] = '\0';
-
-if (!StrStr(VSYSNAME.nodename,VDOMAIN))
-   {
-   snprintf(VFQNAME,CF_BUFSIZE,"%s.%s",VSYSNAME.nodename,ToLowerStr(VDOMAIN));
-   strcpy(VUQNAME,VSYSNAME.nodename);
-   }
-else
-   {
-   int n = 0;
-   strcpy(VFQNAME,VSYSNAME.nodename);
-   
-   while(VSYSNAME.nodename[n++] != '.')
-      {
-      }
-   
-   strncpy(VUQNAME,VSYSNAME.nodename,n-1);        
-   }
-  
-Verbose("Accepted domain name: %s\n\n",VDOMAIN); 
-
-
 if (VACCESSLIST != NULL && !IsItemIn(VACCESSLIST,id))
    {
-   FatalError("Access denied - user not listed in access list");
+   FatalError("Access denied");
    }
 
 Debug2("cfagent -d : Debugging output enabled.\n");
 
-EDITVERBOSE = false;
-
 if (DONTDO && (VERBOSE || DEBUG || D2))
    {
    printf("cfagent -n: Running in ``All talk and no action'' mode\n");
@@ -878,7 +817,7 @@ if (GetMacroValue(CONTEXTID,"LockDirectory"))
 
 if (GetMacroValue(CONTEXTID,"LogDirectory"))
    {
-   Verbose("\n[LogDirectory is no longer runtime configurable: use configure --with-workdir=CFWORKDIR ]\n\n");
+   Verbose("\n[LogDirectory is no longer runtime configurable: use configure --with-workdir=WORKDIR ]\n\n");
    }
 
 Verbose("LogDirectory = %s\n",VLOGDIR);
@@ -931,16 +870,6 @@ if (OptionIs(CONTEXTID,"Verbose",true))
    VERBOSE = true;
    }
 
-if (OptionIs(CONTEXTID,"LastSeen",false))
-   {
-   LASTSEEN = false;
-   }
-
-if (OptionIs(CONTEXTID,"FullEncryption",true))
-   {
-   FULLENCRYPT = true;
-   }
-
 if (OptionIs(CONTEXTID,"Inform",true))
    {
    INFORM = true;
@@ -1042,19 +971,20 @@ if (GetMacroValue(CONTEXTID,"DefaultCopyType"))
  
 if (GetMacroValue(CONTEXTID,"ChecksumDatabase"))
    {
-   FatalError("ChecksumDatabase variable is deprecated - comment it out");
+   ExpandVarstring("$(ChecksumDatabase)",ebuff,NULL);
+
+   CHECKSUMDB = strdup(ebuff);
+
+   if (*CHECKSUMDB != '/')
+      {
+      FatalError("$(ChecksumDatabase) does not expand to an absolute filename\n");
+      }
    }
 else
    {
-   snprintf(ebuff,CF_BUFSIZE,"%s/%s",CFWORKDIR,CF_CHKDB);
+   snprintf(ebuff,CF_BUFSIZE,"%s/checksum.db",WORKDIR);
    CHECKSUMDB = strdup(ebuff);
    }
-
-if (SHOWDB)
-   {
-   printf("%s\n",CHECKSUMDB);
-   exit(0);
-   }
  
 Verbose("Checksum database is %s\n",CHECKSUMDB); 
  
@@ -1066,7 +996,7 @@ if (GetMacroValue(CONTEXTID,"CompressCommand"))
    
    if (*COMPRESSCOMMAND != '/')
       {
-      FatalError("$(CompressCommand) does not expand to an absolute filename\n");
+      FatalError("$(ChecksumDatabase) does not expand to an absolute filename\n");
       }
    }
 
@@ -1089,31 +1019,13 @@ if (GetMacroValue(CONTEXTID,"TimeOut"))
       }
    }
 
-/* Make sure we have a healthy binserver list so binserver expansion works, even if binserver not defined */
-
-if (VBINSERVERS == NULL)
-   {
-   PrependItem(&VBINSERVERS,VUQNAME,NULL);
-   }
-
-if (VBINSERVERS->name != NULL)
-   {
-   VDEFAULTBINSERVER = *VBINSERVERS;
-   Verbose("Default binary server seems to be %s\n",VDEFAULTBINSERVER.name);
-   }
-
-AppendItem(&VBINSERVERS,VUQNAME,NULL);
-
-/* Done binserver massage */
-
 if (NOSPLAY)
    {
    return;
    }
 
 time = 0;
-snprintf(ebuff,CF_BUFSIZE,"%s+%s+%d",VFQNAME,VIPADDRESS,getuid());
-hash = Hash(ebuff);
+hash = Hash(VFQNAME);
 
 if (!NOSPLAY)
    {
@@ -1149,36 +1061,36 @@ if (!NOSPLAY)
     } 
 }
 
-
 /*******************************************************************/
 
-void QueryCheck()
+void SetReferenceTime(int setclasses)
 
-{ char src[CF_MAXVARSIZE],ebuff[CF_EXPANDSIZE];
-  struct Item *ip;
+{ time_t tloc;
+ char vbuff[CF_MAXVARSIZE];
  
-if (QUERYVARS == NULL)
+if ((tloc = time((time_t *)NULL)) == -1)
    {
-   return;
+   CfLog(cferror,"Couldn't read system clock\n","");
    }
 
-for (ip = QUERYVARS; ip != NULL; ip=ip->next)
-   {
-   snprintf(src,CF_MAXVARSIZE,"$(%s)",ip->name);
-   ExpandVarstring(src,ebuff,"");
-   printf("%s=%s\n",ip->name,ebuff);
-   }
+CFSTARTTIME = tloc;
 
-exit(0);
+snprintf(vbuff,CF_BUFSIZE,"%s",ctime(&tloc));
+
+Verbose("Reference time set to %s\n",ctime(&tloc));
+
+if (setclasses)
+   {
+   AddTimeClass(vbuff);
+   }
 }
 
+
 /*******************************************************************/
 
 void DoTree(int passes,char *info)
 
 { struct Item *action;
-
-Debug("DoTree(%d,%s)\n",passes,info);
  
 for (PASS = 1; PASS <= passes; PASS++)
    {
@@ -1203,14 +1115,14 @@ for (PASS = 1; PASS <= passes; PASS++)
       
       if ((PASS > 1) && NothingLeftToDo())
          {
-         break;
+         continue;
          }
       
       Verbose("\n*********************************************************************\n");
       Verbose(" %s Sched: %s pass %d @ %s",info,action->name,PASS,ctime(&CFINITSTARTTIME));
       Verbose("*********************************************************************\n\n");
       
-      switch (EvaluateAction(action->name,&VADDCLASSES,PASS))
+      switch(ACTION = EvaluateAction(action->name,&VADDCLASSES,PASS))
          {
          case mountinfo:
              if (PASS == 1)
@@ -1393,187 +1305,96 @@ int NothingLeftToDo()
   struct Process *vproclist;
   struct Tidy *vtidy;
   struct Package *vpkg;
-  struct Image *vcopy;
 
-if (IsWildItemIn(VACTIONSEQ,"process*"))
+for (vproclist = VPROCLIST; vproclist != NULL; vproclist=vproclist->next)
    {
-   for (vproclist = VPROCLIST; vproclist != NULL; vproclist=vproclist->next)
+   if (vproclist->done == 'n')
       {
-      if ((vproclist->done == 'n') && IsDefinedClass(vproclist->classes))
-         {
-         Verbose("Checking for potential rule:: Proc <%s> / %s\n",vproclist->expr,vproclist->classes);
-         return false;
-         }
+      return false;
+      }
+   }
+ 
+ for (vscript = VSCRIPT; vscript != NULL; vscript=vscript->next)
+    {
+    if (vscript->done == 'n')
+       {
+       return false;
+       }
+    }
+ 
+for (vfile = VFILE; vfile != NULL; vfile=vfile->next)
+   {
+   if (vfile->done == 'n')
+      {
+      return false;
       }
    }
 
-if (IsWildItemIn(VACTIONSEQ,"shellcomman*"))
+for (vtidy = VTIDY; vtidy != NULL; vtidy=vtidy->next)
    {
-   for (vscript = VSCRIPT; vscript != NULL; vscript=vscript->next)
+   if (vtidy->done == 'n')
       {
-      if ((vscript->done == 'n')  && IsDefinedClass(vscript->classes))
-         {
-         Verbose("Checking for potential rule:: Shell <%s> / %s\n",vscript->name,vscript->classes);
-         return false;
-         }
+      return false;
+      }
+   }
+ 
+for (veditlist = VEDITLIST; veditlist != NULL; veditlist=veditlist->next)
+   {
+   if (veditlist->done == 'n')
+      {
+      return false;
       }
    }
 
-if (IsWildItemIn(VACTIONSEQ,"cop*"))
+for (vdisablelist = VDISABLELIST; vdisablelist != NULL; vdisablelist=vdisablelist->next)
    {
-   for (vcopy = VIMAGE; vcopy != NULL; vcopy=vcopy->next)
+   if (vdisablelist->done == 'n')
       {
-      if ((vcopy->done == 'n')  && IsDefinedClass(vcopy->classes))
-         {
-         Verbose("Checking for potential rule:: Copy <%s> / %s\n",vcopy->path,vcopy->classes);
-         return false;
-         }
+      return false;
+      }
+   }
+
+for (vmakepath = VMAKEPATH; vmakepath != NULL; vmakepath=vmakepath->next)
+   {
+   if (vmakepath->done == 'n')
+      {
+      return false;
+      }
+   }
+
+for (vlink = VLINK; vlink != NULL; vlink=vlink->next)
+   {
+   if (vlink->done == 'n')
+      {
+      return false;
+      }
+   }
+
+for (vchlink = VCHLINK; vchlink != NULL; vchlink=vchlink->next)
+   {
+   if (vchlink->done == 'n')
+      {
+      return false;
       }
    }
 
 
-if (IsWildItemIn(VACTIONSEQ,"file*"))
+for (vunmount = VUNMOUNT; vunmount != NULL; vunmount=vunmount->next)
    {
-   for (vfile = VFILE; vfile != NULL; vfile=vfile->next)
+   if (vunmount->done == 'n')
       {
-      if ((vfile->done == 'n') && IsDefinedClass(vfile->classes))
-         {
-         Verbose("Checking for potential rule:: File <%s>/ %s\n",vfile->path,vfile->classes);
-         return false;
-         }
+      return false;
       }
    }
 
-if (IsWildItemIn(VACTIONSEQ,"tid*"))
+for (vpkg = VPKG; vpkg != NULL; vpkg=vpkg->next)
    {
-   for (vtidy = VTIDY; vtidy != NULL; vtidy=vtidy->next)
+   if (vpkg->done == 'n')
       {
-      if (vtidy->done == 'n')
-         {
-         struct TidyPattern *tp;
-         int active = 0;
-         
-         for (tp = vtidy->tidylist; tp != NULL; tp=tp->next)
-            {
-            if (IsDefinedClass(tp->classes))
-               {
-               active=1;
-               break;
-               }
-            }
-
-         if (active)
-            {
-            Verbose("Checking for potential rule:: Tidy <%s>\n",vtidy->path);
-            return false;
-            }
-         }
+      return false;
       }
    }
 
-if (IsWildItemIn(VACTIONSEQ,"editfile*"))
-   {
-   for (veditlist = VEDITLIST; veditlist != NULL; veditlist=veditlist->next) 
-      { 
-      struct Edlist *ep;
-      int something_to_do = false;
-      
-      for (ep = veditlist->actions; ep != NULL; ep=ep->next)
-         {
-         if (IsDefinedClass(ep->classes))
-            {
-            something_to_do = true;
-            if (ep->data)
-               {
-               Verbose("Defined Edit %s / %s\n",ep->data,ep->classes);
-               }
-            else
-               {
-               Verbose("Defined Edit nodata / %s\n",ep->classes);
-               }
-            break;
-            }
-         }
-   
-      if (veditlist->done == 'n' && something_to_do)
-         {
-         Verbose("Checking for potential rule:: Edit <%s>\n",veditlist->fname);
-         return false;
-         }
-      }
-   }
-
-if (IsWildItemIn(VACTIONSEQ,"process*"))
-   {
-   for (vdisablelist = VDISABLELIST; vdisablelist != NULL; vdisablelist=vdisablelist->next)
-      {
-      if (vdisablelist->done == 'n' && IsDefinedClass(vdisablelist->classes))
-         {
-         Verbose("Checking for potential rule:: Disable <%s> / %s\n",vdisablelist->name,vdisablelist->classes);
-         return false;
-         }
-      }
-   }
-
-if (IsWildItemIn(VACTIONSEQ,"director*"))
-   {
-   for (vmakepath = VMAKEPATH; vmakepath != NULL; vmakepath=vmakepath->next)
-      {
-      if (vmakepath->done == 'n' && IsDefinedClass(vmakepath->classes))
-         {
-         Verbose("Checking for potential rule:: makePath <%s>\n",vmakepath->path);
-         return false;
-         }
-      }
-   }
-
-if (IsWildItemIn(VACTIONSEQ,"link*"))
-   {
-   for (vlink = VLINK; vlink != NULL; vlink=vlink->next)
-      {
-      if (vlink->done == 'n' && IsDefinedClass(vlink->classes))
-         {
-         Verbose("Checking for potential rule:: Link <%s>\n",vlink->from);
-         return false;
-         }
-      }
-   
-   for (vchlink = VCHLINK; vchlink != NULL; vchlink=vchlink->next)
-      {
-      if (vchlink->done == 'n' && IsDefinedClass(vchlink->classes))
-         {
-         Verbose("Checking for potential rule:: CLink <%s>\n",vchlink->from);
-         return false;
-         }
-      }
-   }
-
-
-if (IsWildItemIn(VACTIONSEQ,"unmoun*"))
-   {
-   for (vunmount = VUNMOUNT; vunmount != NULL; vunmount=vunmount->next)
-      {
-      if (vunmount->done == 'n' && IsDefinedClass(vunmount->classes))
-         {
-         Verbose("Checking for potential rule:: Umount <%s>\n",vunmount->name);
-         return false;
-         }
-      }
-   }
-
-if (IsWildItemIn(VACTIONSEQ,"packag*"))
-   {
-   for (vpkg = VPKG; vpkg != NULL; vpkg=vpkg->next)
-      {
-      if (vpkg->done == 'n' && IsDefinedClass(vpkg->classes))
-         {
-         Verbose("Checking for potential rule:: Packages <%s>\n",vpkg->name);
-         return false;
-         }
-      }
-   }
-
-
 return true; 
 }
 
@@ -1698,7 +1519,7 @@ void CheckOpts(int argc,char **argv)
   int c;
 
   
-while ((c=getopt_long(argc,argv,"WbBzMgAbKqkhYHd:vlniIf:pPmcCtsSaeEVD:N:LwxXuUj:o:Z:Q:",OPTIONS,&optindex)) != EOF)
+while ((c=getopt_long(argc,argv,"bBzMgAbKqkhYHd:vlniIf:pPmcCtsSaeEVD:N:LwxXuUj:o:Z:",OPTIONS,&optindex)) != EOF)
   {
   switch ((char) c)
       {
@@ -1807,8 +1628,7 @@ while ((c=getopt_long(argc,argv,"WbBzMgAbKqkhYHd:vlniIf:pPmcCtsSaeEVD:N:LwxXuUj:
           PARSEONLY = true;
           break;
           
-      case 'z':
-          PRSCHEDULE = true;
+      case 'z': PRMAILSERVER = true;
           IGNORELOCK = true;
           PARSEONLY = true;
           break;
@@ -1857,9 +1677,6 @@ while ((c=getopt_long(argc,argv,"WbBzMgAbKqkhYHd:vlniIf:pPmcCtsSaeEVD:N:LwxXuUj:
           
       case 'q': NOSPLAY = true;
           break;
-
-      case 'W': SHOWDB = true; 
-          break;
           
       case 'Y': CFPARANOID = true;
           break;
@@ -1871,17 +1688,6 @@ while ((c=getopt_long(argc,argv,"WbBzMgAbKqkhYHd:vlniIf:pPmcCtsSaeEVD:N:LwxXuUj:
       case 'o': actionList = SplitStringAsItemList(optarg, ',');
           VAVOIDACTIONS = ConcatLists(actionList, VAVOIDACTIONS);
           break;
-
-      case 'Q':
-          if (optarg == NULL || strlen(optarg) == 0)
-             {
-             exit(1);
-             }
-          
-          IGNORELOCK = true;
-          NOSPLAY = true;
-          QUERYVARS = SplitStringAsItemList(optarg,',');
-          break;
           
       default:  Syntax();
           exit(1);
@@ -1890,6 +1696,84 @@ while ((c=getopt_long(argc,argv,"WbBzMgAbKqkhYHd:vlniIf:pPmcCtsSaeEVD:N:LwxXuUj:
   }
 }
 
+/*******************************************************************/
+
+void CheckForMethod()
+
+{ struct Item *ip;
+  int i = 0;
+
+if (strcmp(METHODNAME,"cf-nomethod") == 0)
+   {
+   return;
+   }
+
+if (! MINUSF)
+   {
+   FatalError("Input files claim to be a module but this is a parent process\n");
+   }
+
+Verbose("\n++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++\n+\n");
+Verbose("+ This is a private method: %s\n",METHODNAME);
+
+if (METHODARGS == NULL)
+   {
+   FatalError("This module was declared a method but no MethodParameters declaration was given");
+   }
+else
+   {
+   Verbose("+\n+ Method argument prototype = (");
+
+   i = 1;
+   
+   for (ip = METHODARGS; ip != NULL; ip=ip->next)
+      {
+      i++;
+      }
+
+   METHODARGV = (char **) malloc(sizeof(char *) * i); 
+   
+   i = 0;
+
+   for (ip = METHODARGS; ip != NULL; ip=ip->next)
+      {
+      /* Fill this temporarily with the formal parameters */
+      METHODARGV[i++] = ip->name; 
+      }
+
+   METHODARGC = i;
+   
+   Verbose(" )\n+\n");
+   }
+ 
+Verbose("++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++\n\n");
+
+Verbose("Looking for a data package for this method (%s)\n",METHODMD5);
+
+if (!ChildLoadMethodPackage(METHODNAME,METHODMD5))
+   {
+   snprintf(OUTPUT,CF_BUFSIZE,"No valid incoming request to execute method (%s)\n",METHODNAME);
+   CfLog(cfinform,OUTPUT,"");
+   exit(0);
+   }
+
+Debug("Method package looks ok -- proceeding\n"); 
+}
+
+/*******************************************************************/
+
+void CheckMethodReply()
+
+{
+if (ScopeIsMethod())
+   {
+   if (strlen(METHODREPLYTO) > 0)
+      {
+      Banner("Method reply message");
+      DispatchMethodReply();
+      }
+   }
+}
 
 /*******************************************************************/
 
@@ -1910,6 +1794,111 @@ FatalError(OUTPUT);
 return 0;
 }
 
+/*******************************************************************/
+
+void SetStartTime(int setclasses)
+
+{ time_t tloc;
+ 
+if ((tloc = time((time_t *)NULL)) == -1)
+   {
+   CfLog(cferror,"Couldn't read system clock\n","");
+   }
+
+CFINITSTARTTIME = tloc;
+
+Debug("Job start time set to %s\n",ctime(&tloc));
+}
+
+/*******************************************************************/
+
+void BuildClassEnvironment()
+
+{ struct Item *ip;
+ int size = 0;
+ char file[CF_BUFSIZE], *sp;
+ FILE *fp;
+ 
+Debug("(BuildClassEnvironment)\n");
+
+snprintf(ALLCLASSBUFFER,CF_BUFSIZE,"%s=",CF_ALLCLASSESVAR);
+
+if (!IsPrivileged())
+   {
+   Verbose("\n(Non privileged user...)\n\n");
+   
+   if ((sp = getenv("HOME")) == NULL)
+      {
+      FatalError("You do not have a HOME variable pointing to your home directory");
+      }  
+
+   snprintf(file,CF_BUFSIZE,"%s/.cfagent/allclasses",sp);
+   }
+else
+   {
+   snprintf(file,CF_BUFSIZE,"%s/state/allclasses",WORKDIR);
+   }
+
+
+
+if ((fp = fopen(file,"w")) == NULL)
+   {
+   CfLog(cfinform,"Could not open allclasses cache file","");
+   return;
+   }
+
+for (ip = VHEAP; ip != NULL; ip=ip->next)
+   {
+   if (IsDefinedClass(ip->name))
+      {
+      if ((size += strlen(ip->name)) > CF_BUFSIZE - CF_BUFFERMARGIN)
+         {
+         Verbose("Class buffer overflowed, dumping class environment for modules\n");
+         Verbose("This would probably crash the exec interface on most machines\n");
+         }
+      else
+         {
+         size++; /* Allow for : separator */
+         strcat(ALLCLASSBUFFER,ip->name);
+         strcat(ALLCLASSBUFFER,":");
+         }
+
+      fprintf(fp,"%s\n",ip->name);
+      }
+   }
+ 
+ for (ip = VALLADDCLASSES; ip != NULL; ip=ip->next)
+    {
+    if (IsDefinedClass(ip->name))
+      {
+      if ((size += strlen(ip->name)) > 4*CF_BUFSIZE - CF_BUFFERMARGIN)
+         {
+         Verbose("Class buffer overflowed, dumping class environment for modules\n");
+         Verbose("This would probably crash the exec interface on most machines\n");
+         }
+      else
+         {
+         size++; /* Allow for : separator */
+         strcat(ALLCLASSBUFFER,ip->name);
+         strcat(ALLCLASSBUFFER,":");         
+         }
+      
+      fprintf(fp,"%s\n",ip->name);
+      }
+    }
+ 
+ Debug2("---\nENVIRONMENT: %s\n---\n",ALLCLASSBUFFER);
+ 
+ if (USEENVIRON)
+    {
+    if (putenv(ALLCLASSBUFFER) == -1)
+       {
+       perror("putenv");
+       }
+    }
+
+ fclose(fp);
+}
 
 /*******************************************************************/
 
@@ -1930,6 +1919,6 @@ printf("\nDebug levels: 1=parsing, 2=running, 3=summary, 4=expression eval\n");
 
 printf("\nBug reports to bug-cfengine@gnu.org (News: gnu.cfengine.bug)\n");
 printf("General help to help-cfengine@gnu.org (News: gnu.cfengine.help)\n");
-printf("Info & fixes at http://www.cfengine.org\n");
+printf("Info & fixes at http://www.iu.hio.no/cfengine\n");
 }
 /* EOF */
