@@ -28,6 +28,7 @@
 /*                                                                 */
 /*******************************************************************/
 
+#include "../pub/getopt.h"
 #include "cf.defs.h"
 #include "cf.extern.h"
 
@@ -72,7 +73,8 @@ struct option CFDOPTIONS[] =
    { "help",no_argument,0,'h' },
    { "debug",optional_argument,0,'d' }, 
    { "verbose",no_argument,0,'v' },
-   { "no-splay",no_argument,0,'q' },
+   { "file",required_argument,0,'f' },
+   { "no-splay",required_argument,0,'q' },
    { "no-fork",no_argument,0,'F' },
    { "once",no_argument,0,'1'},
    { "foreground",no_argument,0,'g'},
@@ -82,7 +84,6 @@ struct option CFDOPTIONS[] =
    };
 
 char MAILTO[CF_BUFSIZE];
-char MAILFROM[CF_BUFSIZE];
 int MAXLINES = -1;
 const int INF_LINES = -2;
 
@@ -150,7 +151,7 @@ NOSPLAY = false;
 sprintf(VPREFIX, "cfexecd"); 
 openlog(VPREFIX,LOG_PID|LOG_NOWAIT|LOG_ODELAY,LOG_DAEMON);
 
-while ((c=getopt_long(argc,argv,"L:d:vhpqFV1g",CFDOPTIONS,&optindex)) != EOF)
+while ((c=getopt_long(argc,argv,"L:d:vhpFV1g",CFDOPTIONS,&optindex)) != EOF)
   {
   switch ((char) c)
       {
@@ -202,10 +203,6 @@ while ((c=getopt_long(argc,argv,"L:d:vhpqFV1g",CFDOPTIONS,&optindex)) != EOF)
           NO_FORK = true;
           break;
           
-      case 'h':  Syntax();
-          exit(1);
-          break;  /* never reached.... */
-          
       default:  Syntax();
           exit(1);
           
@@ -214,51 +211,33 @@ while ((c=getopt_long(argc,argv,"L:d:vhpqFV1g",CFDOPTIONS,&optindex)) != EOF)
  
 LOGGING = true;                    /* Do output to syslog */
 
- /* XXX Initialize workdir for non privileged users */
-
-strcpy(CFWORKDIR,WORKDIR);
-
-if (getuid() > 0)
-   {
-   char *homedir;
-   if ((homedir = getenv("HOME")) != NULL)
-      {
-      strcpy(CFWORKDIR,homedir);
-      strcat(CFWORKDIR,"/.cfagent");
-      }
-   }
-
-snprintf(VBUFF,CF_BUFSIZE,"%s/inputs/update.conf",CFWORKDIR);
+snprintf(VBUFF,CF_BUFSIZE,"%s/inputs/update.conf",WORKDIR);
 MakeDirectoriesFor(VBUFF,'y');
-snprintf(VBUFF,CF_BUFSIZE,"%s/bin/cfagent -D from_cfexecd",CFWORKDIR);
+snprintf(VBUFF,CF_BUFSIZE,"%s/bin/cfagent",WORKDIR);
 MakeDirectoriesFor(VBUFF,'y');
-snprintf(VBUFF,CF_BUFSIZE,"%s/outputs/spooled_reports",CFWORKDIR);
+snprintf(VBUFF,CF_BUFSIZE,"%s/outputs/spooled_reports",WORKDIR);
 MakeDirectoriesFor(VBUFF,'y');
 
-snprintf(VBUFF,CF_BUFSIZE,"%s/inputs",CFWORKDIR);
+snprintf(VBUFF,CF_BUFSIZE,"%s/inputs",WORKDIR);
 chmod(VBUFF,0700); 
-snprintf(VBUFF,CF_BUFSIZE,"%s/outputs",CFWORKDIR);
+snprintf(VBUFF,CF_BUFSIZE,"%s/outputs",WORKDIR);
 chmod(VBUFF,0700);
 
-strncpy(VLOCKDIR,CFWORKDIR,CF_BUFSIZE-1);
-strncpy(VLOGDIR,CFWORKDIR,CF_BUFSIZE-1);
+strncpy(VLOCKDIR,WORKDIR,CF_BUFSIZE-1);
+strncpy(VLOGDIR,WORKDIR,CF_BUFSIZE-1);
 
 VCANONICALFILE = strdup(CanonifyName(VINPUTFILE));
 GetNameInfo();
 
 strcpy(VUQNAME,VSYSNAME.nodename);
-
-MAILTO[0] = '\0';
-MAILFROM[0] = '\0';
-VIPADDRESS[0] = '\0';
-VMAILSERVER[0] = '\0';
 }
 
+
 /*******************************************************************/
 
 void StartServer(int argc,char **argv)
 
-{ int pid,time_to_run = false;
+{ int time_to_run = false;
   time_t now = time(NULL); 
 
 Banner("Starting server");
@@ -291,8 +270,6 @@ signal(SIGINT,(void *)ExitCleanly);
 signal(SIGTERM,(void *)ExitCleanly);
 signal(SIGHUP,SIG_IGN);
 signal(SIGPIPE,SIG_IGN);
-signal(SIGUSR1,HandleSignal);
-signal(SIGUSR2,HandleSignal);
  
 umask(077);
 
@@ -311,7 +288,7 @@ else
    /*
     * Append --once option to our arguments for spawned monitor process.
     */
-     nargv = malloc(sizeof(char *) * (argc+2));
+   nargv = malloc(sizeof(char *) * argc+2);
    
    for (i = 0; i < argc; i++)
       {
@@ -348,7 +325,7 @@ else
          pid = spawnvp((int)_P_NOWAIT, nargv[0], nargv);
          if (pid < 1)
             {
-            CfLog(cfinform,"Can't spawn run","spawnvp");
+            CfLog(cferror,"Can't spawn run","spawnvp");
             }
 #endif
 #ifndef NT
@@ -363,7 +340,7 @@ else
          
          if (pthread_create(&tid,&PTHREADDEFAULTS,LocalExec,NULL) != 0)
             {
-            CfLog(cfinform,"Can't create thread!","pthread_create");
+            CfLog(cferror,"Can't create thread!","pthread_create");
             LocalExec(NULL);
             }
          
@@ -409,106 +386,85 @@ void GetCfStuff()
   char cfcom[CF_BUFSIZE];
   static char line[CF_BUFSIZE];
 
-/* Do not init variables here, in case we can use previous values. */
-  
-snprintf(cfcom,CF_BUFSIZE-1,"%s/bin/cfagent -Q smtpserver,sysadm,fqhost,ipaddress,EmailMaxLines,EmailFrom,EmailTo -D from_cfexecd",CFWORKDIR);
-
+snprintf(cfcom,CF_BUFSIZE-1,"%s/bin/cfagent -z",WORKDIR);
+ 
 if ((pp=cfpopen(cfcom,"r")) ==  NULL)
    {
-   CfLog(cfinform,"Couldn't start cfengine!","cfpopen");
+   CfLog(cferror,"Couldn't start cfengine!","cfpopen");
    line[0] = '\0';
    return;
    }
 
-while (!feof(pp))
+line[0] = '\0'; 
+fgets(line,CF_BUFSIZE,pp); 
+Chop(line); 
+
+while (strstr(line,":"))
    {
-   char name[CF_BUFSIZE],content[CF_BUFSIZE];
    line[0] = '\0'; 
    fgets(line,CF_BUFSIZE,pp); 
-   Chop(line); 
-   sscanf(line,"%[^=]=%[^\n]",name,content);
-    
-   if (strcmp(name,"sysadm") == 0)
-      {
-      strncpy(MAILTO,content,CF_MAXVARSIZE-1);
-      Debug("%s\n",line);
-      continue;
-      }
-
-   if (strcmp(name,"smtpserver") == 0)
-      {
-      Debug("%s/%s\n",name,content);
-      strncpy(VMAILSERVER,content,CF_MAXVARSIZE-1);
-      continue;
-      }
-   
-   if (strcmp(name,"fqhost") == 0)
-      {
-      Debug("%s/%s\n",name,content);
-      strncpy(VFQNAME,content,CF_MAXVARSIZE-1);
-      continue;
-      }
-
-   if (strcmp(name,"ipaddress") == 0)
-      {
-      Debug("%s/%s\n",name,content);
-      strncpy(VIPADDRESS,content,17);
-      continue;
-      }
-
-   if (strcmp(name,"EmailMaxLines") == 0)
-      {
-      Debug("%s/%s\n",name,content);
-
-      MAXLINES = 100;
-      if (strcmp(content,"inf") == 0)
-         {
-         MAXLINES = -2;
-         Debug("EmailMaxLines set to infinity\n");
-         }
-      else 
-         {
-         sscanf(content,"%d",&MAXLINES);
-         }
-      continue;
-      }
-
-   if (strcmp(name,"EmailFrom") == 0)
-      {
-      Debug("%s/%s\n",name,content);
-      if (strstr(content,"$") == NULL && strlen(content) > 0)
-         {
-         strncpy(MAILFROM,content,CF_MAXVARSIZE-1);
-         continue;
-         }
-      }
-   
-   if (strcmp(name,"EmailTo") == 0)
-      {
-      Debug("%s/%s\n",name,content);
-      if (strstr(content,"$") == NULL && strlen(content) > 0)
-         {
-         strncpy(MAILTO,content,CF_MAXVARSIZE-1);
-         continue;
-         }
-      }
+   Chop(line);    
    }
 
-cfpclose(pp);
-
-Debug("Got(to:%s,serv:%s,host:%s,ip:%s,max:%d,from:%s)\n",MAILTO,VMAILSERVER,VFQNAME,VIPADDRESS,MAXLINES,MAILFROM); 
- 
-/* Now get schedule */
-  
-snprintf(cfcom,CF_BUFSIZE-1,"%s/bin/cfagent -z -D from_cfexecd",CFWORKDIR);
- 
-if ((pp=cfpopen(cfcom,"r")) ==  NULL)
+if (strstr(line,"No SMTP"))
    {
-   CfLog(cfinform,"Couldn't start cfengine!","cfpopen");
-   line[0] = '\0';
-   return;
+   CfLog(cferror,"cfengine defines no SMTP server -- or perhaps a syntax error in the config","");
+   CfLog(cferror,"Need: smtpserver = ( ?? ) in control ","");
    }
 
+strcpy(VMAILSERVER,line); 
+ 
+Debug("Got cfengine SMTP server as (%s)\n",VMAILSERVER); 
+
+line[0] = '\0'; 
+fgets(line,CF_BUFSIZE,pp); 
+Chop(line); 
+
+if (strlen(line) == 0)
+   {
+   CfLog(cferror,"cfengine defines no system administrator address","");
+   CfLog(cferror,"Need: sysadm = ( ??@?? ) in control ","");
+   }
+
+strcpy(MAILTO,line); 
+Debug("Got cfengine sysadm variable (%s)\n",MAILTO); 
+
+line[0] = '\0'; 
+fgets(line,CF_BUFSIZE,pp); 
+Chop(line); 
+strcpy(VFQNAME,line); 
+Debug("Got fully qualified name (%s)\n",VFQNAME); 
+
+line[0] = '\0'; 
+fgets(line,CF_BUFSIZE,pp); 
+Chop(line); 
+strcpy(VIPADDRESS,line); 
+Debug("Got IP (%s)\n",VIPADDRESS); 
+
+if ((ungetc(fgetc(pp), pp)) != '[')
+   {
+   line[0] = '\0';
+   fgets(line,CF_BUFSIZE,pp);
+   Chop(line);
+   if (sscanf(line, "%d", &MAXLINES) == 1)
+      {
+      Debug("Got max lines (%d)\n", MAXLINES); 
+      }
+   else if (strcmp(line, "inf") == 0)
+      {
+      Debug("Infinite lines\n");
+      MAXLINES = INF_LINES;
+      }
+   }
+
+if (MAXLINES == -1)
+   {
+   MAXLINES = 100;
+   Debug("Defaulting to max lines (%d)\n", MAXLINES);
+   }
+
+/* Now get scheduling constraints */
+
 DeleteItemList(SCHEDULE);
 SCHEDULE = NULL; 
  
@@ -564,7 +520,6 @@ for (ip = SCHEDULE; ip != NULL; ip = ip->next)
       DeleteItemList(VHEAP);
       VHEAP = NULL;
       GetNameInfo();
-      strcpy(VUQNAME,VSYSNAME.nodename);
       return true;
       }
    }
@@ -572,7 +527,6 @@ for (ip = SCHEDULE; ip != NULL; ip = ip->next)
 DeleteItemList(VHEAP);
 VHEAP = NULL; 
 GetNameInfo();
-strcpy(VUQNAME,VSYSNAME.nodename);
 return false;
 }
 
@@ -591,23 +545,6 @@ exit(0);
 
 /**************************************************************/
 
-static char *timestamp(time_t stamp, char *buf, size_t len)
-{
-  struct tm *ltime;
-
-  ltime = localtime(&stamp);
-  snprintf(buf, len, "%04d-%02d-%02d--%02d-%02d-%02d",
-		      ltime->tm_year+1900,
-		      ltime->tm_mon+1,
-		      ltime->tm_mday,
-		      ltime->tm_hour,
-		      ltime->tm_min,
-		      ltime->tm_sec);
-  return buf;
-}
-
-/**************************************************************/
-
 void *LocalExec(void *dummy)
 
 { FILE *pp; 
@@ -632,30 +569,30 @@ Verbose("------------------------------------------------------------------\n");
 
 if (NOSPLAY)
    {
-   snprintf(cmd,CF_BUFSIZE-1,"%s/bin/cfagent -q -Dfrom_cfexecd",CFWORKDIR);
+   snprintf(cmd,CF_BUFSIZE-1,"%s/bin/cfagent -q",WORKDIR);
    }
 else
    {
-   snprintf(cmd,CF_BUFSIZE-1,"%s/bin/cfagent -Dfrom_cfexecd",CFWORKDIR);
+   snprintf(cmd,CF_BUFSIZE-1,"%s/bin/cfagent",WORKDIR);
    }
  
-timestamp(starttime, line, CF_BUFSIZE);
+snprintf(line,100,CanonifyName(ctime(&starttime)));
+snprintf(filename,CF_BUFSIZE-1,"%s/outputs/cf_%s_%s",WORKDIR,CanonifyName(VFQNAME),line);
+
 
-snprintf(filename,CF_BUFSIZE-1,"%s/outputs/cf_%s_%s",CFWORKDIR,CanonifyName(VFQNAME),line);
- 
 /* What if no more processes? Could sacrifice and exec() - but we need a sentinel */
 
 if ((fp = fopen(filename,"w")) == NULL)
    {
    snprintf(OUTPUT,CF_BUFSIZE,"Couldn't open %s\n",filename);
-   CfLog(cfinform,OUTPUT,"fopen");
+   CfLog(cferror,OUTPUT,"fopen");
    return NULL;
    }
  
 if ((pp = cfpopen(cmd,"r")) == NULL)
    {
    snprintf(OUTPUT,CF_BUFSIZE,"Couldn't open pipe to command %s\n",cmd);
-   CfLog(cfinform,OUTPUT,"cfpopen");
+   CfLog(cferror,OUTPUT,"cfpopen");
    fclose(fp);
    return NULL;
    }
@@ -859,7 +796,7 @@ if (stat(file,&statbuf) == -1)
    }
 
 /* HvB: Bas van der Vlies */
-snprintf(prev_file,CF_BUFSIZE-1,"%s/outputs/previous",CFWORKDIR);
+snprintf(prev_file,CF_BUFSIZE-1,"%s/outputs/previous",WORKDIR);
  
 if (statbuf.st_size == 0)
    {
@@ -906,7 +843,7 @@ if (strlen(to) == 0)
 if ((fp=fopen(file,"r")) == NULL)
    {
    snprintf(VBUFF,CF_BUFSIZE-1,"Couldn't open file %s",file);
-   CfLog(cfinform,VBUFF,"fopen");
+   CfLog(cferror,VBUFF,"fopen");
    return;
    }
 
@@ -926,7 +863,7 @@ fclose(fp);
 if ((fp=fopen(file,"r")) == NULL)
    {
    snprintf(VBUFF,CF_BUFSIZE-1,"Couldn't open file %s",file);
-   CfLog(cfinform,VBUFF,"fopen");
+   CfLog(cferror,VBUFF,"fopen");
    return;
    }
  
@@ -944,7 +881,7 @@ if ((hp = gethostbyname(VMAILSERVER)) == NULL)
 
 if ((server = getservbyname("smtp","tcp")) == NULL)
    {
-   CfLog(cfinform,"Unable to lookup smtp service","getservbyname");
+   CfLog(cferror,"Unable to lookup smtp service","getservbyname");
    fclose(fp);
    return;
    }
@@ -959,7 +896,7 @@ Debug("Connecting...\n");
 
 if ((sd = socket(AF_INET,SOCK_STREAM,0)) == -1)
    {
-   CfLog(cfinform,"Couldn't open a socket","socket");
+   CfLog(cferror,"Couldn't open a socket","socket");
    fclose(fp);
    return;
    }
@@ -983,31 +920,23 @@ if (!Dialogue(sd,NULL))
 sprintf(VBUFF,"HELO %s\r\n",VFQNAME); 
 Debug("%s",VBUFF);
 
-if (!Dialogue(sd,VBUFF))
-   {
-   goto mail_err;
-   }
+ if (!Dialogue(sd,VBUFF))
+     {
+     goto mail_err;
+     }
 
-if (strlen(MAILFROM) > 0)
+domain[0] = '\0';
+sscanf(to,"%*[^@]@%.64s",domain);
+
+if (strlen(domain) > 0)
    {
-   sprintf(VBUFF,"MAIL FROM: <%s>\r\n",MAILFROM);
-   Debug("%s",VBUFF);   
+   sprintf(VBUFF,"MAIL FROM: <cfengine@%s>\r\n",domain);
+   Debug("%s",VBUFF);
    }
 else
    {
-   domain[0] = '\0';
-   sscanf(to,"%*[^@]@%64s",domain);
-   
-   if (strlen(domain) > 0)
-      {
-      sprintf(VBUFF,"MAIL FROM: <cfengine@%s>\r\n",domain);
-      Debug("%s",VBUFF);
-      }
-   else
-      {
-      sprintf(VBUFF,"MAIL FROM: <%s>\r\n",to);
-      Debug("%s",VBUFF);   
-      }
+   sprintf(VBUFF,"MAIL FROM: <%s>\r\n",to);
+   Debug("%s",VBUFF);   
    }
 
 if (!Dialogue(sd,VBUFF))
@@ -1049,19 +978,9 @@ strftime(VBUFF,CF_BUFSIZE,"Date: %a, %d %b %Y %H:%M:%S %z\r\n",localtime(&now));
 sent=send(sd,VBUFF,strlen(VBUFF),0);
 #endif
 
- if (strlen(MAILFROM) == 0)
-    {
-    sprintf(VBUFF,"From: cfengine@%s\r\n",VFQNAME);
-    Debug("%s",VBUFF);
-    }
- else
-    {
-    sprintf(VBUFF,"From: %s\r\n",MAILFROM);
-    Debug("%s",VBUFF);    
-    }
- 
+sprintf(VBUFF,"From: cfengine@%s\r\n",VFQNAME);
+Debug("%s",VBUFF);
 sent=send(sd,VBUFF,strlen(VBUFF),0);
-
 sprintf(VBUFF,"To: %s\r\n\r\n",to); 
 Debug("%s",VBUFF);
 sent=send(sd,VBUFF,strlen(VBUFF),0);
@@ -1105,7 +1024,7 @@ mail_err:
 fclose(fp);
 close(sd); 
 sprintf(VBUFF, "Cannot mail to %s.", to);
-CfLog(cflogonly,VBUFF,"");
+CfLog(cferror,VBUFF,"");
 }
 
 /******************************************************************/
