@@ -34,8 +34,8 @@
 
 char CFLOCK[CF_BUFSIZE];
 
-void Initialize(void);
-int RecursiveTidySpecialArea(char *name, struct Tidy *tp, int maxrecurse, struct stat *sb);
+void Initialize ARGLIST((void));
+int RecursiveTidySpecialArea ARGLIST((char *name, struct Tidy *tp, int maxrecurse, struct stat *sb));
 
 /*****************************************************************************/
 
@@ -85,14 +85,14 @@ fd = open(CFPRIVKEYFILE,O_WRONLY | O_CREAT | O_TRUNC, 0600);
 if (fd < 0)
    {
    printf("Ppen %s failed: %s.",CFPRIVKEYFILE,strerror(errno));
-   return 1;
+   return 0;
    }
  
 if ((fp = fdopen(fd, "w")) == NULL )
    {
    printf("fdopen %s failed: %s.",CFPRIVKEYFILE, strerror(errno));
    close(fd);
-   return 1;
+   return 0;
    }
 
 printf("Writing private key to %s\n",CFPRIVKEYFILE);
@@ -111,14 +111,14 @@ fd = open(CFPUBKEYFILE,O_WRONLY | O_CREAT | O_TRUNC, 0600);
 if (fd < 0)
    {
    printf("open %s failed: %s.",CFPUBKEYFILE,strerror(errno));
-   return 1;
+   return 0;
    }
  
 if ((fp = fdopen(fd, "w")) == NULL )
    {
    printf("fdopen %s failed: %s.",CFPUBKEYFILE, strerror(errno));
    close(fd);
-   return 1;
+   return 0;
    }
 
 printf("Writing public key to %s\n",CFPUBKEYFILE);
@@ -147,22 +147,8 @@ void Initialize()
 
 {
 umask(077);
- /* XXX Initialize workdir for non privileged users */
-
- strcpy(CFWORKDIR,WORKDIR);
-
- if (geteuid() > 0)
-    {
-    char *homedir;
-    if ((homedir = getenv("HOME")) != NULL)
-       {
-       strcpy(CFWORKDIR,homedir);
-       strcat(CFWORKDIR,"/.cfagent");
-       }
-    }
- 
-strcpy(VLOCKDIR,CFWORKDIR);
-strcpy(VLOGDIR,CFWORKDIR); 
+strcpy(VLOCKDIR,WORKDIR);
+strcpy(VLOGDIR,WORKDIR); 
 
 OpenSSL_add_all_algorithms();
 ERR_load_crypto_strings();
@@ -194,13 +180,3 @@ char *GetMacroValue(char *s,char *sp)
 {
  return NULL;
 }
-
-
-void ChecksumString(char *buffer,int len,unsigned char digest[EVP_MAX_MD_SIZE+1],char type)
-{
-}
-
-char *ChecksumPrint(char type,unsigned char digest[EVP_MAX_MD_SIZE+1])
-{
- return NULL;
-}
