@@ -29,11 +29,11 @@
 /*                                                                 */
 /*******************************************************************/
 
+#include "../pub/getopt.h"
 #include "cf.defs.h"
 #include "cf.extern.h"
 #include "cfservd.h"
 #include <db.h>
-#include <sys/time.h>
 
 /*******************************************************************/
 /* Pthreads                                                        */
@@ -67,7 +67,6 @@ int MULTIPLECONNS = false;
 int TRIES = 0;
 int MAXTRIES = 5;
 int LOGCONNS = false;
-int LOGENCRYPT = false;
 
 struct option CFDOPTIONS[] =
    {
@@ -77,6 +76,7 @@ struct option CFDOPTIONS[] =
    { "file",required_argument,0,'f' },
    { "no-fork",no_argument,0,'F' },
    { "parse-only",no_argument,0,'p'},
+   { "multithread",no_argument,0,'m'},
    { "ld-library-path",required_argument,0,'L'},
    { NULL,0,0,0 }
    };
@@ -89,51 +89,50 @@ struct Item *CONNECTIONLIST = NULL;
 /* Functions internal to cfservd.c                                 */
 /*******************************************************************/
 
-void CheckOptsAndInit (int argc,char **argv);
-void CheckVariables (void);
-void SummarizeParsing (void);
-void StartServer (int argc, char **argv);
-int OpenReceiverChannel (void);
-void Syntax (void);
-void PurgeOldConnections (struct Item **list,time_t now);
-void SpawnConnection (int sd_reply, char *ipaddr);
-void CheckFileChanges (int argc, char **argv, int sd);
-void *HandleConnection (struct cfd_connection *conn);
-int BusyWithConnection (struct cfd_connection *conn);
-void *ExitCleanly (int signum);
-int MatchClasses (struct cfd_connection *conn);
-void DoExec (struct cfd_connection *conn, char *sendbuffer, char *args);
-int GetCommand (char *str);
-int VerifyConnection (struct cfd_connection *conn, char *buf);
-void RefuseAccess (struct cfd_connection *conn, char *sendbuffer, int size, char *errormsg);
-int AccessControl (char *filename, struct cfd_connection *conn, int encrypt);
-int CheckStoreKey  (struct cfd_connection *conn, RSA *key);
-int StatFile (struct cfd_connection *conn, char *sendbuffer, char *filename);
-void CfGetFile (struct cfd_get_arg *args);
-void CompareLocalChecksum (struct cfd_connection *conn, char *sendbuffer, char *recvbuffer);
-int CfOpenDirectory (struct cfd_connection *conn, char *sendbuffer, char *dirname);
-int CfSecOpenDirectory (struct cfd_connection *conn, char *sendbuffer, char *dirname);
-void Terminate (int sd);
-void DeleteAuthList (struct Auth *ap);
-int AllowedUser (char *user);
-void ReplyNothing (struct cfd_connection *conn);
-struct cfd_connection *NewConn (int sd);
-void DeleteConn (struct cfd_connection *conn);
-time_t SecondsTillAuto (void);
-void SetAuto (int seconds);
-int cfscanf (char *in, int len1, int len2, char *out1, char *out2, char *out3);
-int AuthenticationDialogue (struct cfd_connection *conn,char *buffer, int buffersize);
-char *MapAddress (char *addr);
-int IsWildKnownHost (RSA *oldkey,RSA *newkey,char *addr,char *user);
-void AddToKeyDB (RSA *key,char *addr);
-int SafeOpen (char *filename);
-void SafeClose (int fd);
+void CheckOptsAndInit ARGLIST((int argc,char **argv));
+void CheckVariables ARGLIST((void));
+void SummarizeParsing ARGLIST((void));
+void StartServer ARGLIST((int argc, char **argv));
+int OpenReceiverChannel ARGLIST((void));
+void Syntax ARGLIST((void));
+void PurgeOldConnections ARGLIST((struct Item **list,time_t now));
+void SpawnConnection ARGLIST((int sd_reply, char *ipaddr));
+void CheckFileChanges ARGLIST((int argc, char **argv, int sd));
+void *HandleConnection ARGLIST((struct cfd_connection *conn));
+int BusyWithConnection ARGLIST((struct cfd_connection *conn));
+void *ExitCleanly ARGLIST((int signum));
+int MatchClasses ARGLIST((struct cfd_connection *conn));
+void DoExec ARGLIST((struct cfd_connection *conn, char *sendbuffer, char *args));
+int GetCommand ARGLIST((char *str));
+int VerifyConnection ARGLIST((struct cfd_connection *conn, char *buf));
+void RefuseAccess ARGLIST((struct cfd_connection *conn, char *sendbuffer, int size, char *errormsg));
+int AccessControl ARGLIST((char *filename, struct cfd_connection *conn, int encrypt));
+int CheckStoreKey  ARGLIST((struct cfd_connection *conn, RSA *key));
+int StatFile ARGLIST((struct cfd_connection *conn, char *sendbuffer, char *filename));
+void CfGetFile ARGLIST((struct cfd_get_arg *args));
+void CompareLocalChecksum ARGLIST((struct cfd_connection *conn, char *sendbuffer, char *recvbuffer));
+int CfOpenDirectory ARGLIST((struct cfd_connection *conn, char *sendbuffer, char *dirname));
+void Terminate ARGLIST((int sd));
+void DeleteAuthList ARGLIST((struct Auth *ap));
+int AllowedUser ARGLIST((char *user));
+void ReplyNothing ARGLIST((struct cfd_connection *conn));
+struct cfd_connection *NewConn ARGLIST((int sd));
+void DeleteConn ARGLIST((struct cfd_connection *conn));
+time_t SecondsTillAuto ARGLIST((void));
+void SetAuto ARGLIST((int seconds));
+int cfscanf ARGLIST((char *in, int len1, int len2, char *out1, char *out2, char *out3));
+int AuthenticationDialogue ARGLIST((struct cfd_connection *conn,char *buffer, int buffersize));
+char *MapAddress ARGLIST((char *addr));
+int IsWildKnownHost ARGLIST((RSA *oldkey,RSA *newkey,char *addr,char *user));
+void AddToKeyDB ARGLIST((RSA *key,char *addr));
+int SafeOpen ARGLIST((char *filename));
+void SafeClose ARGLIST((int fd));
 
 /*
  * HvB
 */
 
-unsigned find_inet_addr (char *host);
+unsigned find_inet_addr ARGLIST((char *host));
 
 /*******************************************************************/
 /* Level 0 : Main                                                  */
@@ -144,12 +143,9 @@ int main (int argc,char **argv)
 {
 CheckOptsAndInit(argc,argv);
 ParseInputFile(VINPUTFILE);
-
 /* We call CfOpenLog again so, if we configure SyslogFacility, 
    we open syslog again */
-closelog();
 CfOpenLog();
-
 CheckVariables();
 SummarizeParsing();
 
@@ -188,9 +184,6 @@ OUTPUT[0] = '\0';
 
 BINDINTERFACE[0] = '\0';
 
-CfenginePort();
-StrCfenginePort();
-
 SetSignals();
  
 ISCFENGINE = false;   /* Switch for the parser */
@@ -242,10 +235,10 @@ while ((c=getopt_long(argc,argv,"L:d:f:vmhpFV",CFDOPTIONS,&optindex)) != EOF)
          break;
 
       case 'L': Verbose("Setting LD_LIBRARY_PATH=%s\n",optarg);
-          snprintf(ld_library_path,CF_BUFSIZE-1,"LD_LIBRARY_PATH=%s",optarg);
-          putenv(ld_library_path);
-          break;
-          
+         snprintf(ld_library_path,CF_BUFSIZE-1,"LD_LIBRARY_PATH=%s",optarg);
+             putenv(ld_library_path);
+  break;
+   
       case 'm': /* No longer needed */
          break;
 
@@ -274,26 +267,12 @@ if ((CFSTARTTIME = time((time_t *)NULL)) == -1)
    {
    CfLog(cferror,"Couldn't read system clock\n","time");
    }
-
- /* XXX Initialize workdir for non privileged users */
-
- strcpy(CFWORKDIR,WORKDIR);
-
- if (getuid() > 0)
-    {
-    char *homedir;
-    if ((homedir = getenv("HOME")) != NULL)
-       {
-       strcpy(CFWORKDIR,homedir);
-       strcat(CFWORKDIR,"/.cfagent");
-       }
-    }
-
-snprintf(vbuff,CF_BUFSIZE,"%s/test",CFWORKDIR);
+ 
+snprintf(vbuff,CF_BUFSIZE,"%s/test",WORKDIR);
 
 MakeDirectoriesFor(vbuff,'y');
-strncpy(VLOGDIR,CFWORKDIR,CF_BUFSIZE-1);
-strncpy(VLOCKDIR,CFWORKDIR,CF_BUFSIZE-1);
+strncpy(VLOGDIR,WORKDIR,CF_BUFSIZE-1);
+strncpy(VLOCKDIR,WORKDIR,CF_BUFSIZE-1);
 
 VIFELAPSED = CF_EXEC_IFELAPSED;
 VEXPIREAFTER = CF_EXEC_EXPIREAFTER;
@@ -348,20 +327,19 @@ if (OptionIs(CONTEXTID,"LogAllConnections", true))
    LOGCONNS = true;
    }
 
-if (OptionIs(CONTEXTID,"LogEncryptedTransfers", true)) 
-   {
-   LOGENCRYPT = true;
-   }
-
 if (GetMacroValue(CONTEXTID,"ChecksumDatabase"))
    {
-   snprintf(ebuff,CF_BUFSIZE,"%s/%s",CFWORKDIR,CF_CHKDB);
-   /* CHECKSUMDB = strdup(ebuff);*/
-   CHECKSUMDB = NULL;
-   Verbose("Checksum database is no longer used in cfservd\n");
+   ExpandVarstring("$(ChecksumDatabase)",ebuff,NULL);
+
+   CHECKSUMDB = strdup(ebuff);
+
+   if (*CHECKSUMDB != '/')
+      {
+      FatalError("$(ChecksumDatabase) does not expand to an absolute filename\n");
+      }
    }
 
-memset(CFRUNCOMMAND,0,CF_BUFSIZE);
+ memset(CFRUNCOMMAND,0,CF_BUFSIZE);
  
 if (GetMacroValue(CONTEXTID,"cfrunCommand"))
    {
@@ -390,7 +368,7 @@ if (GetMacroValue(CONTEXTID,"MaxConnections"))
    
    MAXTRIES = CFD_MAXPROCESSES / 3;  /* How many attempted connections over max
             before we commit suicide? */
-   if ((CFD_MAXPROCESSES < 1) || (CFD_MAXPROCESSES > 10000))
+   if ((CFD_MAXPROCESSES < 1) || (CFD_MAXPROCESSES > 1000))
       {
       FatalError("cfservd MaxConnections with silly value");
       }
@@ -414,9 +392,7 @@ if (OptionIs(CONTEXTID,"ChecksumUpdates", false))
  
 i = 0;
 
-strncpy(ebuff,ToLowerStr(VDOMAIN),127);
-
-if (StrStr(VSYSNAME.nodename,ebuff))
+if (StrStr(VSYSNAME.nodename,ToLowerStr(VDOMAIN)))
    {
    strncpy(VFQNAME,VSYSNAME.nodename,CF_MAXVARSIZE-1);
    
@@ -465,42 +441,42 @@ if (DEBUG || D2 || D3)
       printf("Path: %s (encrypt=%d)\n",ptr->path,ptr->encrypt);
 
       for (ip = ptr->accesslist; ip != NULL; ip=ip->next)
-         {
-         printf("   Admit: %s root=",ip->name);
-         for (ipr = ptr->maproot; ipr !=NULL; ipr=ipr->next)
-            {
-            printf("%s,",ipr->name);
-            }
-         printf("\n");
-         }
+  {
+  printf("   Admit: %s root=",ip->name);
+  for (ipr = ptr->maproot; ipr !=NULL; ipr=ipr->next)
+     {
+     printf("%s,",ipr->name);
+     }
+  printf("\n");
+  }
       }
-   
+
    printf("ACCESS DENIAL ------------------------ :\n\n");
-   
+
    for (ptr = VDENY; ptr != NULL; ptr=ptr->next)
       {
       printf("Path: %s\n",ptr->path);
-      
+
       for (ip = ptr->accesslist; ip != NULL; ip=ip->next)
-         {
-         printf("   Deny: %s\n",ip->name);
-         }      
+  {
+  printf("   Deny: %s\n",ip->name);
+  }      
       }
    
    printf("Host IPs allowed connection access :\n\n");
-   
+
    for (ip = NONATTACKERLIST; ip != NULL; ip=ip->next)
       {
       printf("IP: %s\n",ip->name);
       }
-   
+
    printf("Host IPs denied connection access :\n\n");
-   
+
    for (ip = ATTACKERLIST; ip != NULL; ip=ip->next)
       {
       printf("IP: %s\n",ip->name);
       }
-   
+
    printf("Host IPs allowed multiple connection access :\n\n");
 
    for (ip = MULTICONNLIST; ip != NULL; ip=ip->next)
@@ -544,11 +520,9 @@ if (ERRORCOUNT > 0)
 void StartServer(int argc,char **argv)
 
 { char ipaddr[CF_MAXVARSIZE],intime[64];
-  int sd,sd_reply;
+  int sd,sd_reply,ageing;
   fd_set rset;
   time_t now;
-  struct timeval timeout;
-  int ret_val;
 
 #if defined(HAVE_GETADDRINFO) && !defined(DARWIN)
   int addrlen=sizeof(struct sockaddr_in6);
@@ -568,9 +542,6 @@ signal(SIGINT,(void*)ExitCleanly);
 signal(SIGTERM,(void*)ExitCleanly);
 signal(SIGHUP,SIG_IGN);
 signal(SIGPIPE,SIG_IGN);
-signal(SIGCHLD,SIG_IGN);
-signal(SIGUSR1,HandleSignal);
-signal(SIGUSR2,HandleSignal);
  
 if (listen(sd,queuesize) == -1)
    {
@@ -584,7 +555,6 @@ if ((!NO_FORK) && (fork() != 0))
    {
    snprintf(OUTPUT,CF_BUFSIZE*2,"cfservd starting %.24s\n",ctime(&CFDSTARTTIME));
    CfLog(cfinform,OUTPUT,"");
-   closelog();
    exit(0);
    }
 
@@ -592,8 +562,8 @@ if (!NO_FORK)
    {
    ActAsDaemon(sd);
    }
-
-WritePID("cfservd.pid");
+ 
+ageing = 0;
 
 /* Andrew Stribblehill <ads@debian.org> -- close sd on exec */ 
 fcntl(sd, F_SETFD, FD_CLOEXEC);
@@ -607,13 +577,8 @@ while (true)
    
    FD_ZERO(&rset);
    FD_SET(sd,&rset);
-   
-   timeout.tv_sec = 10;  /* Set a 10 second timeout for select */
-   timeout.tv_usec = 0;
-   
-   ret_val = select((sd+1),&rset,NULL,NULL,&timeout);
 
-   if (ret_val == -1)   /* Error received from call to select */
+   if (select((sd+1),&rset,NULL,NULL,NULL) == -1)
       {
       if (errno == EINTR)
          {
@@ -625,13 +590,15 @@ while (true)
          exit(1);
          }
       }
-   else if (!ret_val)   /* No data waiting, we must have timed out! */
-      {
-      continue;
-      }
    
    if ((sd_reply = accept(sd,(struct sockaddr *)&cin,&addrlen)) != -1)
       {
+      if (ageing++ > CFD_MAXPROCESSES*50) /* Insurance against stale db */
+         {                                /* estimate number of clients */
+         unlink(CHECKSUMDB);              /* arbitrary policy ..        */
+         ageing = 0;
+         }
+      
       memset(ipaddr,0,CF_MAXVARSIZE);
       snprintf(ipaddr,CF_MAXVARSIZE-1,"%s",sockaddr_ntop((struct sockaddr *)&cin));
       
@@ -696,6 +663,7 @@ while (true)
       return;
       }
 #endif
+
       
       SpawnConnection(sd_reply,ipaddr);
       }
@@ -750,7 +718,7 @@ return (addr.s_addr);
 
 int OpenReceiverChannel()
 
-{ int sd;
+{ int sd,port;
   int yes=1;
   char *ptr = NULL;
 
@@ -764,6 +732,8 @@ int OpenReceiverChannel()
 cflinger.l_onoff = 1;
 cflinger.l_linger = 60;
 
+port = CfenginePort();
+
 #if defined(HAVE_GETADDRINFO) && !defined(DARWIN)
   
 memset(&query,0,sizeof(struct addrinfo));
@@ -780,7 +750,7 @@ if (BINDINTERFACE[0] != '\0' )
   ptr = BINDINTERFACE;
   }
 
-if (getaddrinfo(ptr,STR_CFENGINEPORT,&query,&response) != 0)
+if (getaddrinfo(ptr,"5308",&query,&response) != 0)
    {
    CfLog(cferror,"DNS/service lookup failure","getaddrinfo");
    return -1;   
@@ -852,7 +822,7 @@ if (BINDINTERFACE[0] != '\0' )
    sin.sin_addr.s_addr = INADDR_ANY;
    }
 
-sin.sin_port = (unsigned short)SHORT_CFENGINEPORT;
+sin.sin_port = (unsigned short)(port); /*  Service returns network byte order */
 sin.sin_family = AF_INET; 
 
 if ((sd = socket(AF_INET,SOCK_STREAM,0)) == -1)
@@ -923,35 +893,35 @@ if (list == NULL)
 
 Debug("Purging Old Connections...\n");
 
-#if defined HAVE_PTHREAD_H && (defined HAVE_LIBPTHREAD || defined BUILDTIN_GCC_THREAD)
-if (pthread_mutex_lock(&MUTEX_COUNT) != 0)
-   {
-   CfLog(cferror,"pthread_mutex_lock failed","pthread_mutex_lock");
-   return;
-   }
-#endif
-
 for (ip = *list; ip != NULL; ip=ip->next)
    {
    sscanf(ip->classes,"%d",&then);
 
    if (now > then + 7200)
       {
+#if defined HAVE_PTHREAD_H && (defined HAVE_LIBPTHREAD || defined BUILDTIN_GCC_THREAD)
+      if (pthread_mutex_lock(&MUTEX_COUNT) != 0)
+         {
+         CfLog(cferror,"pthread_mutex_lock failed","pthread_mutex_lock");
+         return;
+         }
+#endif
+
       DeleteItem(list,ip);
 
+#if defined HAVE_PTHREAD_H && (defined HAVE_LIBPTHREAD || defined BUILDTIN_GCC_THREAD)
+      if (pthread_mutex_unlock(&MUTEX_COUNT) != 0)
+         {
+         CfLog(cferror,"pthread_mutex_unlock failed","pthread_mutex_unlock");
+         return;
+         }
+#endif
+
       snprintf(OUTPUT,CF_BUFSIZE*2,"Purging IP address %s from connection list\n",ip->name);
       CfLog(cfverbose,OUTPUT,"");
       }
    }
 
-#if defined HAVE_PTHREAD_H && (defined HAVE_LIBPTHREAD || defined BUILDTIN_GCC_THREAD)
-if (pthread_mutex_unlock(&MUTEX_COUNT) != 0)
-   {
-   CfLog(cferror,"pthread_mutex_unlock failed","pthread_mutex_unlock");
-   return;
-   }
-#endif
-
 Debug("Done purging\n");
 }
 
@@ -1024,7 +994,7 @@ else
    {
    if (!IsAbsoluteFileName(VINPUTFILE)) /* Don't prepend to absolute names */
       {
-      strncpy(filename,CFWORKDIR,CF_BUFSIZE-1);
+      strncpy(filename,WORKDIR,CF_BUFSIZE-1);
       AddSlash(filename);
       strncat(filename,"inputs/",CF_BUFSIZE-1-strlen(filename));
       }
@@ -1040,7 +1010,7 @@ if (stat(filename,&newstat) == -1)
    return;
    }
 
-Debug("Checking file updates on %s (%x/%x)\n",filename, newstat.st_mtime, CFDSTARTTIME);
+Debug("Checking file updates on %s (%x/%x)\n",filename, newstat.st_ctime, CFDSTARTTIME);
 
 if (CFDSTARTTIME < newstat.st_mtime)
    {
@@ -1052,29 +1022,14 @@ if (CFDSTARTTIME < newstat.st_mtime)
    DeleteItemList(VHEAP);
    DeleteItemList(VNEGHEAP);
    DeleteItemList(TRUSTKEYLIST);
-   DeleteItemList(VIMPORT);
-   DeleteItemList(SKIPVERIFY);
-   DeleteItemList(DHCPLIST);
-   DeleteItemList(ATTACKERLIST);
-   DeleteItemList(NONATTACKERLIST);
-   DeleteItemList(MULTICONNLIST);
    DeleteAuthList(VADMIT);
    DeleteAuthList(VDENY);
-
    strcpy(VDOMAIN,"undefined.domain");
 
    VADMIT = VADMITTOP = NULL;
    VDENY  = VDENYTOP  = NULL;
    VHEAP  = VNEGHEAP  = NULL;
-   VIMPORT = NULL;
    TRUSTKEYLIST = NULL;
-   SKIPVERIFY = NULL;
-   DHCPLIST = NULL;
-   ATTACKERLIST = NULL;
-   NONATTACKERLIST = NULL;
-   MULTICONNLIST = NULL;
-
-   BlankHashTable("server");
 
    AddClassToHeap("any");
    GetNameInfo();
@@ -1192,13 +1147,13 @@ int BusyWithConnection(struct cfd_connection *conn)
   /* and extract the information from the message */
 
 { time_t tloc, trem = 0;
-  char recvbuffer[CF_BUFSIZE+CF_BUFEXT], sendbuffer[CF_BUFSIZE],check[CF_BUFSIZE];  
+  char recvbuffer[CF_BUFSIZE+128], sendbuffer[CF_BUFSIZE],check[CF_BUFSIZE];  
   char filename[CF_BUFSIZE],buffer[CF_BUFSIZE],args[CF_BUFSIZE],out[CF_BUFSIZE];
   long time_no_see = 0;
   int len=0, drift, plainlen, received;
   struct cfd_get_arg get_args;
 
-memset(recvbuffer,0,CF_BUFSIZE+CF_BUFEXT);
+memset(recvbuffer,0,CF_BUFSIZE+128);
 memset(&get_args,0,sizeof(get_args));
 
 if ((received = ReceiveTransaction(conn->sd_reply,recvbuffer,NULL)) == -1)
@@ -1253,17 +1208,6 @@ switch (GetCommand(recvbuffer))
        DoExec(conn,sendbuffer,args);
        Terminate(conn->sd_reply);
        return false;
-
-   case cfd_version:
-
-       if (! conn->id_verified)
-          {
-          RefuseAccess(conn,sendbuffer,0,recvbuffer);
-          }
-
-       snprintf(conn->output,CF_BUFSIZE,"OK: %s",VERSION);
-       SendTransaction(conn->sd_reply,conn->output,0,CF_DONE);
-       return conn->id_verified;
        
    case cfd_cauth:
 
@@ -1387,52 +1331,6 @@ switch (GetCommand(recvbuffer))
        
        CfGetFile(&get_args);
        return true;
-
-   case cfd_sopendir:
-
-       memset(buffer,0,CF_BUFSIZE);
-       sscanf(recvbuffer,"SOPENDIR %d",&len);
-
-       if (received != len+CF_PROTO_OFFSET)
-          {
-          Debug("Protocol error: %d\n",len);
-          RefuseAccess(conn,sendbuffer,0,recvbuffer);
-          return false;
-          }
-
-       if (conn->session_key == NULL)
-          {
-          RefuseAccess(conn,sendbuffer,0,recvbuffer);
-          return false;
-          }
-
-       memcpy(out,recvbuffer+CF_PROTO_OFFSET,len);
-       
-       plainlen = DecryptString(out,recvbuffer,conn->session_key,len);
-
-       if (strncmp(recvbuffer,"OPENDIR",7) !=0)
-          {
-          RefuseAccess(conn,sendbuffer,0,recvbuffer);
-          return true;
-          }
-
-       memset(filename,0,CF_BUFSIZE);
-       sscanf(recvbuffer,"OPENDIR %[^\n]",filename);
-       
-       if (! conn->id_verified)
-          {
-          RefuseAccess(conn,sendbuffer,0,recvbuffer);
-          return false;
-          }
-       
-       if (!AccessControl(filename,conn,true)) /* opendir don't care about privacy */
-          {
-          RefuseAccess(conn,sendbuffer,0,recvbuffer);
-          return false;   
-          }       
-       
-       CfSecOpenDirectory(conn,sendbuffer,filename);
-       return true;
        
    case cfd_opendir:
 
@@ -1459,31 +1357,31 @@ switch (GetCommand(recvbuffer))
        
        memset(buffer,0,CF_BUFSIZE);
        sscanf(recvbuffer,"SSYNCH %d",&len);
-
+       
        if (received != len+CF_PROTO_OFFSET)
           {
           Debug("Protocol error: %d\n",len);
           RefuseAccess(conn,sendbuffer,0,recvbuffer);
           return false;
           }
-
+       
        if (conn->session_key == NULL)
           {
           RefuseAccess(conn,sendbuffer,0,recvbuffer);
           return false;
           }
-
+       
        memcpy(out,recvbuffer+CF_PROTO_OFFSET,len);
        
        plainlen = DecryptString(out,recvbuffer,conn->session_key,len);
-
+       
        if (strncmp(recvbuffer,"SYNCH",5) !=0)
           {
           RefuseAccess(conn,sendbuffer,0,recvbuffer);
           return true;
           }
        /* roll through, no break */
-
+       
    case cfd_synch:
        if (! conn->id_verified)
           {
@@ -1592,7 +1490,6 @@ for (i = 0; i < MAXTHREAD ; i++)
 #endif 
  
 HandleSignal(signum);
-unlink(PIDFILE);
 return NULL;
 }
 
@@ -1666,7 +1563,7 @@ while (true && (count < 10))  /* arbitrary check to avoid infinite loop, DoS att
 void DoExec(struct cfd_connection *conn,char *sendbuffer,char *args)
 
 { char ebuff[CF_EXPANDSIZE], line[CF_BUFSIZE], *sp;
-  int print = false,i, opt=false;
+  int print = false,i;
   FILE *pp;
 
 if ((CFSTARTTIME = time((time_t *)NULL)) == -1)
@@ -1704,36 +1601,6 @@ for (sp = args; *sp != '\0'; sp++) /* Blank out -K -f */
          }
       }
    }
-
-for (sp = args; *sp != '\0'; sp++) /* Blank out -f */
-   { 
-
-   if (strncmp(sp,"-D",2) == 0)
-      {
-      opt = false;
-      sp+=2;
-      }
-
-   if (strncmp(sp,"--define",8) == 0)
-      {
-      opt = false;
-      sp+=8;
-      }
-
-   switch (*sp)
-      {
-      case '-': opt = true;
-          break;
-      case ' ': opt = false;
-          break;
-      case 'f': if (opt)
-                   {
-                   *sp = 'q'; /* Replace with non-empty char which is defined anyway */
-                   }
-          break;
-      }
-   
-   }
     
 ExpandVarstring("$(cfrunCommand) --no-splay --inform",ebuff,"");
  
@@ -1749,7 +1616,7 @@ else
    if ((args != NULL) & (strlen(args) > 0))
       {
       strcat(ebuff," ");
-      strncat(ebuff,args,CF_BUFSIZE-strlen(ebuff));
+      strcat(ebuff,args);
 
       snprintf(sendbuffer,CF_BUFSIZE,"cfservd Executing %s\n",ebuff);
       SendTransaction(conn->sd_reply,sendbuffer,0,CF_DONE);
@@ -1895,19 +1762,6 @@ if (strcmp(ip_assert,MapAddress(conn->ipaddr)) != 0)
    return false;
    }
 
-if (strlen(dns_assert) == 0)
-   {
-   Verbose("DNS asserted name was empty - untrustworthy connection\n");
-   return false;
-   }
-
-if (strcmp(dns_assert,"skipident") == 0)
-   {
-   Verbose("DNS asserted name was withheld before key exchange - untrustworthy connection\n");
-   return false;   
-   }
-
-
 Verbose("Socket caller address appears honest (%s matches %s)\n",ip_assert,MapAddress(conn->ipaddr));
  
 snprintf(conn->output,CF_BUFSIZE,"Socket originates from %s=%s\n",ip_assert,dns_assert);
@@ -2092,54 +1946,40 @@ int AccessControl(char *filename,struct cfd_connection *conn,int encrypt)
 
 { struct Auth *ap;
   int access = false;
-  char realname[CF_BUFSIZE],path[CF_BUFSIZE],lastnode[CF_BUFSIZE],*sp;
+  char realname[CF_BUFSIZE];
   struct stat statbuf;
 
 Debug("AccessControl(%s)\n",filename);
 memset(realname,0,CF_BUFSIZE);
 
-/* Separate path first, else this breaks for lastnode = symlink */
-
-for (sp = filename; *sp != '\0'; sp++) /*fix filename to not have windows slashes */
+if (lstat(filename,&statbuf) == -1)
    {
-   if (*sp == FILE_SEPARATOR)
-      {
-      *sp = '/';
-      }
-   }
-
-strncpy(path,filename,CF_BUFSIZE-1);
-strncpy(lastnode,ReadLastNode(filename),CF_BUFSIZE-1);
-ChopLastNode(path);
-
-/* Eliminate links from path */
-
-#ifdef HAVE_REALPATH
-if (realpath(path,realname) == NULL)
-   {
-   snprintf(conn->output,CF_BUFSIZE*2,"Couldn't resolve filename %s from host %s\n",filename,conn->hostname);
+   snprintf(conn->output,CF_BUFSIZE*2,"Couldn't stat filename %s from host %s\n",filename,conn->hostname);
    CfLog(cfverbose,conn->output,"lstat");
    CfLog(cflogonly,conn->output,"lstat");   
    return false;
    }
-#else
-CompressPath(realname,path); /* in links.c */
-#endif
 
-/* Rejoin the last node and stat the real thing */
-
-AddSlash(realname);
-strcat(realname,lastnode);
-
-if (lstat(realname,&statbuf) == -1)
+if (S_ISLNK(statbuf.st_mode)) 
    {
-   snprintf(conn->output,CF_BUFSIZE*2,"Couldn't stat filename %s (i.e. %s) from host %s\n",filename,realname,conn->hostname);
-   CfLog(cfverbose,conn->output,"lstat");
-   /*CfLog(cflogonly,conn->output,"lstat");   */
-   return false;
+   strncpy(realname,filename,CF_BUFSIZE);
    }
-
-Debug("AccessControl, match(%s,%s) encrypt request=%d\n",realname,conn->hostname,encrypt);
+ else
+    {
+#ifdef HAVE_REALPATH
+    if (realpath(filename,realname) == NULL)
+       {
+       snprintf(conn->output,CF_BUFSIZE*2,"Couldn't resolve filename %s from host %s\n",filename,conn->hostname);
+       CfLog(cfverbose,conn->output,"lstat");
+       CfLog(cflogonly,conn->output,"lstat");   
+       return false;
+       }
+#else
+    CompressPath(realname,filename); /* in links.c */
+#endif
+    }
+ 
+Debug("AccessControl(%s,%s) encrypt request=%d\n",realname,conn->hostname,encrypt);
  
 if (VADMIT == NULL)
    {
@@ -2166,7 +2006,7 @@ for (ap = VADMIT; ap != NULL; ap=ap->next)
    
    if (res)
       {
-      Debug("Found a matching rule in access list (%s in %s)\n",realname,ap->path);
+      Debug("Found a matching rule in access list (%s,%s)\n",realname,ap->path);
       if (stat(ap->path,&statbuf) == -1)
          {
          snprintf(OUTPUT,CF_BUFSIZE,"Warning cannot stat file object %s in admit/grant, or access list refers to dangling link\n",ap->path);
@@ -2228,20 +2068,15 @@ for (ap = VADMIT; ap != NULL; ap=ap->next)
     {
     snprintf(conn->output,CF_BUFSIZE*2,"Host %s granted access to %s\n",conn->hostname,realname);
     CfLog(cfverbose,conn->output,"");
-    
-    if (encrypt && LOGENCRYPT)
-       {
-       /* Log files that were marked as requiring encryption */
-       CfLog(cfloginform,conn->output,"");
-       }
     }
  else
     {
     snprintf(conn->output,CF_BUFSIZE*2,"Host %s denied access to %s\n",conn->hostname,realname);
     CfLog(cfverbose,conn->output,"");
-    CfLog(cfloginform,conn->output,"");
+    CfLog(cflogonly,conn->output,"");
     }
  
+ 
  if (!conn->rsa_auth)
     {
     CfLog(cfverbose,"Cannot map root access without RSA authentication","");
@@ -2259,9 +2094,8 @@ int AuthenticationDialogue(struct cfd_connection *conn,char *recvbuffer, int rec
 { char in[CF_BUFSIZE],*out, *decrypted_nonce;
   BIGNUM *counter_challenge = NULL;
   unsigned char digest[EVP_MAX_MD_SIZE+1];
-  unsigned int crypt_len, nonce_len = 0,encrypted_len = 0;
+  unsigned int crypt_len, nonce_len = 0,len = 0, encrypted_len = 0, keylen;
   char sauth[10], iscrypt ='n';
-  int len = 0,keylen;
   unsigned long err;
   RSA *newkey;
 
@@ -2468,7 +2302,10 @@ counter_challenge = BN_new();
 BN_rand(counter_challenge,256,0,0);
 nonce_len = BN_bn2mpi(counter_challenge,in);
 ChecksumString(in,nonce_len,digest,'m');
-encrypted_len = RSA_size(newkey);         /* encryption buffer is always the same size as n */ 
+ 
+/* encrypted_len = BN_num_bytes(newkey->n);  encryption buffer is always the same size as n */
+
+encrypted_len = RSA_size(newkey); /* encryption buffer is always the same size as n */ 
 
  
 #if defined HAVE_PTHREAD_H && (defined HAVE_LIBPTHREAD || defined BUILDTIN_GCC_THREAD)
@@ -2526,9 +2363,6 @@ memset(in,0,CF_BUFSIZE);
 
 if (ReceiveTransaction(conn->sd_reply,in,NULL) == -1)
    {
-   BN_free(counter_challenge);
-   free(out);
-   RSA_free(newkey);   
    return false;
    }
  
@@ -2557,31 +2391,19 @@ else
 /* Receive random session key, blowfish style ... */ 
 
 /* proposition C5 */
-
 memset(in,0,CF_BUFSIZE);
 
 if ((keylen = ReceiveTransaction(conn->sd_reply,in,NULL)) == -1)
    {
-   BN_free(counter_challenge);
-   free(out);
-   RSA_free(newkey); 
    return false;
    }
 
 if (keylen > CF_BUFSIZE/2)
    {
-   BN_free(counter_challenge);
-   free(out);
-   RSA_free(newkey); 
    snprintf(conn->output,CF_BUFSIZE,"Session key length received from %s is too long",conn->ipaddr);
    CfLog(cfinform,conn->output,"");
    return false;
    }
-else
-   {
-   Debug("Got Blowfish size %d\n",keylen);
-   DebugBinOut(in,keylen);
-   }
 
 #if defined HAVE_PTHREAD_H && (defined HAVE_LIBPTHREAD || defined BUILDTIN_GCC_THREAD)
 if (pthread_mutex_lock(&MUTEX_SYSCALL) != 0)
@@ -2590,56 +2412,27 @@ if (pthread_mutex_lock(&MUTEX_SYSCALL) != 0)
    }
 #endif
  
-conn->session_key = malloc(CF_BLOWFISHSIZE); 
+conn->session_key = malloc(keylen);
+
+#if defined HAVE_PTHREAD_H && (defined HAVE_LIBPTHREAD || defined BUILDTIN_GCC_THREAD)
+if (pthread_mutex_unlock(&MUTEX_SYSCALL) != 0)
+   {
+   CfLog(cferror,"pthread_mutex_unlock failed","lock");
+   }
+#endif
 
 if (conn->session_key == NULL)
    {
-   BN_free(counter_challenge);
-   free(out);
-   RSA_free(newkey); 
    return false;
    }
 
-if (keylen == CF_BLOWFISHSIZE) /* Old, non-encrypted */
-   {
-   memcpy(conn->session_key,in,CF_BLOWFISHSIZE);
-   }
-else /* New encrypted */
-   {
-   if (RSA_private_decrypt(keylen,in,out,PRIVKEY,RSA_PKCS1_PADDING) <= 0)
-      {
-#if defined HAVE_PTHREAD_H && (defined HAVE_LIBPTHREAD || defined BUILDTIN_GCC_THREAD)
-      if (pthread_mutex_unlock(&MUTEX_SYSCALL) != 0)
-         {
-         CfLog(cferror,"pthread_mutex_unlock failed","lock");
-         }
-#endif
-      
-      err = ERR_get_error();
-      
-      snprintf(conn->output,CF_BUFSIZE,"Private decrypt failed = %s\n",ERR_reason_error_string(err));
-      CfLog(cferror,conn->output,"");
-      return false;
-      }
-   
-   memcpy(conn->session_key,out,CF_BLOWFISHSIZE);
-   }
-
-#if defined HAVE_PTHREAD_H && (defined HAVE_LIBPTHREAD || defined BUILDTIN_GCC_THREAD)
-   if (pthread_mutex_unlock(&MUTEX_SYSCALL) != 0)
-      {
-      CfLog(cferror,"pthread_mutex_unlock failed","lock");
-      }
-#endif
-
+memcpy(conn->session_key,in,keylen);
 Debug("Got a session key...\n"); 
-DebugBinOut(conn->session_key,16);
-
+ 
 BN_free(counter_challenge);
 free(out);
 RSA_free(newkey); 
 conn->rsa_auth = true;
-
 return true; 
 }
 
@@ -2653,11 +2446,10 @@ int StatFile(struct cfd_connection *conn,char *sendbuffer,char *filename)
 /* plain text and interpret them on the other side. */
 
 { struct cfstat cfst;
- struct stat statbuf,statlinkbuf;
+  struct stat statbuf;
   char linkbuf[CF_BUFSIZE];
-  int islink = false;
 
-Debug("StatFile(%s)\n",filename);
+  Debug("StatFile(%s)\n",filename);
 
 memset(&cfst,0,sizeof(struct cfstat));
   
@@ -2685,7 +2477,6 @@ memset(linkbuf,0,CF_BUFSIZE);
 
 if (S_ISLNK(statbuf.st_mode))
    {
-   islink = true;
    cfst.cf_type = cf_link;                   /* pointless - overwritten */
    cfst.cf_lmode = statbuf.st_mode & 07777;
    cfst.cf_nlink = statbuf.st_nlink;
@@ -2703,7 +2494,7 @@ if (S_ISLNK(statbuf.st_mode))
    cfst.cf_readlink = linkbuf;
    }
 
-if (!islink && (stat(filename,&statbuf) == -1))
+if (stat(filename,&statbuf) == -1)
    {
    snprintf(sendbuffer,CF_BUFSIZE,"BAD: unable to stat file %s\n",filename);
    CfLog(cfverbose,conn->output,"stat");
@@ -2711,13 +2502,6 @@ if (!islink && (stat(filename,&statbuf) == -1))
    return -1;
    }
 
-Debug("Getting size of link deref %s\n",linkbuf);
-
-if (islink && (stat(filename,&statlinkbuf) != -1)) /* linktype=copy used by agent */
-   {
-   statbuf.st_size = statlinkbuf.st_size;
-   }
-
 if (S_ISDIR(statbuf.st_mode))
    {
    cfst.cf_type = cf_dir;
@@ -2798,7 +2582,7 @@ snprintf(sendbuffer,CF_BUFSIZE,"OK: %d %d %d %d %d %ld %d %d %d %d %d %d %d",
 
 SendTransaction(conn->sd_reply,sendbuffer,0,CF_DONE);
 
-memset(sendbuffer,0,CF_BUFSIZE);
+ memset(sendbuffer,0,CF_BUFSIZE);
 
 if (cfst.cf_readlink != NULL)
    {
@@ -2857,7 +2641,7 @@ if (uid != 0 && !args->connect->maproot) /* should remote root be local root */
       }
    }
  
- if (args->buf_size < SMALL_BLOCK_BUF_SIZE)
+ if (args->buf_size < 512)
     {
     snprintf(args->connect->output,CF_BUFSIZE,"blocksize for %s was only %d\n",filename,args->buf_size);
     CfLog(cferror,args->connect->output,"");
@@ -2995,8 +2779,6 @@ void CompareLocalChecksum(struct cfd_connection *conn,char *sendbuffer,char *rec
   char *sp;
   int i;
 
-/* TODO - when safe change this to sha2 */
-  
 sscanf(recvbuffer,"MD5 %[^\n]",filename);
 
 sp = recvbuffer + strlen(recvbuffer) + CF_SMALL_OFFSET;
@@ -3074,61 +2856,6 @@ closedir(dirh);
 return 0;
 }
 
-/**************************************************************/
-
-int CfSecOpenDirectory(struct cfd_connection *conn,char *sendbuffer,char *dirname)
-
-{ DIR *dirh;
-  struct dirent *dirp;
-  int offset,cipherlen;
-  char out[CF_BUFSIZE];
-
-Debug("CfSecOpenDirectory(%s)\n",dirname);
-  
-if (*dirname != '/')
-   {
-   sprintf(sendbuffer,"BAD: request to access a non-absolute filename\n");
-   SendTransaction(conn->sd_reply,sendbuffer,0,CF_DONE);
-   return -1;
-   }
-
-if ((dirh = opendir(dirname)) == NULL)
-   {
-   Debug("cfengine, couldn't open dir %s\n",dirname);
-   snprintf(sendbuffer,CF_BUFSIZE,"BAD: cfengine, couldn't open dir %s\n",dirname);
-   SendTransaction(conn->sd_reply,sendbuffer,0,CF_DONE);
-   return -1;
-   }
-
-/* Pack names for transmission */
-
-memset(sendbuffer,0,CF_BUFSIZE);
-
-offset = 0;
-
-for (dirp = readdir(dirh); dirp != NULL; dirp = readdir(dirh))
-   {
-   if (strlen(dirp->d_name)+1+offset >= CF_BUFSIZE - CF_MAXLINKSIZE)
-      {
-      cipherlen = EncryptString(sendbuffer,out,CONN->session_key,offset+1);
-      SendTransaction(conn->sd_reply,out,cipherlen,CF_MORE);
-      offset = 0;
-      memset(sendbuffer,0,CF_BUFSIZE);
-      memset(out,0,CF_BUFSIZE);
-      }
-
-   strncpy(sendbuffer+offset,dirp->d_name,CF_MAXLINKSIZE);
-   offset += strlen(dirp->d_name) + 1;     /* + zero byte separator */
-   }
- 
-strcpy(sendbuffer+offset,CFD_TERMINATOR);
-cipherlen = EncryptString(sendbuffer,out,conn->session_key,offset+2+strlen(CFD_TERMINATOR));
-SendTransaction(conn->sd_reply,out,cipherlen,CF_DONE);
-Debug("END CfSecOpenDirectory(%s)\n",dirname);
-closedir(dirh);
-return 0;
-}
-
 /***************************************************************/
 
 void Terminate(int sd)
@@ -3199,7 +2926,7 @@ else
    }
  
 snprintf(sendbuffer,CF_BUFSIZE,"%s",CF_FAILEDSTR);
-CfLog(cfinform,"Unspecified refusal by server\n","");
+CfLog(cfinform,"Host authorization/authentication failed or access denied\n","");
 SendTransaction(conn->sd_reply,sendbuffer,size,CF_DONE);
 snprintf(sendbuffer,CF_BUFSIZE,"From (host=%s,user=%s,ip=%s)",hostname,username,ipaddr);
 CfLog(cfinform,sendbuffer,"");
@@ -3207,14 +2934,7 @@ CfLog(cfinform,sendbuffer,"");
 if (strlen(errmesg) > 0)
    {
    snprintf(OUTPUT,CF_BUFSIZE,"ID from connecting host: (%s)",errmesg);
-   if (LOGCONNS)
-      {
-      CfLog(cfloginform,OUTPUT,"");
-      }
-   else
-      {
-      CfLog(cfverbose,OUTPUT,"");
-      }
+   CfLog(cflogonly,OUTPUT,"");
    }
 }
 
@@ -3308,45 +3028,22 @@ if (savedkey = HavePublicKey(keyname))
    
    return true;
    }
-else if ((DHCPLIST != NULL) && IsFuzzyItemIn(DHCPLIST,MapAddress(conn->ipaddr)))
-   {
-   /* If the host is expected to have a dynamic address, check for the key */
-   
-   if ((DHCPLIST != NULL) && IsFuzzyItemIn(DHCPLIST,MapAddress(conn->ipaddr)))
-      {
-      int result;
-      result = IsWildKnownHost(savedkey,key,MapAddress(conn->ipaddr),conn->username);
-      RSA_free(savedkey);
-      if (result)
-         {
-         SendTransaction(conn->sd_reply,"OK: key accepted",0,CF_DONE);
-         }
-      else
-         {
-         SendTransaction(conn->sd_reply,"BAD: keys did not match",0,CF_DONE);
-         }
-      return result;
-      }
-   }
-
-/* Finally, if we're still here, we should consider trusting a new key ... */
-
-if ((TRUSTKEYLIST != NULL) && IsFuzzyItemIn(TRUSTKEYLIST,MapAddress(conn->ipaddr)))
-   {
-   Verbose("Host %s/%s was found in the list of hosts to trust\n",conn->hostname,conn->ipaddr);
-   conn->trust = true;
-   /* conn->maproot = false; ?? */
-   SendTransaction(conn->sd_reply,"OK: unknown key was accepted on trust",0,CF_DONE);
-   SavePublicKey(keyname,key);
-   AddToKeyDB(key,MapAddress(conn->ipaddr));
-   return true;
-   }
-else
-   {
-   Verbose("No previous key found, and unable to accept this one on trust\n");
-   SendTransaction(conn->sd_reply,"BAD: key could not be accepted on trust",0,CF_DONE);
-   return false; 
-   }
+ else if ((TRUSTKEYLIST != NULL) && IsFuzzyItemIn(TRUSTKEYLIST,MapAddress(conn->ipaddr)))
+    {
+    Verbose("Host %s/%s was found in the list of hosts to trust\n",conn->hostname,conn->ipaddr);
+    conn->trust = true;
+    /* conn->maproot = false; ?? */
+    SendTransaction(conn->sd_reply,"OK: key was accepted on trust",0,CF_DONE);
+    SavePublicKey(keyname,key);
+    AddToKeyDB(key,MapAddress(conn->ipaddr));
+    return true;
+    }
+ else
+    {
+    Verbose("No previous key found, and unable to accept this one on trust\n");
+    SendTransaction(conn->sd_reply,"BAD: key could not be accepted on trust",0,CF_DONE);
+    return false; 
+    }
 }
 
 /***************************************************************/
@@ -3364,9 +3061,9 @@ int IsWildKnownHost(RSA *oldkey,RSA *newkey,char *mipaddr,char *username)
   char keydb[CF_MAXVARSIZE];
 
 snprintf(keyname,CF_MAXVARSIZE,"%s-%s",username,mipaddr);
-snprintf(keydb,CF_MAXVARSIZE,"%s/ppkeys/dynamic",CFWORKDIR); 
+snprintf(keydb,CF_MAXVARSIZE,"%s/ppkeys/dynamic",WORKDIR); 
 
-Debug("The key does not match a known key but the host could have a dynamic IP...\n"); 
+Debug("The key does not match the known, key but the host has dynamic IP...\n"); 
  
 if ((TRUSTKEYLIST != NULL) && IsFuzzyItemIn(TRUSTKEYLIST,mipaddr))
    {
@@ -3375,14 +3072,14 @@ if ((TRUSTKEYLIST != NULL) && IsFuzzyItemIn(TRUSTKEYLIST,mipaddr))
    }
 else
    {
-   Debug("Will not accept this key, unless we have seen it before\n");
+   Debug("Will not accept the new key, unless we have seen it before\n");
    }
 
 /* If the host is allowed to have a variable IP range, we can accept
    the new key on trust for the given IP address provided we have seen
    the key before.  Check for it in a database .. */
 
-Debug("Checking to see if we have seen the key before..\n"); 
+Debug("Checking to see if we have seen the new key before..\n"); 
   
 if ((errno = db_create(&dbp,NULL,0)) != 0)
    {
@@ -3428,12 +3125,10 @@ if ((errno = dbp->get(dbp,NULL,&key,&value,0)) != 0)
          {
          dbp->err(dbp,errno,NULL);
          }
-
-      DeletePublicKey(keyname);
       }
    else
       {
-      Debug("Found no grounds for trusting this new from %s\n",mipaddr);
+      Debug("Found no grounds for trusting this new key from %s\n",mipaddr);
       }
    }
 else
@@ -3464,7 +3159,7 @@ void AddToKeyDB(RSA *newkey,char *mipaddr)
   DB *dbp;
   char keydb[CF_MAXVARSIZE];
 
-snprintf(keydb,CF_MAXVARSIZE,"%s/ppkeys/dynamic",CFWORKDIR); 
+snprintf(keydb,CF_MAXVARSIZE,"%s/ppkeys/dynamic",WORKDIR); 
   
 if ((DHCPLIST != NULL) && IsFuzzyItemIn(DHCPLIST,mipaddr))
    {
@@ -3560,11 +3255,6 @@ void DeleteConn(struct cfd_connection *conn) /* destruct */
 Debug("***Closing socket %d from %s\n",conn->sd_reply,conn->ipaddr);
 
 close(conn->sd_reply);
-
-if (conn->session_key != NULL)
-   {
-   free(conn->session_key);
-   }
  
 if (conn->ipaddr != NULL)
    {
@@ -3696,10 +3386,6 @@ struct Method *IsDefinedMethod(char *name,char *s)
 {
 return NULL; 
 }
-
-void CheckForMethod()
-{
-}
 /* EOF */
 
 
