@@ -49,11 +49,11 @@ snprintf(VBUFF,CF_BUFSIZE,"%s/randseed",VLOGDIR);
 
  if (stat(VBUFF,&statbuf) == -1)
     {
-    snprintf(AVDB,CF_MAXVARSIZE-1,"%s/state/%s",CFWORKDIR,CF_AVDB_FILE);
+    snprintf(AVDB,CF_BUFSIZE,"%s/%s",WORKDIR,CF_AVDB_FILE);
     }
  else
     {
-    strncpy(AVDB,VBUFF,CF_MAXVARSIZE-1);
+    strcpy(AVDB,VBUFF);
     }
 
 Verbose("Looking for a source of entropy in %s\n",AVDB);
@@ -138,7 +138,7 @@ RSA *HavePublicKey(char *name)
   FILE *fp;
   RSA *newkey = NULL;
 
-Debug("HavePublickey(%s)\n",name);
+Debug("Havekey(%s)\n",name);
   
 if (!IsPrivileged())
    {
@@ -153,7 +153,7 @@ if (!IsPrivileged())
    }
 else
    {
-   snprintf(filename,CF_BUFSIZE,"%s/ppkeys/%s.pub",CFWORKDIR,name);
+   snprintf(filename,CF_BUFSIZE,"%s/ppkeys/%s.pub",WORKDIR,name);
    }
  
 if (stat(filename,&statbuf) == -1)
@@ -215,7 +215,7 @@ if (!IsPrivileged())
    }
 else
    {
-   snprintf(filename,CF_BUFSIZE,"%s/ppkeys/%s.pub",CFWORKDIR,name);
+   snprintf(filename,CF_BUFSIZE,"%s/ppkeys/%s.pub",WORKDIR,name);
    }
 
 if (stat(filename,&statbuf) != -1)
@@ -262,7 +262,7 @@ if (!IsPrivileged())
    }
 else
    {
-   snprintf(filename,CF_BUFSIZE,"%s/ppkeys/%s.pub",CFWORKDIR,name);
+   snprintf(filename,CF_BUFSIZE,"%s/ppkeys/%s.pub",WORKDIR,name);
    }
 
 unlink(filename);
@@ -276,7 +276,7 @@ void MD5Random(unsigned char digest[EVP_MAX_MD_SIZE+1])
       MD5. We can use this as a seed for pseudo random generator */
 
 { unsigned char buffer[CF_BUFSIZE];
-  char pscomm[CF_BUFSIZE];
+  char pscomm[CF_MAXLINKSIZE];
   char uninitbuffer[100];
   int md_len;
   const EVP_MD *md;
@@ -326,7 +326,7 @@ void GenerateRandomSessionKey()
 /* Hardcode blowfish for now - it's fast */ 
 
 bp = BN_new(); 
-BN_rand(bp,CF_BLOWFISHSIZE,0,0);
+BN_rand(bp,16,0,0);
 CONN->session_key = (unsigned char *)bp;
 }
 
@@ -383,37 +383,4 @@ EVP_CIPHER_CTX_cleanup(&ctx);
 return plainlen; 
 }
 
-/*********************************************************************/
 
-void DebugBinOut(char *buffer,int len)
-
-{ char *sp;
-  int check = 0;
-
- Debug("BinaryBuffer(%d)[",len);
- 
-for (sp = buffer; (sp < buffer+len); sp++)
-   {
-   check++;
-   Debug("%x",*sp);
-   }
- 
-Debug("] = %d\n",check); 
-}
-
-
-/*********************************************************************/
-
-char *KeyPrint(RSA *pubkey)
-
-{ unsigned char digest[EVP_MAX_MD_SIZE+1];
- int i;
-
-for (i = 0; i < EVP_MAX_MD_SIZE+1; i++)
-   {
-   digest[i] = 0;
-   }
- 
-ChecksumString((char *)pubkey,sizeof(BIGNUM)-4,digest,'m');
-return ChecksumPrint('m',digest);
-}
