@@ -1,4 +1,3 @@
-
 /* cfengine for GNU
  
         Copyright (C) 1995
@@ -38,6 +37,219 @@
 /* EDIT Data structure routines                                     */
 /********************************************************************/
 
+int DoRecursiveEditFiles(char *name,int level,struct Edit *ptr,struct stat *sb)
+
+{ DIR *dirh;
+  struct dirent *dirp;
+  char pcwd[CF_BUFSIZE];
+  struct stat statbuf;
+  int goback;
+
+if (level == -1)
+   {
+   return false;
+   }
+
+Debug("RecursiveEditFiles(%s)\n",name);
+
+if (!DirPush(name,sb))
+   {
+   return false;
+   }
+ 
+if ((dirh = opendir(".")) == NULL)
+   {
+   return true;
+   }
+
+for (dirp = readdir(dirh); dirp != NULL; dirp = readdir(dirh))
+   {
+   if (!SensibleFile(dirp->d_name,name,NULL))
+      {
+      continue;
+      }
+
+   if (IgnoreFile(name,dirp->d_name,ptr->ignores))
+      {
+      continue;
+      }
+
+   strcpy(pcwd,name);                                   /* Assemble pathname */
+   AddSlash(pcwd);
+
+   if (BufferOverflow(pcwd,dirp->d_name))
+      {
+      return true;
+      }
+
+   strcat(pcwd,dirp->d_name);
+
+   if (!FileObjectFilter(pcwd,&statbuf,ptr->filters,editfiles))
+      {
+      Verbose("Skipping filtered file %s\n",pcwd);
+      continue;
+      }
+      
+   if (TRAVLINKS)
+      {
+      if (lstat(dirp->d_name,&statbuf) == -1)
+         {
+         snprintf(OUTPUT,CF_BUFSIZE*2,"Can't stat %s\n",pcwd);
+         CfLog(cferror,OUTPUT,"stat");
+         continue;
+         }
+      
+      if (S_ISLNK(statbuf.st_mode) && (statbuf.st_mode != getuid()))   
+         {
+         snprintf(OUTPUT,CF_BUFSIZE,"File %s is an untrusted link. cfagent will not follow it with a destructive operation (tidy)",pcwd);
+         continue;
+         }
+      
+      if (stat(dirp->d_name,&statbuf) == -1)
+         {
+         snprintf(OUTPUT,CF_BUFSIZE*2,"RecursiveCheck was working on %s when this happened:\n",pcwd);
+         CfLog(cferror,OUTPUT,"stat");
+         continue;
+         }
+      }
+   else
+      {
+      if (lstat(dirp->d_name,&statbuf) == -1)
+         {
+         snprintf(OUTPUT,CF_BUFSIZE*2,"RecursiveCheck was working in %s when this happened:\n",pcwd);
+         CfLog(cferror,OUTPUT,"lstat");
+         continue;
+         }
+      }
+   
+   if (S_ISDIR(statbuf.st_mode))
+      {
+      if (IsMountedFileSystem(&statbuf,pcwd,level))
+         {
+         continue;
+         }
+      else
+         {
+         if ((ptr->recurse > 1) || (ptr->recurse == CF_INF_RECURSE))
+            {
+            goback = DoRecursiveEditFiles(pcwd,level-1,ptr,&statbuf);
+            DirPop(goback,name,sb);
+            }
+         else
+            {
+            WrapDoEditFile(ptr,pcwd);
+            }
+         }
+      }
+   else
+      {
+      WrapDoEditFile(ptr,pcwd);
+      }
+   }
+
+closedir(dirh);
+return true; 
+}
+
+/********************************************************************/
+
+void DoEditHomeFiles(struct Edit *ptr)
+
+{ DIR *dirh, *dirh2;
+  struct dirent *dirp, *dirp2;
+  char *sp,homedir[CF_BUFSIZE],dest[CF_BUFSIZE];
+  struct passwd *pw;
+  struct stat statbuf;
+  struct Item *ip;
+  uid_t uid;
+  
+if (!MountPathDefined())
+   {
+   CfLog(cfinform,"Mountpattern is undefined\n","");
+   return;
+   }
+
+for (ip = VMOUNTLIST; ip != NULL; ip=ip->next)
+   {
+   if (IsExcluded(ip->classes))
+      {
+      continue;
+      }
+   
+   if ((dirh = opendir(ip->name)) == NULL)
+      {
+      snprintf(OUTPUT,CF_BUFSIZE*2,"Can't open directory %s\n",ip->name);
+      CfLog(cferror,OUTPUT,"opendir");
+      return;
+      }
+
+   for (dirp = readdir(dirh); dirp != NULL; dirp = readdir(dirh))
+      {
+      if (!SensibleFile(dirp->d_name,ip->name,NULL))
+         {
+         continue;
+         }
+
+      strcpy(homedir,ip->name);
+      AddSlash(homedir);
+      strcat(homedir,dirp->d_name);
+
+      if (! IsHomeDir(homedir))
+         {
+         continue;
+         }
+
+      if ((dirh2 = opendir(homedir)) == NULL)
+         {
+         snprintf(OUTPUT,CF_BUFSIZE*2,"Can't open directory%s\n",homedir);
+         CfLog(cferror,OUTPUT,"opendir");
+         return;
+         }
+
+      for (dirp2 = readdir(dirh2); dirp2 != NULL; dirp2 = readdir(dirh2))
+         {
+         if (!SensibleFile(dirp2->d_name,homedir,NULL))
+            {
+            continue;
+            }
+         
+         strcpy(dest,homedir);
+         AddSlash(dest);
+         strcat(dest,dirp2->d_name);
+         AddSlash(dest);
+         sp = ptr->fname + strlen("home/");
+         strcat(dest,sp);
+         
+         if (stat(dest,&statbuf))
+            {
+            EditVerbose("File %s doesn't exist for editing, skipping\n",dest);
+            continue;
+            }
+      
+         if ((pw = getpwnam(dirp2->d_name)) == NULL)
+            {
+            Debug2("cfengine: directory corresponds to no user %s - ignoring\n",dirp2->d_name);
+            continue;
+            }
+         else
+            {
+            Debug2("(Setting user id to %s)\n",dirp2->d_name);
+            }
+
+         uid = statbuf.st_uid;
+
+         WrapDoEditFile(ptr,dest);
+      
+         chown(dest,uid,CF_SAME_OWNER);
+         }
+      closedir(dirh2);
+      }
+   closedir(dirh);
+   }
+}
+
+/********************************************************************/
+
 void WrapDoEditFile(struct Edit *ptr,char *filename)
 
 { struct stat statbuf,statbuf2;
@@ -135,8 +347,7 @@ void DoEditFile(struct Edit *ptr,char *filename)
   int todo = 0, potentially_outstanding = false;
   FILE *loop_fp = NULL;
   int DeleteItemNotContaining(),DeleteItemNotStarting(),DeleteItemNotMatching();
-  int global_replace = -1, ifel=-1,expaf=-1;
-  int ifelapsed=VIFELAPSED,expireafter=VEXPIREAFTER;
+  int global_replace = -1;
 
 Debug("DoEditFile(%s)\n",filename);
 filestart = NULL;
@@ -158,24 +369,6 @@ for (ep = ptr->actions; ep != NULL; ep=ep->next)
       {
       todo++;
       }
-
-   switch (ep->code)
-      {
-      case EditIfElapsed:
-          ifel = atoi(ep->data);
-          if (ifel > 0)
-             {
-             ifelapsed = ifel;
-             }
-          break;
-      case EditExpireAfter:
-          expaf = atoi(ep->data);
-          if (expaf > 0)
-             {
-             expireafter = expaf;
-             }
-          break;
-      }
    }
 
 if (todo == 0)   /* Because classes are stored per edit, not per file */
@@ -183,9 +376,8 @@ if (todo == 0)   /* Because classes are stored per edit, not per file */
    return;
    }
 
-if (!GetLock(ASUniqueName("editfile"),CanonifyName(filename),ifelapsed,expireafter,VUQNAME,CFSTARTTIME))
+if (!GetLock(ASUniqueName("editfile"),CanonifyName(filename),VIFELAPSED,VEXPIREAFTER,VUQNAME,CFSTARTTIME))
    {
-   ptr->done = 'y';
    return;
    }
  
@@ -200,11 +392,7 @@ CheckEditSwitches(filename,ptr);
 
 if (! LoadItemList(&filestart,filename))
    {
-   if (ptr->warn == 'y')
-      {
-      CfLog(cfverbose,"File was marked for editing\n","");
-      }
-   
+   CfLog(cfverbose,"File was marked for editing\n","");
    ReleaseCurrentLock();
    return;
    }
@@ -241,18 +429,13 @@ while (ep != NULL)
       case NoEdit:
       case EditInform:
       case EditBackup:
-      case EditLog:
       case EditUmask:
       case AutoCreate:
-      case WarnIfFileMissing:
       case EditInclude:
       case EditExclude:
       case EditFilter:
       case DefineClasses:
       case ElseDefineClasses:
-      case EditIfElapsed:
-      case EditExpireAfter:
-      case EditSplit:
         break;
 
       case EditUseShell:
@@ -263,12 +446,6 @@ while (ep != NULL)
         break;
         
       case DefineInGroup:
-          if (EDITGROUPLEVEL < 1)
-             {
-             yyerror("DefineInGroup used outside edit-group");
-             break;
-             }
-          
           for (sp = expdata; *sp != '\0'; sp++)
              {
              currentitem[0] = '\0';
@@ -569,7 +746,7 @@ while (ep != NULL)
           
           if (CURRENTLINEPTR == NULL)
              {
-             newlineptr = NULL;
+             newlineptr == NULL;
              }
           else
              {
@@ -615,14 +792,6 @@ while (ep != NULL)
              }
           break;
           
-      case ExpandVariables:
-          if (!ExpandAllVariables(filestart))
-             {
-             printf("Aborting edit of file %s\n",filename);
-             continue;
-             }
-          break;
-          
       case DeleteToLineMatching:
           if (! DeleteToRegExp(&filestart,expdata))
              {
@@ -761,7 +930,6 @@ while (ep != NULL)
           break;
           
       case BeginGroupIfNoMatch:
-          
           if (CURRENTLINEPTR == NULL || CURRENTLINEPTR->name == NULL )
              {
              EditVerbose("(Begin Group - no match for %s - file empty)\n",expdata);
@@ -776,31 +944,8 @@ while (ep != NULL)
           else
              {
              EditVerbose("(Begin Group - no match for %s)\n",expdata);
-             EDITGROUPLEVEL++;
              }
           break;
-
-      case BeginGroupIfMatch:
-          
-          if (CURRENTLINEPTR == NULL || CURRENTLINEPTR->name == NULL )
-             {
-             EditVerbose("(Begin Group - no match for %s - file empty)\n",expdata);
-             break;
-             }
-          
-          if (LineMatches(CURRENTLINEPTR->name,expdata))
-             {
-             EditVerbose("(Begin Group - match for %s)\n",expdata);
-             EDITGROUPLEVEL++;
-             }
-          else
-             {
-             EditVerbose("(Begin Group - skipping %s)\n",expdata);
-             ep = SkipToEndGroup(ep,filename);
-             }
-
-          break;
-
           
       case BeginGroupIfNoLineMatching:
           if (LocateItemMatchingRegExp(filestart,expdata) != 0)
@@ -811,23 +956,8 @@ while (ep != NULL)
           else
              {
              EditVerbose("(Begin Group - no line matching %s)\n",expdata);
-             EDITGROUPLEVEL++;
              }
           break;
-
-      case BeginGroupIfLineMatching:
-          if (LocateItemMatchingRegExp(filestart,expdata) == 0)
-             {
-             EditVerbose("(Begin Group - skipping %s)\n",expdata);
-             ep = SkipToEndGroup(ep,filename);
-             }
-          else
-             {
-             EditVerbose("(Begin Group - line matching %s)\n",expdata);
-             EDITGROUPLEVEL++;
-             }
-          break;
-
           
       case BeginGroupIfNoLineContaining:
           if (LocateNextItemContaining(filestart,expdata) != 0)
@@ -838,20 +968,6 @@ while (ep != NULL)
           else
              {
              EditVerbose("(Begin Group - no line containing %s)\n",expdata);
-             EDITGROUPLEVEL++;
-             }
-          break;
-          
-      case BeginGroupIfLineContaining:
-          if (LocateNextItemContaining(filestart,expdata) == 0)
-             {
-             EditVerbose("(Begin Group - skipping, string matched)\n");
-             ep = SkipToEndGroup(ep,filename);
-             }
-          else
-             {
-             EditVerbose("(Begin Group - line containing %s)\n",expdata);
-             EDITGROUPLEVEL++;
              }
           break;
           
@@ -864,7 +980,6 @@ while (ep != NULL)
           else
              {
              EditVerbose("(Begin Group - no line %s)\n",expdata);
-             EDITGROUPLEVEL++;
              }
           break;
           
@@ -881,7 +996,6 @@ while (ep != NULL)
           else
              {
              EditVerbose("(Begin Group - new file %s)\n",expdata);
-             EDITGROUPLEVEL++;
              }
           break;
           
@@ -890,7 +1004,6 @@ while (ep != NULL)
           if (!IsExcluded(expdata))
              {
              EditVerbose("(Begin Group - class %s defined)\n", expdata);
-             EDITGROUPLEVEL++;
              }
           else
              {
@@ -902,7 +1015,6 @@ while (ep != NULL)
       case BeginGroupIfNotDefined:
           if (IsExcluded(expdata))
              {
-             EDITGROUPLEVEL++;
              EditVerbose("(Begin Group - class %s not defined)\n", expdata);
              }
           else
@@ -921,13 +1033,10 @@ while (ep != NULL)
           else
              {
              EditVerbose("(Begin Group - found file %s)\n",expdata);
-             EDITGROUPLEVEL++;
              }
           break;
-          
       case EndGroup:
           EditVerbose("(End Group)\n");
-          EDITGROUPLEVEL--;
           break;
           
       case ReplaceAll:
@@ -1058,15 +1167,7 @@ while (ep != NULL)
           break;
           
       case AppendToLineIfNotContains:
-          
-          if (CURRENTLINEPTR == NULL)
-             {
-             PrependItem(&filestart,expdata,NULL);
-             }
-          else
-             {
-             AppendToLine(CURRENTLINEPTR,expdata,filename);
-             }
+          AppendToLine(CURRENTLINEPTR,expdata,filename);
           break;
           
       default: snprintf(OUTPUT,CF_BUFSIZE*2,"Unknown action in editing of file %s\n",filename);
@@ -1093,8 +1194,6 @@ if (DONTDO || CompareToFile(filestart,filename))
  
 if ((! DONTDO) && (NUMBEROFEDITS > 0))
    {
-   snprintf(OUTPUT,CF_BUFSIZE,"Saving edit changes to file %s",filename);
-   CfLog(cfinform,OUTPUT,"");
    SaveItemList(filestart,filename,ptr->repository);
    AddEditfileClasses(ptr,true);
    }
@@ -1253,41 +1352,6 @@ return true;
 
 /********************************************************************/
 
-int ExpandAllVariables (struct Item *list)
-
-{ char *sp;
-  int i = 1;
-  struct Item *ip;
-
-  for (ip = list; ip != NULL; ip=ip->next, i++)
-    {
-
-    if ((sp = malloc(CF_EXPANDSIZE)) == NULL)
-      {
-      printf("Memory allocation failed in ExpandEditLineVariables, aborting edit.\n");
-      return false;
-      }
-
-    memset( sp, 0, CF_EXPANDSIZE);
-    ExpandVarstring(ip->name,sp,NULL);
-
-    if (strcmp(sp,ip->name) == 0)
-      {
-      EditVerbose("ExpandVariables - no expansions in %10s...\n", sp);
-      continue;
-      }
-
-    EditVerbose("Expanded line %d to %10s...\n",i,sp);
-    free (ip->name);
-    ip->name = sp;
-    NUMBEROFEDITS++;
-  }
-
-return true;
-}
-
-/********************************************************************/
-
 int RunEditScript (char *script,char *fname,struct Item **filestart,struct Edit *ptr)
 
 { FILE *pp;
@@ -1337,13 +1401,11 @@ if (pp == NULL)
 
 while (!feof(pp))   
    {
-   char buffer[CF_BUFSIZE];
-   
-   ReadLine(buffer,CF_BUFSIZE-1,pp);
+   ReadLine(CURRENTITEM,CF_BUFSIZE,pp);
 
    if (!feof(pp))
       {
-      EditVerbose("%s\n",buffer);
+      EditVerbose("%s\n",CURRENTITEM);
       }
    }
 
@@ -1353,11 +1415,7 @@ cfpclose(pp);
 
 if (! LoadItemList(filestart,fname))
    {
-   if (ptr->warn == 'y')
-      {
-      snprintf(OUTPUT,CF_BUFSIZE,"File %s did not exist and was marked for editing");
-      CfLog(cferror,OUTPUT,"");
-      }
+   EditVerbose("File was marked for editing\n");
    return false;
    }
 
@@ -1458,45 +1516,20 @@ void CheckEditSwitches(char *filename,struct Edit *ptr)
 
 { struct stat statbuf;
   struct Edlist *ep;
-  char inform, log;
+  char inform = 'd', log = 'd';
   char expdata[CF_EXPANDSIZE];
   int fd;
-  struct Edlist *actions = ptr->actions;
-#ifdef WITH_SELINUX
-  int selinux_enabled=0;
-  security_context_t scontext=NULL;
-
-  selinux_enabled = (is_selinux_enabled()>0);
-#endif
+struct Edlist *actions = ptr->actions;
   
 PARSING = true;
-
-if (INFORM)
-   {
-   inform = 'y';
-   }
-else
-   {
-   inform = 'n';
-   }
-
-if (LOGGING)
-   {
-   log = 'y';
-   }
-else
-   {
-   log = 'n';
-   }
-
-
+ 
 for (ep = actions; ep != NULL; ep=ep->next)
    {
    if (IsExcluded(ep->classes))
       {
       continue;
       }
-   
+
    ExpandVarstring(ep->data,expdata,NULL);
    
    switch(ep->code)
@@ -1509,15 +1542,6 @@ for (ep = actions; ep != NULL; ep=ep->next)
                 {
                 Debug("Setting umask to %o\n",ptr->umask);
                 mask=umask(ptr->umask);
-#ifdef WITH_SELINUX
-                if(selinux_enabled)
-                    {
-                    /* use default security context when creating destination file */
-                    matchpathcon(filename,0,&scontext);
-                    Debug("Setting SELinux context to: %s\n", scontext);
-                    setfscreatecon(scontext);
-                    }
-#endif
                 
                 if ((fd = creat(filename,0644)) == -1)
                    {
@@ -1532,24 +1556,8 @@ for (ep = actions; ep != NULL; ep=ep->next)
                 snprintf(OUTPUT,CF_BUFSIZE*2,"Creating file %s, mode %o\n",filename,(0644 & ~ptr->umask));
                 CfLog(cfinform,OUTPUT,"");
                 umask(mask);
-#ifdef WITH_SELINUX
-                if(selinux_enabled)
-                    {
-                    /* set create context back to default */
-                    setfscreatecon(NULL);
-                    freecon(scontext);
-                    }
-#endif
-                break;
-                }
-             }
-          else
-             {
-             if (stat(filename,&statbuf) == -1)
-                {
-                snprintf(OUTPUT,CF_BUFSIZE*2,"Should create and edit file %s, mode %o\n",filename,(0644 & ~ptr->umask));
-                CfLog(cfinform,OUTPUT,"");
-                }
+                return;
+                }    
              }
           
           break;
@@ -1562,13 +1570,14 @@ for (ep = actions; ep != NULL; ep=ep->next)
           
           if (strcmp("single",ToLowerStr(expdata)) == 0 || strcmp("one",ToLowerStr(expdata)) == 0)
              {
-             IMAGEBACKUP = 'y';
+             IMAGEBACKUP = 'n';
              }
           
           if (strcmp("timestamp",ToLowerStr(expdata)) == 0 || strcmp("stamp",ToLowerStr(expdata)) == 0)
              {
              IMAGEBACKUP = 's';
-             }          
+             }
+          
           break;
           
       case EditLog:
@@ -1583,11 +1592,8 @@ for (ep = actions; ep != NULL; ep=ep->next)
              log = 'n';
              break;
              }
-
-          break;
           
       case EditInform:
-
           if (strcmp(ToLowerStr(expdata),"true") == 0 || strcmp(ToLowerStr(expdata),"on") == 0)
              {
              inform = 'y';
@@ -1598,9 +1604,7 @@ for (ep = actions; ep != NULL; ep=ep->next)
              {
              inform = 'n';
              break;
-             }
-
-          break;
+             }                   
       }
    }
 
@@ -1637,7 +1641,7 @@ if (editsdone)
             
             sscanf(sp,"%[^,:.]",currentitem);
             
-            sp += strlen(currentitem) - 1;
+            sp += strlen(currentitem);
             
             AddClassToHeap(currentitem);
             }
@@ -1656,9 +1660,8 @@ if (editsdone)
        if (ep->code == ElseDefineClasses)
           {
           Debug("Entering AddEditfileClasses(%s)\n",ep->data);
-
-          sp = ep->data; 
-          while(*sp != '\0')
+          
+          for (sp = ep->data; *sp != '\0'; sp++)
              {
              currentitem[0] = '\0';
              
@@ -1667,11 +1670,6 @@ if (editsdone)
              sp += strlen(currentitem);
              
              AddClassToHeap(currentitem);
-
-             if (strlen(sp) > 0)
-                {
-                sp++;
-                }
              }
           }
        }
@@ -1708,7 +1706,6 @@ if (!LoadItemList(&infilelist,infile))
       {
       case DeleteLinesStartingFileItems:
           positive = true;
-
       case DeleteLinesNotStartingFileItems:
           matches = 0;
           
@@ -1738,7 +1735,6 @@ if (!LoadItemList(&infilelist,infile))
           
       case DeleteLinesContainingFileItems:
           positive = true;
-
       case DeleteLinesNotContainingFileItems:
           matches = 0;
           
@@ -1840,18 +1836,15 @@ while(ep != NULL)
    {
    switch (ep->code)
       {
-      case BeginGroupIfMatch:
       case BeginGroupIfNoMatch:
       case BeginGroupIfNoLineMatching:
-      case BeginGroupIfLineMatching:
       case BeginGroupIfNoSuchLine:
       case BeginGroupIfFileIsNewer:
       case BeginGroupIfFileExists:
-      case BeginGroupIfLineContaining:
       case BeginGroupIfNoLineContaining:
       case BeginGroupIfDefined:
       case BeginGroupIfNotDefined:
-          level ++;
+   level ++;
       }
 
    Debug("   skip: %s (%d)\n",VEDITNAMES[ep->code],level);
@@ -2082,7 +2075,7 @@ if (! IsItemIn(VREPOSLIST,new))
       unlink(new);
       return false;
       }
-   else if (Repository(backup,repository))
+   else if(Repository(backup,repository))
       {
       if (rename(new,file) == -1)
          {
