@@ -179,7 +179,6 @@ else
                 
                 sprintf(ebuff,"%d",i);
                 break;
-                
             case filterexecregex:
                 for (sp = ebuff+strlen(ebuff)-1; (*sp != '(') && (sp > ebuff); sp--)
                    {
@@ -337,18 +336,13 @@ for (fp = VFILTERLIST; fp != NULL; fp = fp->next)
          CfLog(cferror,OUTPUT,"");
          FatalError("Consistency errors");
          }
-
       if (strncmp(fp->criteria[filterfromttime],"accumulated",strlen("accumulated")) != 0)
          {
          yyerror("Must use accumulated time in FromTtime");
          }
-
       if (strncmp(fp->criteria[filtertottime],"accumulated",strlen("accumulated")) != 0)
          {
-         if (strcmp(fp->criteria[filtertottime],"inf") != 0)
-            {
-            yyerror("Must use accumulated time in ToTtime");
-            }
+         yyerror("Must use accumulated time in ToTtime");
          }
       }
    
@@ -420,7 +414,7 @@ time_t Date2Number(char *string,time_t now)
     
   */
 
-{ char type[CF_SMALLBUF],datestr[CF_SMALLBUF];
+{ char type[16],datestr[63];
   int year=-1,month=-1,day=-1,hr=-1,min=-1,sec=-1; 
   time_t time;
   struct tm tmv;
@@ -671,6 +665,7 @@ return result;
 
 void DoFilter(struct Item **attr,char **crit,struct stat *lstatptr,char *filename)
 
+
 {
 if (crit[filtertype] != NULL)
    {
@@ -937,7 +932,6 @@ if (S_ISLNK(lstatptr->st_mode))
 if (S_ISREG(lstatptr->st_mode))
    {
    PrependItem(&attrib,"reg","");
-   PrependItem(&attrib,"file","");
    }
 
 if (S_ISDIR(lstatptr->st_mode))
@@ -992,8 +986,7 @@ int FilterProcMatch(char *name1,char *name2,char *expr,char **names,char **line)
   regex_t rx;
   regmatch_t pmatch;
 
-Debug("FilterProcMatch(%s,%s,%s,<%x>,<%x>)\n",name1,name2,expr,names,line);
-
+  Debug("FilterProcMatch(%s,%s,%s,<%x>,<%x>)\n",name1,name2,expr,names,line);
 
 if (CfRegcomp(&rx,expr,REG_EXTENDED) != 0)
    {
@@ -1013,8 +1006,7 @@ for (i = 0; names[i] != NULL; i++)
             return true;
             }
          }
-
-      Debug("No match of (%s) to (%s)\n",expr,line[i]);
+      
       regfree(&rx);
       return false;      
       }
@@ -1146,7 +1138,7 @@ for (i = 0; names[i] != NULL; i++)
       ParseTTime(line[i], timestr);
       Debug("ParseTTime = %s\n",timestr); 
       pstime = Date2Number(timestr,now);
-      
+
       return ((fromtime < pstime) && (pstime < totime));
       }
    } 
@@ -1158,7 +1150,7 @@ return false;
 int FilterOwnerMatch(struct stat *lstatptr,char *crit)
 
 { struct Item *attrib = NULL;
-  char buffer[CF_SMALLBUF];
+  char buffer[64];
   struct passwd *pw;
 
 sprintf(buffer,"%d",lstatptr->st_uid);
@@ -1190,7 +1182,7 @@ else
 int FilterGroupMatch(struct stat *lstatptr,char *crit)
 
 { struct Item *attrib = NULL;
-  char buffer[CF_SMALLBUF];
+  char buffer[64];
   struct group *gr;
 
 sprintf(buffer,"%d",lstatptr->st_gid);
@@ -1375,7 +1367,7 @@ DeleteMacro(CONTEXTID,"this");
 
 Debug("Executing filter command [%s]\n",ebuff);
 
-if (ShellCommandReturnsZero(ebuff,false))
+if (ShellCommandReturnsZero(ebuff))
    {
    return true;
    }
