@@ -59,9 +59,7 @@ char PADCHAR = ' ';
 char CONTEXTID[32];
 char CFPUBKEYFILE[CF_BUFSIZE];
 char CFPRIVKEYFILE[CF_BUFSIZE];
-char AVDB[CF_MAXVARSIZE];
-char CFWORKDIR[CF_BUFSIZE];
-char PIDFILE[CF_BUFSIZE];
+char AVDB[1024];
 
 RSA *PRIVKEY = NULL, *PUBKEY = NULL;
 
@@ -94,7 +92,7 @@ pthread_mutex_t MUTEX_LOCK = PTHREAD_MUTEX_INITIALIZER;
 /*                                                                 */
 /*******************************************************************/
 
-  PUBLIC char *COPYRIGHT = "Free Software Foundation 1994-\nDonated by Mark Burgess, Faculty of Engineering,\nOslo University College, Norway";
+  PUBLIC char *COPYRIGHT = "Free Software Foundation 1994-\nDonated by Mark Burgess, Faculty of Engineering,\nOslo University College, 0254 Oslo, Norway";
 
   PRIVATE char *VPRECONFIG = "cf.preconf";
   PRIVATE char *VRCFILE = "cfrc";
@@ -110,7 +108,7 @@ pthread_mutex_t MUTEX_LOCK = PTHREAD_MUTEX_INITIALIZER;
   PUBLIC char VINPUTFILE[CF_BUFSIZE];
   PUBLIC char VCURRENTFILE[CF_BUFSIZE];
   PUBLIC char VLOGFILE[CF_BUFSIZE];
-  PUBLIC char ALLCLASSBUFFER[CF_ALLCLASSSIZE];
+  PUBLIC char ALLCLASSBUFFER[4*CF_BUFSIZE];
   PUBLIC char ELSECLASSBUFFER[CF_BUFSIZE];
   PUBLIC char FAILOVERBUFFER[CF_BUFSIZE];
   PUBLIC char CHROOT[CF_BUFSIZE];
@@ -121,7 +119,6 @@ pthread_mutex_t MUTEX_LOCK = PTHREAD_MUTEX_INITIALIZER;
   PUBLIC short D2 = false;
   PUBLIC short D3 = false;
   PUBLIC short D4 = false;
-  PUBLIC short LASTSEEN = true;
   PUBLIC short VERBOSE = false;
   PUBLIC short INFORM = false;
   PUBLIC short CHECK = false;
@@ -135,8 +132,6 @@ pthread_mutex_t MUTEX_LOCK = PTHREAD_MUTEX_INITIALIZER;
   PUBLIC short LOGTIDYHOMEFILES = true;
   PUBLIC short UPDATEONLY = false;
   PUBLIC short SKIPIDENTIFY = false;
-  PUBLIC short ALL_SINGLECOPY = false;
-  PUBLIC short FULLENCRYPT = false;
 
   PUBLIC char FORK = 'n';
 
@@ -149,9 +144,6 @@ pthread_mutex_t MUTEX_LOCK = PTHREAD_MUTEX_INITIALIZER;
 
   PUBLIC dev_t ROOTDEVICE = 0;
 
-  PUBLIC char  STR_CFENGINEPORT[16];
-  PUBLIC unsigned short SHORT_CFENGINEPORT;
-
   PUBLIC enum classes VSYSTEMHARDCLASS;
 
   PUBLIC struct Item VDEFAULTBINSERVER =      /* see GetNameInfo(), main.c */
@@ -176,9 +168,7 @@ pthread_mutex_t MUTEX_LOCK = PTHREAD_MUTEX_INITIALIZER;
   PROTECTED int VDEFAULTEXPIREAFTER = 120; /* minutes */
 
   PUBLIC struct cfagent_connection *CONN = NULL;
-
   PUBLIC struct Item *VEXCLUDECACHE = NULL;
-  PUBLIC struct Item *QUERYVARS = NULL;
 
   PUBLIC struct cfObject *OBJECTLIST = NULL;
 
@@ -188,19 +178,19 @@ pthread_mutex_t MUTEX_LOCK = PTHREAD_MUTEX_INITIALIZER;
  /* Anomaly                                                         */
  /*******************************************************************/
 
-struct sock ECGSOCKS[ATTR] = /* extended to map old to new using enum*/
+char *ECGSOCKS[ATTR][2] =
    {
-   {"137","netbiosns",ob_netbiosns_in,ob_netbiosns_out},
-   {"138","netbiosdgm",ob_netbiosdgm_in,ob_netbiosdgm_out},
-   {"139","netbiosssn",ob_netbiosssn_in,ob_netbiosssn_out},
-   {"194","irc",ob_irc_in,ob_irc_out},
-   {"5308","cfengine",ob_cfengine_in,ob_cfengine_out},
-   {"2049","nfsd",ob_nfsd_in,ob_nfsd_out},
-   {"25","smtp",ob_smtp_in,ob_smtp_out},
-   {"80","www",ob_www_in,ob_www_out},
-   {"21","ftp",ob_ftp_in,ob_ftp_out},
-   {"22","ssh",ob_ssh_in,ob_ssh_out},
-   {"443","wwws",ob_wwws_in,ob_wwws_out}
+   {"137","netbiosns"},
+   {"138","netbiosdgm"},
+   {"139","netbiosssn"},
+   {"194","irc"},
+   {"5308","cfengine"},
+   {"2049","nfsd"},
+   {"25","smtp"},
+   {"80","www"},
+   {"21","ftp"},
+   {"22","ssh"},
+   {"443","wwws"}
    };
 
 char *TCPNAMES[CF_NETATTR] =
@@ -214,106 +204,10 @@ char *TCPNAMES[CF_NETATTR] =
    "misc"
    };
 
-char *OBS[CF_OBSERVABLES] =
-    {
-    "users",
-    "rootprocs",
-    "otherprocs",
-    "diskfree",
-    "loadavg",
-    "netbiosns_in",
-    "netbiosns_out",
-    "netbiosdgm_in",
-    "netbiosdgm_out",
-    "netbiosssn_in",
-    "netbiosssn_out",
-    "irc_in",
-    "irc_out",
-    "cfengine_in",
-    "cfengine_out",
-    "nfsd_in",
-    "nfsd_out",
-    "smtp_in",
-    "smtp_out",
-    "www_in",
-    "www_out",
-    "ftp_in",
-    "ftp_out",
-    "ssh_in",
-    "ssh_out",
-    "wwws_in",
-    "wwws_out",
-    "icmp_in",
-    "icmp_out",
-    "udp_in",
-    "udp_out",
-    "dns_in",
-    "dns_out",
-    "tcpsyn_in",
-    "tcpsyn_out",
-    "tcpack_in",
-    "tcpack_out",
-    "tcpfin_in",
-    "tcpfin_out",
-    "tcpmisc_in",
-    "tcpmisc_out",
-    "spare",
-    "spare",
-    "spare",
-    "spare",
-    "spare",
-    "spare",
-    "spare",
-    "spare",
-    "spare",
-    "spare",
-    "spare",
-    "spare",
-    "spare",
-    "spare",
-    "spare",
-    "spare",
-    "spare",
-    "spare",
-    "spare",
-    "spare",
-    "spare",
-    "spare",
-    "spare",
-    "spare",
-    "spare",
-    "spare",
-    "spare",
-    "spare",
-    "spare",
-    "spare",
-    "spare",
-    "spare",
-    "spare",
-    "spare",
-    "spare",
-    "spare",
-    "spare",
-    "spare",
-    "spare",
-    "spare",
-    "spare",
-    "spare",
-    "spare",
-    "spare",
-    "spare",
-    "spare",
-    "spare",
-    "spare",
-    "spare",
-    "spare",
-    };
-
  /*******************************************************************/
  /* Methods                                                         */
  /*******************************************************************/
 
-  PUBLIC int GOTMETHODARGS = false;
   PUBLIC struct Item *METHODARGS = NULL;
   PUBLIC char ** METHODARGV = NULL;
   PUBLIC int METHODARGC = 0;
@@ -342,12 +236,11 @@ char *OBS[CF_OBSERVABLES] =
  /* Data/list structures - root pointers                            */
  /*******************************************************************/
 
-  PUBLIC struct Item *ABORTHEAP = NULL;
-  
   PROTECTED  struct Item *VTIMEZONE = NULL;
   PROTECTED  struct Item *VMOUNTLIST = NULL;
   PROTECTED  struct Item *VEXCLUDECOPY = NULL;
   PROTECTED  struct Item *VAUTODEFINE = NULL;
+  PROTECTED  struct Item *VSINGLECOPY = NULL;
   PROTECTED  struct Item *VEXCLUDELINK = NULL;
   PROTECTED  struct Item *VCOPYLINKS = NULL;
   PROTECTED  struct Item *VLINKCOPIES = NULL;
@@ -378,14 +271,12 @@ char *OBS[CF_OBSERVABLES] =
   PROTECTED  struct Disk *VREQUIREDTOP = NULL;
   PROTECTED  struct ShellComm *VSCRIPT = NULL;              /* List of scripts to execute */
   PROTECTED  struct ShellComm *VSCRIPTTOP = NULL;
-  PROTECTED  struct ShellComm *VSCLI = NULL;               /* List of scli coms to execute */
-  PROTECTED  struct ShellComm *VSCLITOP = NULL;
   PROTECTED  struct Interface *VIFLIST = NULL;
   PROTECTED  struct Interface *VIFLISTTOP = NULL;
   PROTECTED  struct Mounted *MOUNTED = NULL;             /* Files systems already mounted */
   PROTECTED  struct MiscMount *VMISCMOUNT = NULL;
   PROTECTED  struct MiscMount *VMISCMOUNTTOP = NULL;
-  PROTECTED  struct Item *VBINSERVERS = NULL;
+  PROTECTED  struct Item *VBINSERVERS = &VDEFAULTBINSERVER;
   PROTECTED  struct Link *VLINK = NULL;
   PROTECTED  struct Link *VLINKTOP = NULL;
   PROTECTED  struct File *VFILE = NULL;
@@ -424,8 +315,6 @@ char *OBS[CF_OBSERVABLES] =
   PROTECTED  struct Item *VALLADDCLASSES=NULL;        /* All classes */
   PROTECTED  struct Item *VJUSTACTIONS=NULL;
   PROTECTED  struct Item *VAVOIDACTIONS=NULL;
-  PROTECTED  struct Item *VDEFAULTROUTE=NULL;
-
   PROTECTED  struct UnMount *VUNMOUNT=NULL;
   PROTECTED  struct UnMount *VUNMOUNTTOP=NULL;
   PROTECTED  struct Edit *VEDITLIST=NULL;
@@ -477,6 +366,7 @@ char *OBS[CF_OBSERVABLES] =
  PROTECTED char       VSYSADM[CF_MAXVARSIZE];
  PROTECTED char      VNETMASK[CF_MAXVARSIZE];
  PROTECTED char    VBROADCAST[CF_MAXVARSIZE];
+ PROTECTED char VDEFAULTROUTE[CF_MAXVARSIZE];
  PROTECTED char      VNFSTYPE[CF_MAXVARSIZE];
  PROTECTED char       VFQNAME[CF_MAXVARSIZE];
  PROTECTED char       VUQNAME[CF_MAXVARSIZE];
@@ -497,7 +387,7 @@ char *OBS[CF_OBSERVABLES] =
   /* GNU STUFF FOR LATER #include "getopt.h" */
  
  
- PRIVATE struct option OPTIONS[49] =
+ PRIVATE struct option OPTIONS[] =
       {
       { "help",no_argument,0,'h' },
       { "debug",optional_argument,0,'d' },
@@ -545,8 +435,6 @@ char *OBS[CF_OBSERVABLES] =
       { "check-contradictions",no_argument,0,'g'},
       { "just",required_argument,0,'j'},
       { "avoid",required_argument,0,'o'},
-      { "query",required_argument,0,'Q'},
-      { "csdb",no_argument,0,'W'},
       { NULL,0,0,0 }
       };
 
@@ -593,7 +481,6 @@ char *OBS[CF_OBSERVABLES] =
       "Strategies:",
       "Package Checks:",
       "Method Function Calls",
-      "SCLI SNMP Agent Calls",
       NULL
       };
 
@@ -635,7 +522,6 @@ char *OBS[CF_OBSERVABLES] =
       "strategies",
       "packages",
       "methods",
-      "scli",
       NULL
       };
 
@@ -651,9 +537,7 @@ char *OBS[CF_OBSERVABLES] =
       "islink",
       "isplain",
       "execresult",
-      "execshellresult",
       "returnszero",
-      "returnszeroshell",
       "iprange",
       "hostrange",
       "isdefined",
@@ -675,10 +559,6 @@ char *OBS[CF_OBSERVABLES] =
       "selectpartitionleader",
       "selectpartitionneighbours",
       "selectpartitionneighbors",
-      "isgreaterthan",
-      "islessthan",
-      "readtcp",
-      "printfile",
       NULL
       };
 
@@ -746,19 +626,6 @@ char *OBS[CF_OBSERVABLES] =
       "ge",
       "le",
       "ne",
-      "none",
-      NULL
-      };
-
-  PRIVATE char *CMPSENSEOPERAND[] =
-      {
-      "=",
-      ">",
-      "<",
-      ">=",
-      "<=",
-      "!=",
-      NULL,
       NULL
       };
 
@@ -769,20 +636,6 @@ char *OBS[CF_OBSERVABLES] =
       {
       "rpm",
       "dpkg",   /* aptget ? */
-      "sun",    /* pkginfo/pkgadd/pkgrm */
-      "aix",    /* lslpp/installp */
-      "portage",
-      "freebsd",
-      NULL
-      };
-
-  /*********************************************************************/
-  /* The names of the possible package-related actions */
-  PRIVATE char *PKGACTIONTEXT[] =
-      {
-      "install",
-      "remove",
-      "upgrade",
       NULL
       };
 
@@ -794,8 +647,8 @@ char *OBS[CF_OBSERVABLES] =
 
   PUBLIC short ISCFENGINE;  /* for re-using parser code in cfd */
 
-  PUBLIC  short SHOWDB = false;
   PUBLIC  short PARSING = false;
+  PRIVATE short NOABSPATH = false;
   PRIVATE short TRAVLINKS = false;
   PRIVATE short PTRAVLINKS = false;
   PRIVATE short DEADLINKS = true;
@@ -809,7 +662,7 @@ char *OBS[CF_OBSERVABLES] =
   PRIVATE short NOTIDY = false;
   PRIVATE short NOSCRIPTS = false;
   PRIVATE short PRSYSADM = false;
-  PRIVATE short PRSCHEDULE = false;
+  PRIVATE short PRMAILSERVER = false;
   PRIVATE short MOUNTCHECK = false;
   PRIVATE short NOPROCS = false;
   PRIVATE short NOMETHODS = false;
@@ -837,13 +690,11 @@ char *OBS[CF_OBSERVABLES] =
   PRIVATE short NOSPLAY = false;
   PRIVATE short DONESPLAY = false;
 
-  PUBLIC  struct Item *VSINGLECOPY = NULL;
 
   PROTECTED  struct Item *VACLBUILD = NULL;
   PROTECTED  struct Item *VFILTERBUILD = NULL;
   PROTECTED  struct Item *VSTRATEGYBUILD = NULL;
 
-  PRIVATE char NOABSPATH = 'n';
   PRIVATE char TIDYDIRS = 'n';
   PRIVATE char XDEV = false;
   PRIVATE char IMAGEBACKUP='y';
@@ -895,8 +746,8 @@ char *OBS[CF_OBSERVABLES] =
   PRIVATE char *MOUNTOPTS;
   PRIVATE char *DESTINATION;
   PRIVATE char *IMAGEACTION;
-  PRIVATE char VIFNAME[16];
-  PRIVATE char VIFNAMEOVERRIDE[16];
+  PRIVATE char *VIFNAME[16];
+  PRIVATE char *VIFNAMEOVERRIDE[16];
   PRIVATE char *CHDIR;
   PRIVATE char *LOCALREPOS;
   PRIVATE char *EXPR;
@@ -940,7 +791,6 @@ char *OBS[CF_OBSERVABLES] =
   PRIVATE enum cmpsense CMPSENSE = cmpsense_eq; /* Comparison for packages: */
   PRIVATE enum pkgmgrs PKGMGR = pkgmgr_none;  /* Which package mgr to query */
   PRIVATE enum pkgmgrs DEFAULTPKGMGR = pkgmgr_none;
-  PRIVATE enum pkgactions PKGACTION = pkgaction_none;
 
   PRIVATE flag ACTION_IS_LINK = false;
   PRIVATE flag ACTION_IS_LINKCHILDREN = false;
@@ -956,7 +806,7 @@ char *OBS[CF_OBSERVABLES] =
   /*
    * HvB: Bas van der Vlies
   */
-  PRIVATE flag CF_MOUNT_RO = false;
+  PRIVATE flag MOUNT_RO = false;
 
   PRIVATE char *COMMATTRIBUTES[] =
      {
@@ -1149,7 +999,6 @@ char *OBS[CF_OBSERVABLES] =
      "AppendIfNoSuchLinesFromFile",
      "IncrementPointer",
      "ReplaceLineWith",
-     "ExpandVariables",
      "DeleteToLineMatching",
      "HashCommentToLineMatching",
      "PercentCommentToLineMatching",
@@ -1164,10 +1013,8 @@ char *OBS[CF_OBSERVABLES] =
      "GotoLastLine",
      "BreakIfLineMatches",
      "BeginGroupIfNoMatch",
-     "BeginGroupIfMatch",
      "BeginGroupIfNoLineMatching",
      "BeginGroupIfNoSuchLine",
-     "BeginGroupIfLineMatching",
      "EndGroup",
      "Append",
      "Prepend",
@@ -1193,11 +1040,9 @@ char *OBS[CF_OBSERVABLES] =
      "BeginGroupIfFileIsNewer",
      "BeginGroupIfFileExists",
      "BeginGroupIfNoLineContaining",
-     "BeginGroupIfLineContaining",
      "BeginGroupIfDefined",
      "BeginGroupIfNotDefined",
      "AutoCreate",
-     "WarnIfFileMissing",
      "ForEachLineIn",
      "EndLoop",
      "ReplaceLinesMatchingField",
@@ -1224,7 +1069,6 @@ char *OBS[CF_OBSERVABLES] =
      "DefineInGroup",
      "IfElapsed",
      "ExpireAfter",
-     "EditSplit",
      NULL
      };
 
@@ -1270,8 +1114,6 @@ char *OBS[CF_OBSERVABLES] =
    "SAUTH",
    "SSYNCH",
    "SGET",
-   "VERSION",
-   "SOPENDIR",
    NULL
    };
 
@@ -1295,40 +1137,5 @@ char *OBS[CF_OBSERVABLES] =
   PUBLIC char CFLAST[CF_BUFSIZE]; 
   PUBLIC char LOCKDB[CF_BUFSIZE];
 
-
-/*******************************************************************/
-/*                                                                 */
-/* Checksums                                                       */
-/*                                                                 */
-/*******************************************************************/
-
-/* These string lengths should not exceed CF_MAXDIGESTNAMELEN
-   characters for packing */
-
-  PUBLIC char *CF_DIGEST_TYPES[8][2] =
-     {
-     "md5","m",
-     "sha224","c",
-     "sha256","C",
-     "sha384","h",
-     "sha512","H",
-     "sha1","S",
-     "sha","s",   /* Should come last, since substring */
-     NULL,NULL
-     };
-
-  PUBLIC int CF_DIGEST_SIZES[8] =
-     {
-     CF_MD5_LEN,
-     CF_SHA224_LEN,
-     CF_SHA256_LEN,
-     CF_SHA384_LEN,
-     CF_SHA512_LEN,
-     CF_SHA1_LEN,
-     CF_SHA_LEN,
-     0
-     };
-
-
 /* EOF */
 
