@@ -45,8 +45,7 @@ struct Item *ListFromArgs(char *string)
 /* Splits a string with quoted components etc */
 
 { struct Item *ip = NULL;
- int inquotes_level = 0,i = 0,argc=0;
-  int inquote_level = 0;
+  int dquote_level = 0,i = 0;
   int paren_level = 0;
   char *sp,lastch = '\0';
   char item[CF_BUFSIZE];
@@ -61,77 +60,53 @@ for (sp = string; *sp != '\0'; sp++)
           
           if (lastch == '\\')  /* Escaped quote */
              {
-             if (inquotes_level == 0)
-                {
-                yyerror("Quoting error - escaped quote outside string");
-                FatalError("Unrecoverable");
-                }
-             
-             i--;
+             sp--;
+             *sp = ')';
+             continue;
              }
           else
              {
-             inquotes_level = 1 - inquotes_level; /* toggle */
-             continue;
+             if (dquote_level == 0)
+                {
+                dquote_level = 1;
+                continue;
+                }
+             else
+                {
+                dquote_level = 0;
+                continue;
+                }
              }
           break;
-
-      case '\'':
           
-          if (lastch == '\\')  /* Escaped quote */
-             {
-             if (inquotes_level == 0)
-                {
-                yyerror("Quoting error - escaped quote outside string");
-                FatalError("Unrecoverable");
-                }
-             
-             i--;
-             }
-          else
-             {
-             inquote_level = 1 - inquote_level; /* toggle */
-             continue;
-             }
-          break;
-
       case '(':
-
-          if (inquotes_level == 0)
-             {
-             paren_level++;
-             }
+          
+          paren_level++;
           break;
           
       case ')':
           
-          if (inquotes_level == 0)
-             {          
-             paren_level--;
-             }
+          paren_level--;
           break;
           
       case ',':
           
-          if ((inquotes_level == 0) && (paren_level == 0))
+          if (dquote_level == 0 && paren_level == 0)
              {
              item[i] = '\0';
              i = 0;
              AppendItem(&ip,item,"");
-             Debug("ListArg[%d]=(%s)\n",argc++,item);
              memset(item,0,CF_BUFSIZE);
              continue;
              }
       }
-
+   
    item[i++] = *sp;
    lastch = *sp;
    }
-
-item[i] = '\0';
-AppendItem(&ip,item,"");
-Debug("ListArg[%d]=(%s)\n",argc,item);
-return ip;
+ 
+ AppendItem(&ip,item,""); 
+ return ip;
 }
 
 /*********************************************************************/
@@ -187,7 +162,7 @@ return(false);
 
 /*********************************************************************/
 
-int IsWildItemIn(struct Item *list,char *wildcard)
+int IsWildItemIn(struct Item *list,char *item)
 
    /* Checks whether item matches a list of wildcards */
 
@@ -200,9 +175,9 @@ for (ptr = list; ptr != NULL; ptr=ptr->next)
       continue;
       }
 
-   if (WildMatch(wildcard,ptr->name) || WildMatch(ptr->name,wildcard))
+   if (WildMatch(ptr->name,item))
       {
-      Debug("IsWildItem(%s,%s)\n",wildcard,ptr->name);
+      Debug("IsWildItem(%s,%s)\n",item,ptr->name);
       return(true);
       }
    }
@@ -232,7 +207,7 @@ if ((sp = malloc(strlen(string)+1)) == NULL)
 
 if (CURRENTLINEPTR == NULL)   /* File is empty */
    {
-   if (*filestart == NULL)
+   if (filestart == NULL)
       {
       *filestart = ip;
       ip->next = NULL;
@@ -817,7 +792,7 @@ for (ip = *list; ip != NULL; ip=ip->next)
       if ((ip->name = malloc(strlen(buff)+1)) == NULL)
          {
          CfLog(cferror,"malloc in CommentItemStarting\n","");
-         FatalError("");
+         FatalError("");;
          }
 
       strcpy(ip->name,buff);
@@ -871,7 +846,7 @@ for (ip = *list; ip != NULL; ip=ip->next)
       if ((ip->name = malloc(strlen(buff)+1)) == NULL)
          {
          CfLog(cferror,"malloc in CommentItemContaining\n","");
-         FatalError("");
+         FatalError("");;
          }
 
       strcpy(ip->name,buff);
@@ -938,7 +913,7 @@ for (ip = *list; ip != NULL; ip=ip->next)
          if ((ip->name = malloc(strlen(buff)+1)) == NULL)
             {
             CfLog(cferror,"malloc in CommentItemContaining\n ","");
-            FatalError("");
+            FatalError("");;
             }
          
          strcpy(ip->name,buff);
@@ -1403,7 +1378,6 @@ for (ip = *liststart; ip != NULL; ip=ip->next)
          i += strlen(replace)-1;
          
          memcpy(&rx,&rxcache,sizeof(rx)); /* To fix a bug on some implementations where rx gets emptied */
-
          if (regexec(&rx,sp,1,&match,0) == 0)
             {
             start = sp + match.rm_so;
@@ -1421,31 +1395,12 @@ for (ip = *liststart; ip != NULL; ip=ip->next)
    
    if (regexec(&rx,VBUFF,1,&matchcheck,0) == 0)
       {
-      if ((matchcheck.rm_so == 0) && (matchcheck.rm_eo == strlen(VBUFF)))
-         {
-         Verbose("Edit operation replaces [%s] with whole line [%s], so it appears convergent.\n",search,replace);
-         }
-      else
-         {
-         if (EDITGROUPLEVEL <= 0)
-            {
-            snprintf(OUTPUT,CF_BUFSIZE*2,"WARNING: Non-convergent edit operation ReplaceAll [%s] With [%s]",search,replace);
-            CfLog(cferror,OUTPUT,"");
-            snprintf(OUTPUT,CF_BUFSIZE*2,"Line begins [%.40s]",ip->name);
-            CfLog(cferror,OUTPUT,"");
-            CfLog(cferror,"Replacement matches search string and will thus replace every time - edit was not done","");
-            return false;
-            }
-         else
-            {
-            /* This needs to be a smarter check - to see if the group fixes the problem or not*/
-            snprintf(OUTPUT,CF_BUFSIZE*2,"WARNING: Possible non-convergent edit operation ReplaceAll [%s] With [%s]",search,replace);
-            CfLog(cfinform,OUTPUT,"");
-            snprintf(OUTPUT,CF_BUFSIZE*2,"Line begins [%.40s]",ip->name);
-            CfLog(cfinform,OUTPUT,"");
-            CfLog(cfinform,"Replacement, although predicated, could match search string and might thus replace every time - edit was not done","");
-            }
-         }
+      snprintf(OUTPUT,CF_BUFSIZE*2,"WARNING: Non-convergent edit operation ReplaceAll [%s] With [%s]",replace,search);
+      CfLog(cferror,OUTPUT,"");
+      snprintf(OUTPUT,CF_BUFSIZE*2,"Line begins [%.40s]",ip->name);
+      CfLog(cferror,OUTPUT,"");
+      CfLog(cferror,"Replacement matches search string and will thus replace every time - edit was not done","");
+      return false;
       }
 
    CURRENTLINEPTR = ip;
@@ -1891,21 +1846,10 @@ for (ip = *filestart; ip != NULL; ip=ip->next, linenum++)
 void AppendToLine(struct Item *current,char *text,char *filename)
 
 { char *new;
- int wasblank = false;
 
-if (current == NULL)
+if (strstr(current->name,text))
    {
-   FatalError("Software error -- attempt to append to a non-existent line (shouldn't happen)");
-   }
- 
-if (current->name != NULL)
-   {
-   wasblank = false;
-   
-   if (strstr(current->name,text))
-      {
-      return;
-      }
+   return;
    }
 
 EditVerbose("Appending %s to line %-60s...\n",text,current->name);
@@ -1915,11 +1859,7 @@ strcpy(new,current->name);
 strcat(new,text);
 NUMBEROFEDITS++;
 
-if (!wasblank)
-   {
-   free(current->name);
-   }
-
+free(current->name);
 current->name = new;
 }
 
@@ -1931,11 +1871,6 @@ int CfRegcomp(regex_t *preg,const char *regex,int cflags)
 { int code;
   char buf[CF_BUFSIZE];
 
-if (regex == NULL || *regex == '\0')
-   {
-   return -1;
-   }
-
 code = regcomp(preg,regex,cflags);
  
 if (code != 0)
