@@ -42,18 +42,9 @@ int LoadItemList(struct Item **liststart,char *file)
 
 if (stat(file,&statbuf) == -1)
    {
-   if (DONTDO)
-      {
-      snprintf(OUTPUT,CF_BUFSIZE*2,"Currently no file %s to edit\n",file);
-      CfLog(cfverbose,OUTPUT,"");
-      return false;
-      }
-   else
-      {
-      snprintf(OUTPUT,CF_BUFSIZE*2,"Couldn't stat %s - no file to edit\n",file);
-      CfLog(cfverbose,OUTPUT,"stat");
-      return false;
-      }
+   snprintf(OUTPUT,CF_BUFSIZE*2,"Couldn't stat %s\n",file);
+   CfLog(cfverbose,OUTPUT,"stat");
+   return false;
    }
 
 if ((EDITFILESIZE != 0) &&(statbuf.st_size > EDITFILESIZE))
@@ -73,7 +64,7 @@ if (! S_ISREG(statbuf.st_mode))
 if ((fp = fopen(file,"r")) == NULL)
    {
    snprintf(OUTPUT,CF_BUFSIZE*2,"Couldn't read file %s for editing\n",file);
-   CfLog(cfinform,OUTPUT,"fopen");
+   CfLog(cferror,OUTPUT,"fopen");
    return false;
    }
 
@@ -163,7 +154,7 @@ if (IMAGEBACKUP != 'n')
       if (rename(file,backup) == -1)
          {
          snprintf(OUTPUT,CF_BUFSIZE*2,"Error while renaming backup %s\n",file);
-         CfLog(cfverbose,OUTPUT,"rename ");
+         CfLog(cferror,OUTPUT,"rename ");
          unlink(new);
          return false;
          }
@@ -177,7 +168,7 @@ if (IMAGEBACKUP != 'n')
 if (rename(new,file) == -1)
    {
    snprintf(OUTPUT,CF_BUFSIZE*2,"Error while renaming %s\n",file);
-   CfLog(cfverbose,OUTPUT,"rename");
+   CfLog(cferror,OUTPUT,"rename");
    return false;
    }       
 
@@ -197,8 +188,6 @@ int CompareToFile(struct Item *liststart,char *file)
 { FILE *fp;
   struct stat statbuf;
   struct Item *ip = liststart;
-  unsigned char *finmem = NULL, fdata;
-  unsigned long fip = 0, tmplen, idx;
 
 Debug("CompareToFile(%s)\n",file);
 
@@ -211,55 +200,52 @@ if (liststart == NULL)
    {
    return false;
    }
-
-for (ip = liststart; ip != NULL; ip=ip->next)
-   {
-   tmplen = strlen(ip->name);
-   if ((finmem = realloc(finmem, fip+tmplen+1)) == NULL)
-	{
-	Debug("CompareToFile(%s): can't realloc() memory\n",file);
-	free(finmem);
-	return false;
-	}
-   memcpy(finmem+fip, ip->name, tmplen);
-   fip += tmplen;
-   *(finmem+fip++) = '\n';
-   }
-
-if (statbuf.st_size != fip)
-   {
-   Debug("CompareToFile(%s): sizes are different: MEM:(%u) FILE:(%u)\n",file, fip, statbuf.st_size);
-   free(finmem);
-   return false;
-   }
  
 if ((fp = fopen(file,"r")) == NULL)
    {
    snprintf(OUTPUT,CF_BUFSIZE*2,"Couldn't read file %s for editing\n",file);
    CfLog(cferror,OUTPUT,"fopen");
-   free(finmem);
    return false;
    }
 
-for (idx = 0; idx < fip; idx++)
+memset(VBUFF,0,CF_BUFSIZE);
+
+for (ip = liststart; ip != NULL; ip=ip->next)
    {
-   if (fread(&fdata, 1, 1, fp) != 1)
-	{
-	Debug("CompareToFile(%s): non-zero fread() before file-in-mem finished at %u-th byte MEM:(0x%x/%c)\n",file, idx, *(finmem+idx), *(finmem+idx));
-	free(finmem);
-	fclose(fp);
-	return false;
-	}
-   if (fdata != *(finmem+idx))
-	{
-	Debug("CompareToFile(%s): difference found at %u-th byte MEM:(0x%x/%c) != FILE:(0x%x/%c)\n",file, idx, *(finmem+idx), *(finmem+idx), fdata, fdata);
-	free(finmem);
-	fclose(fp);
-	return false;
-	}
+   ReadLine(VBUFF,CF_BUFSIZE,fp);
+   
+   if (feof(fp) && (ip->next != NULL))
+      {
+      fclose(fp);
+      return false;
+      }
+
+   if ((ip->name == NULL) && (strlen(VBUFF) == 0))
+      {
+      continue;
+      }
+   
+   if (ip->name == NULL)
+      {
+      fclose(fp);
+      return false;
+      }
+   
+   if (strcmp(ip->name,VBUFF) != 0)
+      {
+      fclose(fp);
+      return false;
+      }
+
+   VBUFF[0] = '\0';
+   }
+
+if (!feof(fp) && (ReadLine(VBUFF,CF_BUFSIZE,fp) != false))
+   {
+   fclose(fp);
+   return false;
    }
 
-free(finmem);
 fclose(fp);
 return (true);
 }
