@@ -69,12 +69,18 @@
 
 DB *DBP;
 
+struct LockData
+   {
+   pid_t pid;
+   time_t time;
+   };
+
 /********************************************************************/
 
 void PreLockState()
 
 {
-strcpy(CFLOCK,"pre-lock-state");
+ strcpy(CFLOCK,"pre-lock-state");
 }
 
 /********************************************************************/
@@ -82,7 +88,7 @@ strcpy(CFLOCK,"pre-lock-state");
 void SaveExecLock()
 
 {
-strcpy(SAVELOCK,CFLOCK);
+ strcpy(SAVELOCK,CFLOCK);
 }
 
 
@@ -91,42 +97,7 @@ strcpy(SAVELOCK,CFLOCK);
 void RestoreExecLock()
 
 {
-strcpy(CFLOCK,SAVELOCK);
-}
-
-/********************************************************************/
-
-void WritePID(char *filename)
-
-{ FILE *fp;
-  char *sp;
-
-if (!IsPrivileged())
-   {
-   Verbose("\n(Non privileged user...)\n\n");
-   
-   if ((sp = getenv("HOME")) == NULL)
-      {
-      FatalError("You do not have a HOME variable pointing to your home directory");
-      }
-   
-   snprintf(PIDFILE,CF_BUFSIZE-1,"%s/%s",sp,filename);
-   }
-else
-   {
-   snprintf(PIDFILE,CF_BUFSIZE-1,"%s/%s",WORKDIR,filename);
-   }
-
-if ((fp = fopen(PIDFILE,"w")) == NULL)
-   {
-   snprintf(OUTPUT,CF_BUFSIZE,"Could not write to PID file %s\n",filename);
-   CfLog(cfinform,OUTPUT,"fopen");
-   return;
-   }
-
-fprintf(fp,"%d\n",getpid());
-
-fclose(fp);
+ strcpy(CFLOCK,SAVELOCK);
 }
 
 /********************************************************************/
@@ -134,41 +105,23 @@ fclose(fp);
 void HandleSignal(int signum)
  
 {
-if (signum != SIGCHLD)
-   {
-   snprintf(OUTPUT,CF_BUFSIZE*2,"Received signal %d (%s) while doing [%s]",signum,SIGNALS[signum],CFLOCK);
-   Chop(OUTPUT);
-   CfLog(cferror,OUTPUT,"");
-   snprintf(OUTPUT,CF_BUFSIZE*2,"Logical start time %s ",ctime(&CFSTARTTIME));
-   Chop(OUTPUT);
-   CfLog(cferror,OUTPUT,"");
-   snprintf(OUTPUT,CF_BUFSIZE*2,"This sub-task started really at %s\n",ctime(&CFINITSTARTTIME));
-   CfLog(cferror,OUTPUT,"");
-   fflush(stdout);
-   
-   if (signum == SIGTERM || signum == SIGINT || signum == SIGHUP || signum == SIGSEGV || signum == SIGKILL|| signum == SIGPIPE)
-      {
-      unlink(PIDFILE);
-      ReleaseCurrentLock();
-      closelog();
-      exit(0);
-      }
-   else if (signum == SIGUSR1)
-	  {
-	  DEBUG= true;
-	  D2= true;
-	  }
-   else if (signum == SIGUSR2)
-	  {
-	  DEBUG= false;
-	  D2= false;
-	  }
-   else /* zombie cleanup - how hard does it have to be? */
-	  {
-	  }
+snprintf(OUTPUT,CF_BUFSIZE*2,"Received signal %d (%s) while doing [%s]",signum,SIGNALS[signum],CFLOCK);
+Chop(OUTPUT);
+CfLog(cferror,OUTPUT,"");
+snprintf(OUTPUT,CF_BUFSIZE*2,"Logical start time %s ",ctime(&CFSTARTTIME));
+Chop(OUTPUT);
+CfLog(cferror,OUTPUT,"");
+snprintf(OUTPUT,CF_BUFSIZE*2,"This sub-task started really at %s\n",ctime(&CFINITSTARTTIME));
 
-   /* Reset the signal handler */
-   signal(signum,HandleSignal);
+CfLog(cferror,OUTPUT,"");
+
+fflush(stdout);
+
+if (signum == SIGTERM || signum == SIGINT || signum == SIGHUP || signum == SIGSEGV || signum == SIGKILL)
+   {
+   ReleaseCurrentLock();
+   closelog();
+   exit(0);
    }
 }
 
@@ -193,6 +146,8 @@ if ((errno = db_create(&DBP,NULL,0)) != 0)
    return;
    }
 
+
+
 #ifdef CF_OLD_DB
 if ((errno = DBP->open(DBP,LOCKDB,NULL,DB_BTREE,DB_CREATE,0644)) != 0)
 #else
@@ -225,10 +180,9 @@ DBP->close(DBP,0);
 int GetLock(char *operator,char *operand,int ifelapsed,int expireafter,char *host,time_t now)
 
 { unsigned int pid;
-  int i, err, sum=0;
+  int err; 
   time_t lastcompleted = 0, elapsedtime;
-  char c_operator[CF_BUFSIZE],c_operand[CF_BUFSIZE],cc_operator[CF_BUFSIZE],cc_operand[CF_BUFSIZE];
-  
+
 if (IGNORELOCK)
    {
    return true;
@@ -246,28 +200,11 @@ if (now == 0)
 Debug("GetLock(%s,%s,time=%d), ExpireAfter=%d, IfElapsed=%d\n",operator,operand,now,expireafter,ifelapsed);
 
 memset(CFLOCK,0,CF_BUFSIZE);
-memset(CFLAST,0,CF_BUFSIZE);
-
-/* Make local copy in case CanonifyName called - not re-entrant - best fix for now */
-
-strncpy(c_operator,operator,CF_BUFSIZE-1);
-strncpy(c_operand,operand,CF_BUFSIZE-1);
-strncpy(cc_operator,CanonifyName(c_operator),CF_BUFSIZE-1);
-strncpy(cc_operand,CanonifyName(c_operand),CF_BUFSIZE-1);
-
-for (i = 0; operator[i] != '\0'; i++)
-    {
-    sum = (CF_MACROALPHABET * sum + operator[i]) % CF_HASHTABLESIZE;
-    }
-
-for (i = 0; operand[i] != '\0'; i++)
-    {
-    sum = (CF_MACROALPHABET * sum + operand[i]) % CF_HASHTABLESIZE;
-    }
-
+memset(CFLAST,0,CF_BUFSIZE); 
+ 
 snprintf(CFLOG,CF_BUFSIZE,"%s/cfengine.%.40s.runlog",VLOGDIR,host);
-snprintf(CFLOCK,CF_BUFSIZE,"lock.%.100s.%.40s.%s.%.100s_%d",VCANONICALFILE,host,cc_operator,cc_operand,sum);
-snprintf(CFLAST,CF_BUFSIZE,"last.%.100s.%.40s.%s.%.100s_%d",VCANONICALFILE,host,cc_operator,cc_operand,sum);
+snprintf(CFLOCK,CF_BUFSIZE,"lock.%.100s.%.40s.%s.%.100s",VCANONICALFILE,host,operator,operand);
+snprintf(CFLAST,CF_BUFSIZE,"last.%.100s.%.40s.%s.%.100s",VCANONICALFILE,host,operator,operand);
  
 if (strlen(CFLOCK) > MAX_FILENAME)
    {
@@ -286,14 +223,14 @@ elapsedtime = (time_t)(now-lastcompleted) / 60;
 
 if (elapsedtime < 0)
    {
-   snprintf(OUTPUT,CF_BUFSIZE*2,"Another cfengine seems to have done [%s.%s] since I started (elapsed=%d)\n",operator,operand,elapsedtime);
+   snprintf(OUTPUT,CF_BUFSIZE*2,"Another cfengine seems to have done %s.%s since I started\n",operator, operand);
    CfLog(cfverbose,OUTPUT,"");
    return false;
    }
 
 if (elapsedtime < ifelapsed)
    {
-   snprintf(OUTPUT,CF_BUFSIZE*2,"Nothing promised for [%s.%s] (%u/%u minutes elapsed)\n",operator,operand,elapsedtime,ifelapsed);
+   snprintf(OUTPUT,CF_BUFSIZE*2,"Nothing scheduled for %s.%s (%u/%u minutes elapsed)\n",operator,operand,elapsedtime,ifelapsed);
    CfLog(cfverbose,OUTPUT,"");
    return false;
    }
@@ -307,7 +244,7 @@ if (lastcompleted != 0)
    {
    if (elapsedtime >= expireafter)
       {
-      snprintf(OUTPUT,CF_BUFSIZE*2,"Lock %s expired (after %u/%u minutes)\n",CFLOCK,elapsedtime,expireafter);
+      snprintf(OUTPUT,CF_BUFSIZE*2,"Lock %s expired...(after %u/%u minutes)\n",CFLOCK,elapsedtime,expireafter);
       CfLog(cfinform,OUTPUT,"");
       
       pid = GetLockPid(CFLOCK);
@@ -323,6 +260,14 @@ if (lastcompleted != 0)
          
          err = 0;
          
+/*  if (((err = kill(pid,SIGCONT)) == -1) && (errno != ESRCH))
+    {
+    sleep(3);
+    err=0;
+    
+    Does anyone remember who put this in or why it was here?
+*/
+         
          if ((err = kill(pid,SIGINT)) == -1)
             {
             sleep(1);
@@ -521,42 +466,10 @@ if (PutLock(CFLOCK) == -1)
    {
    snprintf(OUTPUT,CF_BUFSIZE*2,"GetLock: can't open new lock file %s\n",CFLOCK);
    CfLog(cferror,OUTPUT,"fopen");
-   FatalError("");
+   FatalError("");;
    }
 }
 
-/**********************************************************************/
-
-void SetSignals()
-
-
-{ int i;
-
- SIGNALS[SIGHUP] = strdup("SIGHUP");
- SIGNALS[SIGINT] = strdup("SIGINT");
- SIGNALS[SIGTRAP] = strdup("SIGTRAP");
- SIGNALS[SIGKILL] = strdup("SIGKILL");
- SIGNALS[SIGPIPE] = strdup("SIGPIPE");
- SIGNALS[SIGCONT] = strdup("SIGCONT");
- SIGNALS[SIGABRT] = strdup("SIGABRT");
- SIGNALS[SIGSTOP] = strdup("SIGSTOP");
- SIGNALS[SIGQUIT] = strdup("SIGQUIT");
- SIGNALS[SIGTERM] = strdup("SIGTERM");
- SIGNALS[SIGCHLD] = strdup("SIGCHLD");
- SIGNALS[SIGUSR1] = strdup("SIGUSR1");
- SIGNALS[SIGUSR2] = strdup("SIGUSR2");
- SIGNALS[SIGBUS] = strdup("SIGBUS");
- SIGNALS[SIGSEGV] = strdup("SIGSEGV");
-
- for (i = 0; i < highest_signal; i++)
-    {
-    if (SIGNALS[i] == NULL)
-       {
-       SIGNALS[i] = strdup("NOSIG");
-       }
-    }
-}
-
 
 /************************************************************************/
 /* Level 3                                                              */
