@@ -32,110 +32,24 @@
 #include "cf.extern.h"
 
 
-/*******************************************************************/
-
-void CheckForMethod()
-
-{ struct Item *ip;
-  int i = 0;
-
-if (strcmp(METHODNAME,"cf-nomethod") == 0)
-   {
-   return;
-   }
-
-if (! MINUSF)
-   {
-   FatalError("Input files claim to be a module but this is a parent process\n");
-   }
-
-Verbose("\n++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++\n+\n");
-Verbose("+ This is a private method: %s\n",METHODNAME);
-
-if (METHODARGS == NULL)
-   {
-   FatalError("This module was declared a method but no MethodParameters declaration was given");
-   }
-else
-   {
-   Verbose("+\n+ Method argument prototype = (");
-
-   i = 1;
-   
-   for (ip = METHODARGS; ip != NULL; ip=ip->next)
-      {
-      i++;
-      }
-
-   METHODARGV = (char **) malloc(sizeof(char *) * i); 
-   
-   i = 0;
-
-   for (ip = METHODARGS; ip != NULL; ip=ip->next)
-      {
-      /* Fill this temporarily with the formal parameters */
-      METHODARGV[i++] = ip->name;
-      Verbose("%s ",ip->name);
-      }
-
-   METHODARGC = i;
-   
-   Verbose(")\n+\n");
-   }
- 
-Verbose("++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++\n\n");
-
-Verbose("Looking for a data package for this method (%s)\n",METHODMD5);
-
-if (!ChildLoadMethodPackage(METHODNAME,METHODMD5))
-   {
-   snprintf(OUTPUT,CF_BUFSIZE,"No valid incoming request to execute method (%s)\n",METHODNAME);
-   CfLog(cfinform,OUTPUT,"");
-   exit(0);
-   }
-
-Debug("Method package looks ok -- proceeding\n"); 
-}
-
-/*******************************************************************/
-
-void CheckMethodReply()
-
-{
-if (ScopeIsMethod())
-   {
-   if (strlen(METHODREPLYTO) > 0)
-      {
-      Banner("Method reply message");
-      DispatchMethodReply();
-      }
-   }
-}
-
 /*****************************************************************************/
 
 void DispatchNewMethod(struct Method *ptr)
 
 { struct Item *ip;
   char label[CF_BUFSIZE]; 
-  char serverip[CF_SMALLBUF],clientip[CF_SMALLBUF];
+  char serverip[64],clientip[64];
 
 serverip[0] = clientip[0] = '\0';
   
 for (ip = ptr->servers; ip != NULL; ip=ip->next)
-   {
-   if (strcmp(ip->name,"none") == 0)
-      {
-      Verbose("Method with no server is a no-op\n");
-      continue;
-      }
-   
+   {  
    if ((strcmp(ip->name,"localhost") == 0) || (strcmp(ip->name,"::1") == 0) || (strcmp(ip->name,"127.0.0.1") == 0))
       {
       Verbose("\nDispatch method localhost:%s to %s/rpc_in\n",ptr->name,VLOCKDIR);
 
       ptr->invitation = 'y';
-      snprintf(label,CF_BUFSIZE-1,"%s/rpc_in/localhost+localhost+%s+%s",VLOCKDIR,ptr->name,ChecksumPrint('m',ptr->digest));
+      snprintf(label,CF_BUFSIZE-1,"%s/rpc_in/localhost_localhost_%s_%s",VLOCKDIR,ptr->name,ChecksumPrint('m',ptr->digest));
       EncapsulateMethod(ptr,label);
       }
    else
@@ -159,7 +73,7 @@ for (ip = ptr->servers; ip != NULL; ip=ip->next)
          }
       
       Verbose("Hailing server (%s) from our calling id %s\n",serverip,VFQNAME);
-      snprintf(label,CF_BUFSIZE-1,"%s/rpc_out/%s+%s+%s+%s",VLOCKDIR,clientip,serverip,ptr->name,ChecksumPrint('m',ptr->digest));
+      snprintf(label,CF_BUFSIZE-1,"%s/rpc_out/%s_%s_%s_%s",VLOCKDIR,clientip,serverip,ptr->name,ChecksumPrint('m',ptr->digest));
       EncapsulateMethod(ptr,label);
       Debug("\nDispatched method %s to %s/rpc_out\n",label,VLOCKDIR);
       }
@@ -181,6 +95,7 @@ struct Item *GetPendingMethods(int state)
   
 Debug("GetPendingMethods(%d) in (%s/rpc_in)\n",state,VLOCKDIR);
 
+
 Debug("Processing applications...\n");
  
 snprintf(filename,CF_MAXVARSIZE-1,"%s/rpc_in",VLOCKDIR);
@@ -226,15 +141,15 @@ for (dirp = readdir(dirh); dirp != NULL; dirp = readdir(dirh))
 
    for (ip = IPADDRESSES; ip != NULL; ip = ip->next)
       {
-      if (strcmp(server,ip->name) == 0 || strcmp(client,ip->name) == 0)
+      if (strcmp(server,ip->name) == 0)
          {
          belongs_here = true;
-         }      
-      }
-
-   if (strcmp(server,"localhost") == 0)
-      {
-      belongs_here = true;
+         }
+      
+      if (strcmp(server,"localhost") == 0)
+         {
+         belongs_here = true;
+         }
       }
    
    if (!belongs_here)
@@ -275,7 +190,7 @@ for (dirp = readdir(dirh); dirp != NULL; dirp = readdir(dirh))
    
    if (mp = IsDefinedMethod(ip->name,digeststring))
       {
-      if (IsItemIn(mp->servers,"localhost") || IsItemIn(mp->servers,IPString2Hostname(server)) || IsItemIn(mp->servers,IPString2UQHostname(server)) || IsItemIn(mp->servers,VIPADDRESS) || IsItemIn(mp->servers,server) || IsItemIn(mp->servers,VFQNAME) || IsItemIn(mp->servers,VUQNAME))
+      if (IsItemIn(mp->servers,"localhost") || IsItemIn(mp->servers,IPString2Hostname(server)) || IsItemIn(mp->servers,VIPADDRESS) || IsItemIn(mp->servers,server) || IsItemIn(mp->servers,VFQNAME))
          {
          if (state == CF_METHODREPLY)
             {
@@ -290,6 +205,7 @@ for (dirp = readdir(dirh); dirp != NULL; dirp = readdir(dirh))
             else
                {
                Verbose("No local approval in methods list on this host for received request (%s) if (%s)\n",dirp->d_name,mp->classes);
+               unlink(path);
                continue;
                }
             }
@@ -299,7 +215,6 @@ for (dirp = readdir(dirh); dirp != NULL; dirp = readdir(dirh))
       else
          {
          Verbose("No local method match on this host for received request (%s) for host %s=%s=%s in\n",dirp->d_name,server,IPString2Hostname(server),VIPADDRESS);
-
          if (VERBOSE)
             {
             DebugListItemList(mp->servers);
@@ -331,7 +246,7 @@ void EvaluatePendingMethod(char *methodname)
 
 { struct Method *ptr;
   char line[CF_BUFSIZE];
-  char options[CF_BUFSIZE];
+  char options[32];
   char client[CF_BUFSIZE],server[CF_BUFSIZE],name[CF_BUFSIZE],digeststring[CF_BUFSIZE],extra[CF_BUFSIZE];
   char *sp;
   char execstr[CF_BUFSIZE];
@@ -351,6 +266,7 @@ else
    Debug("Nothing to do for %s\n",methodname);
    return;
    }
+ 
 
 options[0] = '\0';
 
@@ -359,11 +275,6 @@ if (INFORM)
    strcat(options,"-I ");
    }
 
-if (IGNORELOCK)
-   {
-   strcat(options,"-K ");
-   }
-
 if (VERBOSE)
    {
    strcat(options,"-v ");
@@ -380,7 +291,7 @@ strcat(options,"-Z ");
 strcat(options,digeststring);
 strcat(options," ");
 
-snprintf(execstr,CF_BUFSIZE-1,"%s/bin/cfagent -f %s %s",CFWORKDIR,GetMethodFilename(ptr),options);
+snprintf(execstr,CF_BUFSIZE-1,"%s/bin/cfagent -f %s %s",WORKDIR,GetMethodFilename(ptr),options);
 
 Verbose("Trying %s\n",execstr);
  
@@ -392,7 +303,7 @@ if (IsExcluded(ptr->classes))
  
 ResetOutputRoute(ptr->log,ptr->inform);
 
-if (!GetLock(ASUniqueName("method-exec"),CanonifyName(methodname),ptr->ifelapsed,ptr->expireafter,VUQNAME,CFSTARTTIME))
+if (!GetLock(ASUniqueName("method-exec"),CanonifyName(ptr->name),ptr->ifelapsed,ptr->expireafter,VUQNAME,CFSTARTTIME))
    {
    return;
    }
@@ -484,7 +395,7 @@ return;
 int ParentLoadReplyPackage(char *methodname)
 
 { char client[CF_MAXVARSIZE],server[CF_BUFSIZE],name[CF_BUFSIZE],buf[CF_BUFSIZE];
-  char line[CF_BUFSIZE],type[CF_SMALLBUF],arg[CF_BUFSIZE], **methodargv = NULL;
+  char line[CF_BUFSIZE],type[64],arg[CF_BUFSIZE], **methodargv = NULL;
   char basepackage[CF_BUFSIZE],digeststring[CF_BUFSIZE],extra[CF_MAXVARSIZE];
   char *sp;
   struct Item *ip;
@@ -505,11 +416,12 @@ for (sp = name; *sp != '\0'; sp++)
       }
    }
 
+
 if ((mp = IsDefinedMethod(name,digeststring)) == NULL)
    {
    return false;
    }
-
+ 
 i = 1;
    
 for (ip = mp->return_vars; ip != NULL; ip=ip->next)
@@ -543,19 +455,18 @@ if (argnum != methodargc)
 
 snprintf(buf,CF_BUFSIZE,"rpc_in_%s_%s",methodname,digeststring);
 
-if (IsDefinedClass(CanonifyName(buf)))
+if (IsExcluded(buf))
    {
-   free((char *)methodargv);
    return false;
    }
 else
    {
    Debug("No further replies can be accepted yet (tot %d mins)\n",mp->ifelapsed);
-   AddPersistentClass(CanonifyName(buf),mp->ifelapsed,cfpreserve);
+   AddPersistentClass(buf,mp->ifelapsed,cfpreserve);
    }
 
 argnum = 0;
-Verbose("Opening bundle %s\n",methodname);
+Debug("Opening bundle %s\n",methodname);
  
 if ((fp = fopen(basepackage,"r")) == NULL)
    {
@@ -627,7 +538,6 @@ if ((fp = fopen(basepackage,"r")) == NULL)
                  {
                  snprintf(OUTPUT,CF_BUFSIZE,"could not open argument bundle %s\n",arg);
                  CfLog(cferror,OUTPUT,"fopen");
-                 free((char *)methodargv);
                  return false;
                  }
               
@@ -635,7 +545,6 @@ if ((fp = fopen(basepackage,"r")) == NULL)
                  {
                  snprintf(OUTPUT,CF_BUFSIZE,"Could not write to local parameter file %s\n",methodargv[argnum]);
                  CfLog(cferror,OUTPUT,"fopen");
-                 free((char *)methodargv);
                  fclose(fin);
                  return false;
                  }
@@ -725,7 +634,7 @@ return true;
 
 int ChildLoadMethodPackage(char *name,char *digeststring)
 
-{ char line[CF_BUFSIZE],type[CF_SMALLBUF],arg[CF_BUFSIZE];
+{ char line[CF_BUFSIZE],type[64],arg[CF_BUFSIZE];
   char basepackage[CF_BUFSIZE],cffilename[CF_BUFSIZE],buf[CF_BUFSIZE],ebuff[CF_EXPANDSIZE];
   char clientip[CF_BUFSIZE],ipaddress[CF_BUFSIZE];
   struct stat statbuf;
@@ -753,7 +662,8 @@ else
    strncpy(ipaddress,"localhost",63);     
    }
 
-snprintf(basepackage,CF_BUFSIZE-1,"%s/rpc_in/%s+%s+%s+%s",VLOCKDIR,clientip,ipaddress,METHODNAME,METHODMD5);
+
+snprintf(basepackage,CF_BUFSIZE-1,"%s/rpc_in/%s_%s_%s_%s",VLOCKDIR,clientip,ipaddress,METHODNAME,METHODMD5);
 
 argnum = CountAttachments(basepackage);
  
@@ -972,13 +882,13 @@ return true;
 void DispatchMethodReply()
 
 { char label[CF_BUFSIZE]; 
-  char ipaddress[CF_SMALLBUF],clientip[CF_SMALLBUF];
+  char ipaddress[64],clientip[64];
 
 Verbose("DispatchMethodReply()\n\n");
 
 if (strcmp(METHODREPLYTO,"localhost") == 0 || strcmp(METHODREPLYTO,"::1") == 0 || strcmp(METHODREPLYTO,"127.0.0.1") == 0)
    {    
-   snprintf(label,CF_BUFSIZE-1,"%s/rpc_in/localhost+localhost+%s:Reply+%s",VLOCKDIR,METHODNAME,METHODMD5);
+   snprintf(label,CF_BUFSIZE-1,"%s/rpc_in/localhost_localhost_%s:Reply_%s",VLOCKDIR,METHODNAME,METHODMD5);
    EncapsulateReply(label);
    }
 else
@@ -988,7 +898,7 @@ else
 
    Verbose("\nDispatch method %s:%s to %s/rpc_out\n",METHODREPLYTO,METHODNAME,VLOCKDIR);
 
-   snprintf(label,CF_BUFSIZE-1,"%s/rpc_out/%s+%s+%s:Reply+%s",VLOCKDIR,clientip,ipaddress,METHODNAME,METHODMD5);
+   snprintf(label,CF_BUFSIZE-1,"%s/rpc_out/%s_%s_%s:Reply_%s",VLOCKDIR,clientip,ipaddress,METHODNAME,METHODMD5);
    EncapsulateReply(label);
    }
 }
@@ -998,7 +908,7 @@ else
 
 char *GetMethodFilename(struct Method *ptr)
 
-{ char line[CF_BUFSIZE],type[CF_SMALLBUF],arg[CF_BUFSIZE];
+{ char line[CF_BUFSIZE],type[64],arg[CF_BUFSIZE];
   char basepackage[CF_BUFSIZE],cffilename[CF_BUFSIZE],ebuff[CF_EXPANDSIZE];
   static char returnfile[CF_BUFSIZE];
   FILE *fp;
@@ -1060,7 +970,7 @@ if ((fp = fopen(basepackage,"r")) == NULL)
                  snprintf(OUTPUT,CF_BUFSIZE,"SECURITY ALERT. Method (%s) source is a symbolic link",ptr->name);
                  CfLog(cferror,OUTPUT,"");
                  fclose(fp);
-                 return returnfile;
+                 continue;
                  }
               }
            
@@ -1069,7 +979,7 @@ if ((fp = fopen(basepackage,"r")) == NULL)
               snprintf(OUTPUT,CF_BUFSIZE,"Method name %s did not find package name %s",ptr->name,cffilename);
               CfLog(cfinform,OUTPUT,"stat");
               fclose(fp);
-              return returnfile;
+              continue;
               }
            
            strncpy(returnfile,cffilename,CF_MAXVARSIZE);
@@ -1212,7 +1122,7 @@ for (mp = VMETHODS; mp != NULL; mp=mp->next)
       Debug("  Comparing digests: %s=%s\n",digeststring,ChecksumPrint('m',mp->digest));
       if (strcmp(digeststring,ChecksumPrint('m',mp->digest)) == 0)
          {
-         Debug("Method %s is defined\n",name);
+         Verbose("Method %s is defined\n",name);
          return mp;
          }
       else
@@ -1335,11 +1245,11 @@ if ((fp = fopen(name,"w")) == NULL)
        {
        char correction[CF_BUFSIZE];
        snprintf(correction,CF_BUFSIZE-1,"%s/rpc_in/%s",VLOCKDIR,name+strlen(VLOCKDIR)+2+strlen("rpc_out"));
-       fprintf(fp,"%s %s+%d\n",VMETHODPROTO[cfmeth_attacharg],correction,i);
+       fprintf(fp,"%s %s_%d\n",VMETHODPROTO[cfmeth_attacharg],correction,i);
        }
     else
        {
-       fprintf(fp,"%s %s+%d\n",VMETHODPROTO[cfmeth_attacharg],name,i);
+       fprintf(fp,"%s %s_%d\n",VMETHODPROTO[cfmeth_attacharg],name,i);
        }
     }
 
@@ -1356,7 +1266,7 @@ if ((fp = fopen(name,"w")) == NULL)
  for (ip = ptr->send_args; ip != NULL; ip=ip->next)
     {
     i++;    
-    snprintf(filename,CF_BUFSIZE-1,"%s+%d",name,i);
+    snprintf(filename,CF_BUFSIZE-1,"%s_%d",name,i);
     Debug("Create arg_file %s\n",filename);
     
     if (IsBuiltinFunction(ip->name))
@@ -1526,11 +1436,11 @@ if ((fp = fopen(name,"w")) == NULL)
        {
        char correction[CF_BUFSIZE];
        snprintf(correction,CF_BUFSIZE-1,"%s/rpc_in/%s",VLOCKDIR,name+strlen(VLOCKDIR)+2+strlen("rpc_out"));
-       fprintf(fp,"%s %s+%d (%s)\n",VMETHODPROTO[cfmeth_attacharg],correction,i,expbuf);
+       fprintf(fp,"%s %s_%d (%s)\n",VMETHODPROTO[cfmeth_attacharg],correction,i,expbuf);
        }
     else
        {
-       fprintf(fp,"%s %s+%d (%s)\n",VMETHODPROTO[cfmeth_attacharg],name,i,expbuf);
+       fprintf(fp,"%s %s_%d (%s)\n",VMETHODPROTO[cfmeth_attacharg],name,i,expbuf);
        }
     }
 
@@ -1548,7 +1458,7 @@ if ((fp = fopen(name,"w")) == NULL)
  for (ip = METHODRETURNVARS; ip != NULL; ip=ip->next)
     {
     i++;    
-    snprintf(filename,CF_BUFSIZE-1,"%s+%d",name,i);
+    snprintf(filename,CF_BUFSIZE-1,"%s_%d",name,i);
     Debug("Create arg_file %s\n",filename);
     
     if (IsBuiltinFunction(ip->name))
@@ -1671,11 +1581,5 @@ server[0] = '\0';
 digeststring[0] = '\0';
 extra[0] = '\0';
  
-sscanf(name,"%1024[^+]+%1024[^+]+%1024[^+]+%[^+]+%64s",client,server,methodname,digeststring,extra);
-
-Debug("Method client -> %s\n",client);
-Debug("Method server -> %s\n",server);
-Debug("Method name -> %s\n",methodname);
-Debug("Method digeststring -> %s\n",digeststring);
-Debug("Method extra -> %s\n",extra);
+sscanf(name,"%1024[^_]_%1024[^_]_%1024[^_]_%[^_]_%64s",client,server,methodname,digeststring,extra);
 }
