@@ -22,7 +22,7 @@
   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
 
 */
- 
+
 
 /*********************************************************************/
 /*                                                                   */
@@ -44,12 +44,9 @@ Verbose("%s: Time out\n",VPREFIX);
 
 /*************************************************************************/
 
-int SendTransaction(sd,buffer,len,status)
+int SendTransaction(int sd,char *buffer,int len,char status)
 
-char *buffer,status;
-int sd,len;
-
-{ char work[bufsize];
+{ char work[CF_BUFSIZE];
   int wlen;
  
 if (len == 0) 
@@ -61,14 +58,14 @@ else
    wlen = len;
    }
     
-if (wlen > bufsize-8)
+if (wlen > CF_BUFSIZE-8)
    {
    FatalError("SendTransaction software failure");
    }
  
 snprintf(work,8,"%c %d",status,wlen);
 
-bcopy(buffer,work+8,wlen);
+memcpy(work+8,buffer,wlen);
 
 Debug("Transaction Send[%s][Packed text]\n",work); 
  
@@ -82,16 +79,13 @@ return 0;
 
 /*************************************************************************/
 
-int ReceiveTransaction(sd,buffer,more)
-
-char *buffer;
-int sd,*more;
+int ReceiveTransaction(int sd,char *buffer,int *more)
 
 { char proto[9];
-  char status;
-  unsigned int len;
+  char status = 'x';
+  unsigned int len = 0;
  
-bzero(proto,9);
+memset(proto,0,9);
 
 if (RecvSocketStream(sd,proto,8,0) == -1)   /* Get control channel */
    {
@@ -101,37 +95,47 @@ if (RecvSocketStream(sd,proto,8,0) == -1)   /* Get control channel */
 sscanf(proto,"%c %u",&status,&len);
 Debug("Transaction Receive [%s][%s]\n",proto,proto+8);
 
+if (len > CF_BUFSIZE - 8)
+   {
+   snprintf(OUTPUT,CF_BUFSIZE,"Bad transaction packet -- too long (%c %d) Proto = %s ",status,len,proto);
+   CfLog(cferror,OUTPUT,"");
+   return -1;
+   }
+
 if (strncmp(proto,"CAUTH",5) == 0)
    {
    Debug("Version 1 protocol connection attempted - no you don't!!\n");
    return -1;
    }
  
-if (more != NULL)
-   {
-   switch(status)
-      {
-      case 'm': *more = true;
-	  break;
-      default: *more = false;
-      }
-   }
+ if (more != NULL)
+    {
+    switch(status)
+       {
+       case 'm': *more = true;
+           break;
+       default: *more = false;
+       }
+    }
  
 return RecvSocketStream(sd,buffer,len,0);
 }
 
 /*************************************************************************/
  
-int RecvSocketStream(sd,buffer,toget,nothing)
- 
-int sd,toget,nothing;
-char buffer[bufsize];
+int RecvSocketStream(int sd,char buffer[CF_BUFSIZE],int toget,int nothing)
  
 { int already, got;
   static int fraction;
 
 Debug("RecvSocketStream(%d)\n",toget);
 
+if (toget > CF_BUFSIZE)
+   {
+   CfLog(cferror,"Bad software request for overfull buffer","");
+   return -1;
+   }
+ 
 for (already = 0; already != toget; already += got)
    {
    got = recv(sd,buffer+already,toget-already,0);
@@ -144,14 +148,14 @@ for (already = 0; already != toget; already += got)
  
    if (got == 0)   /* doesn't happen unless sock is closed */
       {
-      Debug("Transmission empty...\n");
+      Debug("Transmission empty or timed out...\n");
       fraction = 0;
       return already;
       }
 
    Debug("    (Concatenated %d from stream)\n",got);
 
-   if (strncmp(buffer,"AUTH",4) == 0 && (already == bufsize))
+   if (strncmp(buffer,"AUTH",4) == 0 && (already == CF_BUFSIZE))
       {
       fraction = 0;
       return already;
@@ -170,30 +174,30 @@ return toget;
  * Wed Feb 28 11:30:55 GMT 2001, Morten Hermanrud, mhe@say.no
  */
 
-int SendSocketStream(sd,buffer,tosend,flags)
-int sd,tosend,flags;
-char buffer[bufsize];
+int SendSocketStream(int sd,char buffer[CF_BUFSIZE],int tosend,int flags)
 
 { int sent,already=0;
 
 do
    {
+   Debug("Attempting to send %d bytes\n",tosend-already);
+
    sent=send(sd,buffer+already,tosend-already,flags);
    
    switch(sent)
       {
       case -1:
-	  CfLog(cfverbose,"Couldn't send","send");
-	  return -1;
+          CfLog(cfverbose,"Couldn't send","send");
+          return -1;
       default:
-	  Debug("SendSocketStream, sent %d\n",sent);
-	  already += sent;
-	  break;
+          Debug("SendSocketStream, sent %d\n",sent);
+          already += sent;
+          break;
       }
    }
-while(already < tosend);
+ while (already < tosend); 
 
-return already;
+ return already;
 }
 
 /*************************************************************************/
