@@ -42,13 +42,9 @@ int    MAXFD = 20; /* Max number of simultaneous pipes */
 
 /*****************************************************************************/
 
-FILE *cfpopensetuid(command,type,uid,gid,chdirv,chrootv)
+FILE *cfpopen(char *command,char *type)
     
-char *command, *type, *chdirv, *chrootv;
-uid_t uid;
-gid_t gid;
-
- { char arg[maxshellargs][bufsize];
+ { static char arg[CF_MAXSHELLARGS][CF_BUFSIZE];
    int i, argc, pd[2];
    char **argv;
    pid_t pid;
@@ -79,148 +75,103 @@ gid_t gid;
     {
     return NULL;
     }
-
  
  if (pid == 0)
     {
     switch (*type)
        {
        case 'r':
-
-	   close(pd[0]);        /* Don't need output from parent */
-
-	   if (pd[1] != 1)
-	      {
-	      dup2(pd[1],1);    /* Attach pp=pd[1] to our stdout */
-	      dup2(pd[1],2);    /* Merge stdout/stderr */
-	      close(pd[1]);
-	      }
-
-	   break;
-
-       case 'w':
-
-	   close(pd[1]);
-
-	   if (pd[0] != 0)
-	      {
-	      dup2(pd[0],0);
-	      close(pd[0]);
-	      }
-       }
-
-    for (i = 0; i < MAXFD; i++)
-       {
-       if (CHILD[i] > 0)
-	  {
-	  close(CHILD[i]);
-	  }
-
-       argc = SplitCommand(command,arg);
-       argv = (char **) malloc((argc+1)*sizeof(char *));
-
-       if (argv == NULL)
-	  {
-	  FatalError("Out of memory");
-	  }
-       
-       for (i = 0; i < argc; i++)
-	  {
-	  argv[i] = arg[i];
-	  }
-
-       argv[i] = (char *) NULL;
-
-       if (strlen(chrootv) != 0)
-	  {
-	  if (chroot(chrootv) == -1)
-	     {
-	     sprintf(OUTPUT,"Couldn't chroot to %s\n",chrootv);
-	     CfLog(cferror,OUTPUT,"chroot");
-	     return NULL;
-	     }
-	  }
-       
-       if (strlen(chdirv) != 0)
-	  {
-	  if (chdir(chdirv) == -1)
-	     {
-	     sprintf(OUTPUT,"Couldn't chdir to %s\n",chdirv);
-	     CfLog(cferror,OUTPUT,"chdir");
-	     return NULL;
-	     }
-	  }
            
-       if (gid != (gid_t) -1)
-	  {
-	  Verbose("Changing gid to %d\n",gid);      
-	  
-	  if (setgid(gid) == -1)
-	     {
-	     sprintf(OUTPUT,"Couldn't set gid to %d\n",gid);
-	     CfLog(cferror,OUTPUT,"setgid");
-	     return NULL;
-	     }
-	  }
-       
-       if (uid != (uid_t) -1)
-	  {
-	  Verbose("Changing uid to %d\n",uid);
-	  
-	  if (setuid(uid) == -1)
-	     {
-	     sprintf(OUTPUT,"Couldn't effective uid to %d\n",uid);
-	     CfLog(cferror,OUTPUT,"setuid");
-	     return NULL;
-	     }
-	  }
-       
-       if (execv(arg[0],argv) == -1)
-	  {
-	  sprintf(OUTPUT,"Couldn't run %s",arg[0]);
-	  CfLog(cferror,OUTPUT,"execv");
-	  }
-
-       _exit(1);
+           close(pd[0]);        /* Don't need output from parent */
+           
+           if (pd[1] != 1)
+              {
+              dup2(pd[1],1);    /* Attach pp=pd[1] to our stdout */
+              dup2(pd[1],2);    /* Merge stdout/stderr */
+              close(pd[1]);
+              }
+           
+           break;
+           
+       case 'w':
+           
+           close(pd[1]);
+           
+           if (pd[0] != 0)
+              {
+              dup2(pd[0],0);
+              close(pd[0]);
+              }
        }
+    
+    for (i = 0; i < MAXFD; i++)
+       {
+       if (CHILD[i] > 0)
+          {
+          close(i);
+          }
+       }
+    
+    argc = SplitCommand(command,arg);
+    argv = (char **) malloc((argc+1)*sizeof(char *));
+    
+    if (argv == NULL)
+       {
+       FatalError("Out of memory");
+       }
+    
+    for (i = 0; i < argc; i++)
+       {
+       argv[i] = arg[i];
+       }
+    
+    argv[i] = (char *) NULL;
+    
+    if (execv(arg[0],argv) == -1)
+       {
+       snprintf(OUTPUT,CF_BUFSIZE,"Couldn't run %s",arg[0]);
+       CfLog(cferror,OUTPUT,"execv");
+       }
+    
+    free((char *)argv);
+    _exit(1);
     }
  else
     {
     switch (*type)
        {
        case 'r':
-
-	   close(pd[1]);
-	   
-	   if ((pp = fdopen(pd[0],type)) == NULL)
-	      {
-	      return NULL;
-	      }
-	   break;
-	   
+           
+           close(pd[1]);
+           
+           if ((pp = fdopen(pd[0],type)) == NULL)
+              {
+              return NULL;
+              }
+           break;
+           
        case 'w':
-
-	   close(pd[0]);
-	   
-	   if ((pp = fdopen(pd[1],type)) == NULL)
-	      {
-	      return NULL;
-	      }
+           
+           close(pd[0]);
+           
+           if ((pp = fdopen(pd[1],type)) == NULL)
+              {
+              return NULL;
+              }
        }
-
+    
     CHILD[fileno(pp)] = pid;
     return pp;
     }
-    return NULL; /* cannot reach here */
+ 
+ return NULL; /* Cannot reach here */
  }
 
 /*****************************************************************************/
 
-FILE *cfpopen(command,type)
+FILE *cfpopensetuid(char *command,char *type,uid_t uid,gid_t gid,char *chdirv,char *chrootv)
     
-char *command, *type;
-
- { char arg[maxshellargs][bufsize];
+ { static char arg[CF_MAXSHELLARGS][CF_BUFSIZE];
    int i, argc, pd[2];
    char **argv;
    pid_t pid;
@@ -251,302 +202,76 @@ char *command, *type;
     {
     return NULL;
     }
- 
+
  if (pid == 0)
     {
     switch (*type)
        {
        case 'r':
-
-	   close(pd[0]);        /* Don't need output from parent */
-
-	   if (pd[1] != 1)
-	      {
-	      dup2(pd[1],1);    /* Attach pp=pd[1] to our stdout */
-	      dup2(pd[1],2);    /* Merge stdout/stderr */
-	      close(pd[1]);
-	      }
-
-	   break;
-
+           
+           close(pd[0]);        /* Don't need output from parent */
+           
+           if (pd[1] != 1)
+              {
+              dup2(pd[1],1);    /* Attach pp=pd[1] to our stdout */
+              dup2(pd[1],2);    /* Merge stdout/stderr */
+              close(pd[1]);
+              }
+           
+           break;
+           
        case 'w':
-
-	   close(pd[1]);
-
-	   if (pd[0] != 0)
-	      {
-	      dup2(pd[0],0);
-	      close(pd[0]);
-	      }
+           
+           close(pd[1]);
+           
+           if (pd[0] != 0)
+              {
+              dup2(pd[0],0);
+              close(pd[0]);
+              }
        }
-
-    for (i = 0; i < MAXFD; i++)
-       {
-       if (CHILD[i] > 0)
-	  {
-	  close(CHILD[i]);
-	  }
-
-       argc = SplitCommand(command,arg);
-       argv = (char **) malloc((argc+1)*sizeof(char *));
-
-       if (argv == NULL)
-	  {
-	  FatalError("Out of memory");
-	  }
-       
-       for (i = 0; i < argc; i++)
-	  {
-	  argv[i] = arg[i];
-	  }
-
-       argv[i] = (char *) NULL;
-
-       if (execv(arg[0],argv) == -1)
-	  {
-	  sprintf(OUTPUT,"Couldn't run %s",arg[0]);
-	  CfLog(cferror,OUTPUT,"execv");
-	  }
-
-       _exit(1);
-       }
-    }
- else
-    {
-    switch (*type)
-       {
-       case 'r':
-
-	   close(pd[1]);
-	   
-	   if ((pp = fdopen(pd[0],type)) == NULL)
-	      {
-	      return NULL;
-	      }
-	   break;
-	   
-       case 'w':
-
-	   close(pd[0]);
-	   
-	   if ((pp = fdopen(pd[1],type)) == NULL)
-	      {
-	      return NULL;
-	      }
-       }
-
-    CHILD[fileno(pp)] = pid;
-    return pp;
-    }
-    return NULL; /* Cannot reach here */
- }
-
-/*****************************************************************************/
-/* Shell versions of commands - not recommended for security reasons         */
-/*****************************************************************************/
-
-FILE *cfpopen_sh(command,type)
     
-char *command, *type;
-
- { char arg[maxshellargs][bufsize];
-   int i, argc, pd[2];
-   char **argv;
-   pid_t pid;
-   FILE *pp = NULL;
-
- Debug("cfpopen(%s)\n",command);
-
- if ((*type != 'r' && *type != 'w') || (type[1] != '\0'))
-    {
-    errno = EINVAL;
-    return NULL;
-    }
- 
- if (CHILD == NULL)   /* first time */
-    {
-    if ((CHILD = calloc(MAXFD,sizeof(pid_t))) == NULL)
-       {
-       return NULL;
-       }
-    }
-
- if (pipe(pd) < 0)        /* Create a pair of descriptors to this process */
-    {
-    return NULL;
-    }
-
- if ((pid = fork()) == -1)
-    {
-    return NULL;
-    }
- 
- if (pid == 0)
-    {
-    switch (*type)
-       {
-       case 'r':
-
-	   close(pd[0]);        /* Don't need output from parent */
-
-	   if (pd[1] != 1)
-	      {
-	      dup2(pd[1],1);    /* Attach pp=pd[1] to our stdout */
-	      dup2(pd[1],2);    /* Merge stdout/stderr */
-	      close(pd[1]);
-	      }
-
-	   break;
-
-       case 'w':
-
-	   close(pd[1]);
-
-	   if (pd[0] != 0)
-	      {
-	      dup2(pd[0],0);
-	      close(pd[0]);
-	      }
-       }
-
     for (i = 0; i < MAXFD; i++)
        {
        if (CHILD[i] > 0)
-	  {
-	  close(CHILD[i]);
-	  }
+          {
+          close(i);
+          }
        }
-
-    execl("/bin/sh","sh","-c",command,NULL);
-    _exit(127);
-    }
- else
-    {
-    switch (*type)
-       {
-       case 'r':
-	   
-	   close(pd[1]);
-	   
-	   if ((pp = fdopen(pd[0],type)) == NULL)
-	      {
-	      return NULL;
-	      }
-	   break;
-	   
-       case 'w':
-	   
-	   close(pd[0]);
-	   
-	   if ((pp = fdopen(pd[1],type)) == NULL)
-	      {
-	      return NULL;
-	      }
-       }
-
-    CHILD[fileno(pp)] = pid;
-    return pp;
-    }
-
-return NULL;
-}
-
-/******************************************************************************/
-
-FILE *cfpopen_shsetuid(command,type,uid,gid,chdirv,chrootv)
     
-char *command, *type, *chdirv, *chrootv;
-uid_t uid;
-gid_t gid;
-
-
- { char arg[maxshellargs][bufsize];
-   int i, argc, pd[2];
-   char **argv;
-   pid_t pid;
-   FILE *pp = NULL;
-
- Debug("cfpopen(%s)\n",command);
-
- if ((*type != 'r' && *type != 'w') || (type[1] != '\0'))
-    {
-    errno = EINVAL;
-    return NULL;
-    }
- 
- if (CHILD == NULL)   /* first time */
-    {
-    if ((CHILD = calloc(MAXFD,sizeof(pid_t))) == NULL)
+    argc = SplitCommand(command,arg);
+    argv = (char **) malloc((argc+1)*sizeof(char *));
+    
+    if (argv == NULL)
        {
-       return NULL;
+       FatalError("Out of memory");
        }
-    }
-
- if (pipe(pd) < 0)        /* Create a pair of descriptors to this process */
-    {
-    return NULL;
-    }
-
- if ((pid = fork()) == -1)
-    {
-    return NULL;
-    }
- 
- 
- if (pid == 0)
-    {
-    switch (*type)
+    
+    for (i = 0; i < argc; i++)
        {
-       case 'r':
-
-	   close(pd[0]);        /* Don't need output from parent */
-
-	   if (pd[1] != 1)
-	      {
-	      dup2(pd[1],1);    /* Attach pp=pd[1] to our stdout */
-	      dup2(pd[1],2);    /* Merge stdout/stderr */
-	      close(pd[1]);
-	      }
-
-	   break;
-
-       case 'w':
-
-	   close(pd[1]);
-
-	   if (pd[0] != 0)
-	      {
-	      dup2(pd[0],0);
-	      close(pd[0]);
-	      }
+       argv[i] = arg[i];
        }
-
-    for (i = 0; i < MAXFD; i++)
-       {
-       if (CHILD[i] > 0)
-	  {
-	  close(CHILD[i]);
-	  }
-       }
-
+    
+    argv[i] = (char *) NULL;
+    
     if (strlen(chrootv) != 0)
        {
        if (chroot(chrootv) == -1)
-	  {
-	  sprintf(OUTPUT,"Couldn't chroot to %s\n",chrootv);
-	  CfLog(cferror,OUTPUT,"chroot");
-	  return NULL;
-	  }
+          {
+          snprintf(OUTPUT,CF_BUFSIZE,"Couldn't chroot to %s\n",chrootv);
+          CfLog(cferror,OUTPUT,"chroot");
+          return NULL;
+          }
        }
-
+    
     if (strlen(chdirv) != 0)
        {
        if (chdir(chdirv) == -1)
-	  {
-	  sprintf(OUTPUT,"Couldn't chdir to %s\n",chdirv);
-	  CfLog(cferror,OUTPUT,"chroot");
-	  return NULL;
-	  }
+          {
+          snprintf(OUTPUT,CF_BUFSIZE,"Couldn't chdir to %s\n",chdirv);
+          CfLog(cferror,OUTPUT,"chdir");
+          return NULL;
+          }
        }
     
     if (gid != (gid_t) -1)
@@ -554,11 +279,11 @@ gid_t gid;
        Verbose("Changing gid to %d\n",gid);      
        
        if (setgid(gid) == -1)
-	  {
-	  sprintf(OUTPUT,"Couldn't set gid to %d\n",gid);
-	  CfLog(cferror,OUTPUT,"setgid");
-	  return NULL;
-	  }
+          {
+          snprintf(OUTPUT,CF_BUFSIZE,"Couldn't set gid to %d\n",gid);
+          CfLog(cferror,OUTPUT,"setgid");
+          return NULL;
+          }
        }
     
     if (uid != (uid_t) -1)
@@ -566,45 +291,306 @@ gid_t gid;
        Verbose("Changing uid to %d\n",uid);
        
        if (setuid(uid) == -1)
-	  {
-	  sprintf(OUTPUT,"Couldn't set uid to %d\n",uid);
-	  CfLog(cferror,OUTPUT,"setuid");
-	  return NULL;
-	  }
+          {
+          snprintf(OUTPUT,CF_BUFSIZE,"Couldn't effective uid to %d\n",uid);
+          CfLog(cferror,OUTPUT,"setuid");
+          return NULL;
+          }
        }
     
-    execl("/bin/sh","sh","-c",command,NULL);
-    _exit(127);
+    if (execv(arg[0],argv) == -1)
+       {
+       snprintf(OUTPUT,CF_BUFSIZE,"Couldn't run %s",arg[0]);
+       CfLog(cferror,OUTPUT,"execv");
+       }
+    
+    free((char *)argv);
+    _exit(1);
     }
  else
     {
     switch (*type)
        {
        case 'r':
-	   
-	   close(pd[1]);
-	   
-	   if ((pp = fdopen(pd[0],type)) == NULL)
-	      {
-	      return NULL;
-	      }
-	   break;
-	   
+           
+           close(pd[1]);
+           
+           if ((pp = fdopen(pd[0],type)) == NULL)
+              {
+              return NULL;
+              }
+           break;
+           
        case 'w':
-	   
-	   close(pd[0]);
-	   
-	   if ((pp = fdopen(pd[1],type)) == NULL)
-	      {
-	      return NULL;
-	      }
+           
+           close(pd[0]);
+           
+           if ((pp = fdopen(pd[1],type)) == NULL)
+              {
+              return NULL;
+              }
        }
-
+    
     CHILD[fileno(pp)] = pid;
     return pp;
     }
+ return NULL; /* cannot reach here */
+ }
 
-return NULL;
+
+/*****************************************************************************/
+/* Shell versions of commands - not recommended for security reasons         */
+/*****************************************************************************/
+
+FILE *cfpopen_sh(char *command,char *type)
+    
+ { int i,pd[2];
+   pid_t pid;
+   FILE *pp = NULL;
+
+ Debug("cfpopen(%s)\n",command);
+
+ if ((*type != 'r' && *type != 'w') || (type[1] != '\0'))
+    {
+    errno = EINVAL;
+    return NULL;
+    }
+ 
+ if (CHILD == NULL)   /* first time */
+    {
+    if ((CHILD = calloc(MAXFD,sizeof(pid_t))) == NULL)
+       {
+       return NULL;
+       }
+    }
+
+ if (pipe(pd) < 0)        /* Create a pair of descriptors to this process */
+    {
+    return NULL;
+    }
+
+ if ((pid = fork()) == -1)
+    {
+    return NULL;
+    }
+ 
+ if (pid == 0)
+    {
+    switch (*type)
+       {
+       case 'r':
+
+    close(pd[0]);        /* Don't need output from parent */
+
+    if (pd[1] != 1)
+       {
+       dup2(pd[1],1);    /* Attach pp=pd[1] to our stdout */
+       dup2(pd[1],2);    /* Merge stdout/stderr */
+       close(pd[1]);
+       }
+
+    break;
+
+       case 'w':
+
+    close(pd[1]);
+
+    if (pd[0] != 0)
+       {
+       dup2(pd[0],0);
+       close(pd[0]);
+       }
+       }
+    
+    for (i = 0; i < MAXFD; i++)
+       {
+       if (CHILD[i] > 0)
+          {
+          close(i);
+          }
+       }
+    
+    execl("/bin/sh","sh","-c",command,NULL);
+    _exit(1);
+    }
+ else
+    {
+    switch (*type)
+       {
+       case 'r':
+           
+           close(pd[1]);
+           
+           if ((pp = fdopen(pd[0],type)) == NULL)
+              {
+              return NULL;
+              }
+           break;
+           
+       case 'w':
+           
+           close(pd[0]);
+           
+           if ((pp = fdopen(pd[1],type)) == NULL)
+              {
+              return NULL;
+              }
+       }
+    
+    CHILD[fileno(pp)] = pid;
+    return pp;
+    }
+ 
+ return NULL;
+}
+
+/******************************************************************************/
+
+FILE *cfpopen_shsetuid(char *command,char *type,uid_t uid,gid_t gid,char *chdirv,char *chrootv)
+    
+ { int i,pd[2];
+   pid_t pid;
+   FILE *pp = NULL;
+
+ Debug("cfpopen(%s)\n",command);
+
+ if ((*type != 'r' && *type != 'w') || (type[1] != '\0'))
+    {
+    errno = EINVAL;
+    return NULL;
+    }
+ 
+ if (CHILD == NULL)   /* first time */
+    {
+    if ((CHILD = calloc(MAXFD,sizeof(pid_t))) == NULL)
+       {
+       return NULL;
+       }
+    }
+
+ if (pipe(pd) < 0)        /* Create a pair of descriptors to this process */
+    {
+    return NULL;
+    }
+
+ if ((pid = fork()) == -1)
+    {
+    return NULL;
+    }
+ 
+ 
+ if (pid == 0)
+    {
+    switch (*type)
+       {
+       case 'r':
+           
+           close(pd[0]);        /* Don't need output from parent */
+           
+           if (pd[1] != 1)
+              {
+              dup2(pd[1],1);    /* Attach pp=pd[1] to our stdout */
+              dup2(pd[1],2);    /* Merge stdout/stderr */
+              close(pd[1]);
+              }
+           
+           break;
+           
+       case 'w':
+           
+           close(pd[1]);
+           
+           if (pd[0] != 0)
+              {
+              dup2(pd[0],0);
+              close(pd[0]);
+              }
+       }
+    
+    for (i = 0; i < MAXFD; i++)
+       {
+       if (CHILD[i] > 0)
+          {
+          close(i);
+          }
+       }
+    
+    if (strlen(chrootv) != 0)
+       {
+       if (chroot(chrootv) == -1)
+          {
+          snprintf(OUTPUT,CF_BUFSIZE,"Couldn't chroot to %s\n",chrootv);
+          CfLog(cferror,OUTPUT,"chroot");
+          return NULL;
+          }
+       }
+    
+    if (strlen(chdirv) != 0)
+       {
+       if (chdir(chdirv) == -1)
+          {
+          snprintf(OUTPUT,CF_BUFSIZE,"Couldn't chdir to %s\n",chdirv);
+          CfLog(cferror,OUTPUT,"chroot");
+          return NULL;
+          }
+       }
+    
+    if (gid != (gid_t) -1)
+       {
+       Verbose("Changing gid to %d\n",gid);      
+       
+       if (setgid(gid) == -1)
+          {
+          snprintf(OUTPUT,CF_BUFSIZE,"Couldn't set gid to %d\n",gid);
+          CfLog(cferror,OUTPUT,"setgid");
+          return NULL;
+          }
+       }
+    
+    if (uid != (uid_t) -1)
+       {
+       Verbose("Changing uid to %d\n",uid);
+       
+       if (setuid(uid) == -1)
+          {
+          snprintf(OUTPUT,CF_BUFSIZE,"Couldn't set uid to %d\n",uid);
+          CfLog(cferror,OUTPUT,"setuid");
+          return NULL;
+          }
+       }
+    
+    execl("/bin/sh","sh","-c",command,NULL);
+    _exit(1);
+    }
+ else
+    {
+    switch (*type)
+       {
+       case 'r':
+           
+           close(pd[1]);
+           
+           if ((pp = fdopen(pd[0],type)) == NULL)
+              {
+              return NULL;
+              }
+           break;
+           
+       case 'w':
+           
+           close(pd[0]);
+           
+           if ((pp = fdopen(pd[1],type)) == NULL)
+              {
+              return NULL;
+              }
+       }
+    
+    CHILD[fileno(pp)] = pid;
+    return pp;
+    }
+ 
+ return NULL;
 }
 
 
@@ -612,11 +598,9 @@ return NULL;
 /* Close commands                                                             */
 /******************************************************************************/
 
-int cfpclose(pp)
+int cfpclose(FILE *pp)
 
-FILE *pp;
-
-{ int fd, status;
+{ int fd, status, wait_result;
   pid_t pid;
 
 Debug("cfpclose(pp)\n");
@@ -655,107 +639,28 @@ while(waitpid(pid,&status,0) < 0)
  return status; 
  
 #else
-      
- if (wait(&status) != pid)
+
+ while ((wait_result = wait(&status)) != pid)
     {
-    return -1;
-    }
- else
-    {
-    if (WIFSIGNALED(status))
+    if (wait_result <= 0)
        {
+       snprintf(OUTPUT,CF_BUFSIZE,"Wait for child failed\n");
+       CfLog(cfinform,OUTPUT,"wait");
        return -1;
        }
-    
-    if (! WIFEXITED(status))
-       {
-       return -1;
-       }
-
-    return (WEXITSTATUS(status));
     }
-#endif
-}
-
-/******************************************************************************/
-
-int cfpclose_def(pp,defines,elsedef)
-
-FILE *pp;
-char *defines,*elsedef;
-
-{ int fd, status;
-  pid_t pid;
-
-Debug("cfpclose(pp)\n");
-
-if (CHILD == NULL)  /* popen hasn't been called */
-   {
-   return -1;
-   }
-
-fd = fileno(pp);
-
-if ((pid = CHILD[fd]) == 0)
-   {
-   return -1;
-   }
-
-CHILD[fd] = 0;
-
-if (fclose(pp) == EOF)
-   {
-   return -1;
-   }
-
-Debug("cfpopen - Waiting for process %d\n",pid); 
-
-#ifdef HAVE_WAITPID
-
-while(waitpid(pid,&status,0) < 0)
-   {
-   if (errno != EINTR)
-      {
-      return -1;
-      }
-   }
-
-if (status == 0)
-   {
-   AddMultipleClasses(defines);
-   }
-
-return status; 
  
-#else
-      
- if (wait(&status) != pid)
+ if (WIFSIGNALED(status))
     {
     return -1;
     }
- else
+ 
+ if (! WIFEXITED(status))
     {
-    if (WIFSIGNALED(status))
-       {
-       return -1;
-       }
-    
-    if (! WIFEXITED(status))
-       {
-       return -1;
-       }
-
-    if (WEXITSTATUS(status) == 0)
-       {
-       AddMultipleClasses(defines);
-       }
-    else
-       {
-       AddMultipleClasses(elsedef);
-       }
-    
-    return (WEXITSTATUS(status));
+    return -1;
     }
+ 
+ return (WEXITSTATUS(status));
 #endif
 }
 
@@ -764,48 +669,43 @@ return status;
 /* Command exec aids                                               */
 /*******************************************************************/
 
-int SplitCommand(comm,arg)
-
-char *comm, arg[maxshellargs][bufsize];
+int SplitCommand(char *comm,char arg[CF_MAXSHELLARGS][CF_BUFSIZE])
 
 { char *sp;
-  int i = 0, j;
-  char buff[bufsize];
+  int i = 0;
 
 for (sp = comm; sp < comm+strlen(comm); sp++)
    {
-   bzero(buff,bufsize);
-
-   if (i >= maxshellargs-1)
+   if (i >= CF_MAXSHELLARGS-1)
       {
       CfLog(cferror,"Too many arguments in embedded script","");
       FatalError("Use a wrapper");
       }
-
+   
    while (*sp == ' ' || *sp == '\t')
       {
       sp++;
       }
-
+   
    switch (*sp)
       {
       case '\0': return(i-1);
-
+   
       case '\"': sscanf (++sp,"%[^\"]",arg[i]);
-                 break;
+          break;
       case '\'': sscanf (++sp,"%[^\']",arg[i]);
-                 break;
+          break;
       case '`':  sscanf (++sp,"%[^`]",arg[i]);
-	         break;
+          break;
       default:   sscanf (sp,"%s",arg[i]);
-                 break;
+          break;
       }
-
+   
    sp += strlen(arg[i]);
    i++;
    }
-
-return (i);
+ 
+ return (i);
 }
 
 
