@@ -73,76 +73,70 @@ int IdentifyForVerification(int sd,char *localip,int family)
 memset(sendbuff,0,CF_BUFSIZE);
 memset(dnsname,0,CF_BUFSIZE);
 
+
 if (!SKIPIDENTIFY && (strcmp(VDOMAIN,CF_START_DOMAIN) == 0))
    {
    CfLog(cferror,"Undefined domain name","");
    return false;
    }
-
-if (!SKIPIDENTIFY)
-   {
+ 
 /* First we need to find out the IP address and DNS name of the socket
    we are sending from. This is not necessarily the same as VFQNAME if
    the machine has a different uname from its IP name (!) This can
    happen on stupidly set up machines or on hosts with multiple
    interfaces, with different names on each interface ... */ 
-   
-   switch (family)
-      {
-      case AF_INET: len = sizeof(struct sockaddr_in);
-          break;
-#if defined(HAVE_GETADDRINFO) && !defined(DARWIN)
-      case AF_INET6: len = sizeof(struct sockaddr_in6);
-          break;
-#endif
-      default:
-          CfLog(cferror,"Software error in IdentifyForVerification","");
-      }
-   
-   if (getsockname(sd,(struct sockaddr *)&myaddr,&len) == -1)
-      {
-      CfLog(cferror,"Couldn't get socket address\n","getsockname");
-      return false;
-      }
-   
-   snprintf(localip,CF_MAX_IP_LEN-1,"%s",sockaddr_ntop((struct sockaddr *)&myaddr)); 
-   
-   Debug("Identifying this agent as %s i.e. %s, with signature %d\n",localip,VFQNAME,CFSIGNATURE);
-   
-#if defined(HAVE_GETADDRINFO) && !defined(DARWIN)
-   
-   if ((err=getnameinfo((struct sockaddr *)&myaddr,len,dnsname,CF_MAXVARSIZE,NULL,0,0)) != 0)
-      {
-      snprintf(OUTPUT,CF_BUFSIZE,"Couldn't look up address v6 for %s: %s\n",dnsname,gai_strerror(err));
-      CfLog(cferror,OUTPUT,"");
-      return false;
-      }
-   
-#else 
-   
-   iaddr = &(myaddr.sin_addr); 
-   hp = gethostbyaddr((void *)iaddr,sizeof(myaddr.sin_addr),family);
-   
-   if ((hp == NULL) || (hp->h_name == NULL))
-      {
-      CfLog(cferror,"Couldn't lookup IP address\n","gethostbyaddr");
-      return false;
-      }
-   
-   strncpy(dnsname,hp->h_name,CF_MAXVARSIZE);
-   
-   if ((strstr(hp->h_name,".") == 0) && (strlen(VDOMAIN) > 0))
-      {
-      strcat(dnsname,".");
-      strcat(dnsname,VDOMAIN);
-      } 
-#endif 
-   }
-else
-   {
-   strcat(dnsname,"skipident");
-   }
 
+ switch (family)
+    {
+    case AF_INET: len = sizeof(struct sockaddr_in);
+        break;
+#if defined(HAVE_GETADDRINFO) && !defined(DARWIN)
+    case AF_INET6: len = sizeof(struct sockaddr_in6);
+        break;
+#endif
+    default:
+        CfLog(cferror,"Software error in IdentifyForVerification","");
+    }
+ 
+ if (getsockname(sd,(struct sockaddr *)&myaddr,&len) == -1)
+    {
+    CfLog(cferror,"Couldn't get socket address\n","getsockname");
+    return false;
+    }
+ 
+ snprintf(localip,CF_MAX_IP_LEN-1,"%s",sockaddr_ntop((struct sockaddr *)&myaddr)); 
+ 
+ Debug("Identifying this agent as %s i.e. %s, with signature %d\n",localip,VFQNAME,CFSIGNATURE);
+ 
+#if defined(HAVE_GETADDRINFO) && !defined(DARWIN)
+ 
+ if ((err=getnameinfo((struct sockaddr *)&myaddr,len,dnsname,CF_MAXVARSIZE,NULL,0,0)) != 0)
+    {
+    snprintf(OUTPUT,CF_BUFSIZE,"Couldn't look up address v6 for %s: %s\n",dnsname,gai_strerror(err));
+    CfLog(cferror,OUTPUT,"");
+    return false;
+    }
+ 
+#else 
+ 
+ iaddr = &(myaddr.sin_addr); 
+ hp = gethostbyaddr((void *)iaddr,sizeof(myaddr.sin_addr),family);
+ 
+ if ((hp == NULL) || (hp->h_name == NULL))
+    {
+    CfLog(cferror,"Couldn't lookup IP address\n","gethostbyaddr");
+    return false;
+    }
+ 
+ strncpy(dnsname,hp->h_name,CF_MAXVARSIZE);
+ 
+ if ((strstr(hp->h_name,".") == 0) && (strlen(VDOMAIN) > 0))
+    {
+    strcat(dnsname,".");
+    strcat(dnsname,VDOMAIN);
+    } 
+#endif 
+ 
 user_ptr = getpwuid(getuid());
 uname = user_ptr ? user_ptr->pw_name : "UNKNOWN";
 
@@ -161,12 +155,7 @@ if (strncmp(dnsname,localip,strlen(localip)) == 0)
    strcpy(dnsname,localip);
    }
 
-if (strlen(dnsname) == 0)
-   {
-   strcpy(dnsname,localip);
-   }
-
-snprintf(sendbuff,CF_BUFSIZE-1,"CAUTH %s %s %s %d",localip,dnsname,uname,CFSIGNATURE);
+ snprintf(sendbuff,CF_BUFSIZE-1,"CAUTH %s %s %s %d",localip,dnsname,uname,CFSIGNATURE);
 
 Debug("SENT:::%s\n",sendbuff);
  
@@ -244,7 +233,6 @@ if (server_pubkey != NULL)
       err = ERR_get_error();
       snprintf(OUTPUT,CF_BUFSIZE,"Public encryption failed = %s\n",ERR_reason_error_string(err));
       CfLog(cferror,OUTPUT,"");
-      free(out);
       return false;
       }
    
@@ -343,11 +331,16 @@ else
 
 /* Receive counter challenge from server */ 
 
+
 Debug("Receive counter challenge from server\n");  
 /* proposition S3 */   
 memset(in,0,CF_BUFSIZE);  
 encrypted_len = ReceiveTransaction(CONN->sd,in,NULL);
 
+
+
+
+
 if (encrypted_len < 0)
    {
    CfLog(cferror,"Protocol transaction sent illegal cipher length",NULL);
@@ -394,7 +387,6 @@ if (server_pubkey == NULL)
       err = ERR_get_error();
       snprintf(OUTPUT,CF_BUFSIZE,"Private decrypt failed = %s\n",ERR_reason_error_string(err));
       CfLog(cferror,OUTPUT,"");
-      RSA_free(newkey);
       return false;
       }
 
@@ -402,7 +394,6 @@ if (server_pubkey == NULL)
    if ((len=ReceiveTransaction(CONN->sd,in,NULL)) == 0)
       {
       CfLog(cfinform,"Protocol error in RSA authentation from IP %s\n",ip->server);
-      RSA_free(newkey);
       return false;
       }
    
@@ -411,65 +402,27 @@ if (server_pubkey == NULL)
       err = ERR_get_error();
       snprintf(OUTPUT,CF_BUFSIZE,"Private decrypt failed = %s\n",ERR_reason_error_string(err));
       CfLog(cferror,OUTPUT,"");
-      RSA_free(newkey);
       return false;
       }
 
    SavePublicKey(keyname,newkey);
-   server_pubkey = RSAPublicKey_dup(newkey);
    RSA_free(newkey);
    }
+else
+   {
+   RSA_free(server_pubkey);
+   }
  
-/* proposition C5 */
-
+/* proposition C5 */ 
 GenerateRandomSessionKey();
 
-DebugBinOut(CONN->session_key,CF_BLOWFISHSIZE);
-
 if (CONN->session_key == NULL)
    {
    CfLog(cferror,"A random session key could not be established","");
    return false;
    }
-else
-   {
-   Debug("Generated session key\n");
-   DebugBinOut(CONN->session_key,CF_BLOWFISHSIZE);
-   }
-
-/* blowfishmpisize = BN_bn2mpi((BIGNUM *)CONN->session_key,in); */
-
-DebugBinOut(CONN->session_key,CF_BLOWFISHSIZE);
-
-encrypted_len = RSA_size(server_pubkey);
-
-Debug("Encrypt %d to %d\n",CF_BLOWFISHSIZE,encrypted_len);
-
-if ((out = malloc(encrypted_len)) == NULL)
-   {
-   FatalError("memory failure");
-   }
-
-if (RSA_public_encrypt(CF_BLOWFISHSIZE,CONN->session_key,out,server_pubkey,RSA_PKCS1_PADDING) <= 0)
-   {
-   err = ERR_get_error();
-   snprintf(OUTPUT,CF_BUFSIZE,"Public encryption failed = %s\n",ERR_reason_error_string(err));
-   CfLog(cferror,OUTPUT,"");
-   free(out);
-   return false;
-   }
-
-Debug("Encryption succeeded\n");
-
-SendTransaction(CONN->sd,out,encrypted_len,CF_DONE);
-DebugBinOut(out,encrypted_len);
-
-if (server_pubkey != NULL)
-   {
-   RSA_free(server_pubkey);
-   }
-
-free(out);
+ 
+SendTransaction(CONN->sd,CONN->session_key,16,CF_DONE); 
 return true; 
 }
 
