@@ -79,7 +79,6 @@ char *VVNAMES[] =
    "cr",
    "n",
    "dblquote",
-   "colon",
    "quote",
    "dollar",
    "repchar",
@@ -104,7 +103,6 @@ char *VVNAMES[] =
    "defaultcopytype",
    "allowredefinitionof",
    "defaultpkgmgr",     /* For packages */
-   "abortclasses",
    NULL
    };
 
@@ -141,20 +139,18 @@ return false;
 int CheckVarID(char *var)
 
 { char *sp;
-
- Debug("CheckVarID(%s)\n",var);
-
+ 
 for (sp = var; *sp != '\0'; sp++)
    {
    if (isalnum((int)*sp))
       {
       }
-   else if ((*sp == '_') || (*sp == '[') || (*sp == ']') || (*sp == '.'))
+   else if ((*sp == '_') || (*sp == '[') || (*sp == ']'))
       {
       }
    else
       {
-      snprintf(OUTPUT,CF_BUFSIZE,"Non identifier character (%c) in variable identifier (%s) - ",*sp,var);
+      snprintf(OUTPUT,CF_BUFSIZE,"Non identifier character (%c) in variable identifier (%s)",*sp,var);
       yyerror(OUTPUT);
       return false;
       }
@@ -178,11 +174,7 @@ for (sp = str; *sp != '\0' ; sp++)       /* check for varitems */
    {
    switch (*sp)
       {
-      case '$':
-          if (*(sp+1) == '{' || *(sp+1) == '(')
-             {
-             dollar = true;
-             }
+      case '$': dollar = true;
           break;
       case '(':
       case '{': 
@@ -234,13 +226,11 @@ char *ExtractInnerVarString(char *str,char *substr)
 { char *sp;
   int bracks = 1;
 
-Debug1("ExtractInnerVarString( %s ) - syntax verify\n",str);
+Debug1("ExtractInnerVarString(%s) - syntax verify\n",str);
 
 memset(substr,0,CF_BUFSIZE);
-
-/* Start this from after the opening $( */
-
-for (sp = str+2; *sp != '\0' ; sp++)       /* check for varitems */
+ 
+for (sp = str; *sp != '\0' ; sp++)       /* check for varitems */
    {
    switch (*sp)
       {
@@ -254,19 +244,18 @@ for (sp = str+2; *sp != '\0' ; sp++)       /* check for varitems */
           break;
           
       default:
-          if (isalnum((int)*sp) || IsIn(*sp,"_[]$.:-"))
+          if (isalnum((int)*sp) || (*sp != '_') || (*sp != '[')|| (*sp != ']'))
              {
              }
           else
              {
-             Debug("Illegal character found: '%c'\n", *sp);
              yyerror("Illegal character somewhere in variable or nested expansion");
              }
       }
    
    if (bracks == 0)
       {
-      strncpy(substr,str+2,sp-str-2);
+      strncpy(substr,str,sp-str);
       Debug("Returning substring value %s\n",substr);
       return substr;
       }
@@ -315,7 +304,7 @@ for (sp = str; *sp != '\0' ; sp++)       /* check for varitems */
    if (dollar && (bracks == 0) && onebrack)
       {
       strncpy(substr,str,sp-str+1);
-      Debug("Extracted outer variable |%s|\n",substr);
+      Debug("Extracted outer variable %s\n",substr);
       return substr;
       }
    }
@@ -328,7 +317,7 @@ for (sp = str; *sp != '\0' ; sp++)       /* check for varitems */
  if (bracks != 0)
     {
     yyerror("Incomplete variable syntax or bracket mismatch");
-    return NULL;
+    return false;
     }
  
  return sp-1;
@@ -339,9 +328,9 @@ for (sp = str; *sp != '\0' ; sp++)       /* check for varitems */
 int ExpandVarstring(char *string,char buffer[CF_EXPANDSIZE],char *bserver) 
 
 { char *sp,*env;
-  int varstring = false;
+  char varstring = false;
   char currentitem[CF_EXPANDSIZE],temp[CF_BUFSIZE],name[CF_MAXVARSIZE];
-  int len,increment;
+  int len;
   time_t tloc;
   
 memset(buffer,0,CF_EXPANDSIZE);
@@ -351,24 +340,14 @@ if (string == 0 || strlen(string) == 0)
    return false;
    }
 
-Debug("ExpandVarstring( %s )\n",string);
+Debug("ExpandVarstring(%s)\n",string);
 
 for (sp = string; /* No exit */ ; sp++)       /* check for varitems */
    {
-   char var[CF_BUFSIZE];
-   
-   memset(var,0,CF_BUFSIZE);
-   increment = 0;
+   currentitem[0] = '\0';
 
-   if (*sp == '\0')
-      {
-      break;
-      }
-
-   memset(currentitem,0,CF_EXPANDSIZE);
-   
    sscanf(sp,"%[^$]",currentitem);
-   
+
    if (ExpandOverflow(buffer,currentitem))
       {
       FatalError("Can't expand varstring");
@@ -377,445 +356,420 @@ for (sp = string; /* No exit */ ; sp++)       /* check for varitems */
    strcat(buffer,currentitem);
    sp += strlen(currentitem);
 
-   Debug("Add |%s| to str, waiting at |%s|\n",buffer,sp);
-   
-   if (*sp == '\0')
-      {
-      break;
-      }
-
    if (*sp == '$')
       {
       switch (*(sp+1))
          {
-         case '(':
-                   ExtractOuterVarString(sp,var);
+         case '(': 
                    varstring = ')';
                    break;
-         case '{':
-                   ExtractOuterVarString(sp,var);
+         case '{': 
                    varstring = '}';
                    break;
-
          default: 
                    strcat(buffer,"$");
                    continue;
          }
+      sp++;
       }
 
-   memset(currentitem,0,CF_EXPANDSIZE);
+   currentitem[0] = '\0';
 
-   temp[0] = '\0';
-   ExtractInnerVarString(sp,temp);
-   
-   if (strstr(temp,"$"))
+   if (*sp == '\0')
       {
-      Debug("Nested variables - %s\n",temp);
-
-      ExpandVarstring(temp,currentitem,"");
-      CheckVarID(currentitem);
+      break;
       }
    else
       {
-      strncpy(currentitem,temp,CF_BUFSIZE-1);
-      }
+      temp[0] = '\0';
+      ExtractInnerVarString(++sp,temp);
+      
+      if (strstr(temp,"$"))
+         {
+         Debug("Nested variables");
+         ExpandVarstring(temp,currentitem,"");
+         CheckVarID(currentitem);
+         sp += 3; /* $() */
+         }
+      else
+         {
+         strncpy(currentitem,temp,CF_BUFSIZE-1);
+         }
 
-   increment = strlen(var) - 1;
-   Debug("Scanning variable %s\n",currentitem);
-   
-   switch (ScanVariable(currentitem))
-      {
-      case cfversionvar:
-          if (ExpandOverflow(buffer,VERSION))
-             {
-             FatalError("Can't expand varstring");
-             }
-          strcat(buffer,VERSION);
-          break;
-          
-      case cffaculty:
-      case cfsite:
-          if (VFACULTY[0] == '\0')
-             {
-             yyerror("faculty/site undefined variable");
-             }
-          
-          if (ExpandOverflow(buffer,VFACULTY))
-             {
-             FatalError("Can't expand varstring");
-             }
-          strcat(buffer,VFACULTY);
-          break;
-          
-          
-      case cfhost:
-          if (strlen(VUQNAME) == 0)
-             {
-             if (ExpandOverflow(buffer,VDEFAULTBINSERVER.name))
+      Debug("Scanning variable %s\n",currentitem);
+      
+      switch (ScanVariable(currentitem))
+         {
+         case cfversionvar:
+             if (ExpandOverflow(buffer,VERSION))
                 {
                 FatalError("Can't expand varstring");
                 }
-             strcat(buffer,VDEFAULTBINSERVER.name);
-             }
-          else
-             {
-             if (ExpandOverflow(buffer,VUQNAME))
+             strcat(buffer,VERSION);
+	     break;
+             
+         case cffaculty:
+         case cfsite:
+             if (VFACULTY[0] == '\0')
+                {
+                yyerror("faculty/site undefined variable");
+                }
+             
+             if (ExpandOverflow(buffer,VFACULTY))
                 {
                 FatalError("Can't expand varstring");
                 }
-             strcat(buffer,VUQNAME);
-             }
-          break;
-          
-      case cffqhost:
-          if (ExpandOverflow(buffer,VFQNAME))
-             {
-             FatalError("Can't expand varstring");
-             }
-          strcat(buffer,VFQNAME);
-          break;
-          
-      case cfnetmask:
-          if (ExpandOverflow(buffer,VNETMASK))
-             {
-             FatalError("Can't expand varstring");
-             }
-          strcat(buffer,VNETMASK);
-          break;
-          
-          
-      case cfipaddr:
-          if (ExpandOverflow(buffer,VIPADDRESS))
-             {
-             FatalError("Can't expand varstring");
-             }
-          strcat(buffer,VIPADDRESS);
-          break;
-          
-      case cfbinserver:
-          if (ACTION != links && ACTION != required)
-             {
-             yyerror("Inappropriate use of variable binserver");
-             FatalError("Bad variable");
-             }
-          
-          if (ExpandOverflow(buffer,"$(binserver)"))
-             {
-             FatalError("Can't expand varstring");
-             }
-          strcat(buffer,"$(binserver)");
-          break;
-          
-      case cfsysadm:
-          if (VSYSADM[0] == '\0')
-             {
-             yyerror("sysadm undefined variable");
-             }
-          
-          if (ExpandOverflow(buffer,VSYSADM))
-             {
-             FatalError("Can't expand varstring");
-             }
-          strcat(buffer,VSYSADM);
-          break;
-          
-      case cfdomain:
-          if (VDOMAIN[0] == '\0')
-             {
-             yyerror("domain undefined variable");
-             }
-          
-          if (ExpandOverflow(buffer,VDOMAIN))
-             {
-             FatalError("Can't expandvarstring");
-             }
-          strcat(buffer,ToLowerStr(VDOMAIN));
-          break;
-          
-      case cfnfstype:
-          if (ExpandOverflow(buffer,VNFSTYPE))
-             {
-             FatalError("Can't expandvarstring");
-             }
-          strcat(buffer,VNFSTYPE);
-          break;
-          
-      case cftimezone:
-          if (VTIMEZONE == NULL)
-             {
-             yyerror("timezone undefined variable");
-             }
-          
-          if (ExpandOverflow(buffer,VTIMEZONE->name))
-             {
-             FatalError("Can't expandvarstring");
-             }
-          strcat(buffer,VTIMEZONE->name);
-          break;
-          
-      case cfclass:
-          if (ExpandOverflow(buffer,CLASSTEXT[VSYSTEMHARDCLASS]))
-             {
-             FatalError("Can't expandvarstring");
-             }
-          strcat(buffer,CLASSTEXT[VSYSTEMHARDCLASS]);
-          break;
-          
-      case cfarch:
-          if (ExpandOverflow(buffer,VARCH))
-             {
-             FatalError("Can't expandvarstring");
-             }
-          strcat(buffer,VARCH);
-          break;
-          
-      case cfarch2:
-          if (ExpandOverflow(buffer,VARCH2))
-             {
-             FatalError("Can't expandvarstring");
-             }
-          strcat(buffer,VARCH2);
-          break;
-          
-          
-      case cfdate:
-          
-          if ((tloc = time((time_t *)NULL)) == -1)
-             {
-             snprintf(OUTPUT,CF_BUFSIZE*2,"Couldn't read system clock\n");
-             CfLog(cferror,"Couldn't read clock","time");
-             }
-          
-          if (ExpandOverflow(buffer,ctime(&tloc)))
-             {
-             FatalError("Can't expandvarstring");
-             }
-          else
-             {
-             strcat(buffer,Space2Score(ctime(&tloc)));
-             Chop(buffer);
-             }
-          
-          break;
-          
-      case cfyear:
-          if (ExpandOverflow(buffer,VYEAR))
-             {
-             FatalError("Can't expandvarstring");
-             }
-          else
-             {
-             strcat(buffer,VYEAR);
-             }
-          break;
-          
-      case cfmonth:
-          if (ExpandOverflow(buffer,VMONTH))
-             {
-             FatalError("Can't expandvarstring");
-             }
-          else
-             {
-             strcat(buffer,VMONTH);
-             }
-          break;
-          
-      case cfday:
-          if (ExpandOverflow(buffer,VDAY))
-             {
-             FatalError("Can't expandvarstring");
-             }
-          else
-             {
-             strcat(buffer,VDAY);
-             }
-          break;
-          
-      case cfhr:
-          if (ExpandOverflow(buffer,VHR))
-             {
-             FatalError("Can't expandvarstring");
-             }
-          else
-             {
-             strcat(buffer,VHR);
-             }
-          break;
-          
-      case cfmin:
-          if (ExpandOverflow(buffer,VMINUTE))
-             {
-             FatalError("Can't expandvarstring");
-             }
-          else
-             {
-             strcat(buffer,VMINUTE);
-             }
-          break;
-          
-      case cfallclass:
-          if (strlen(ALLCLASSBUFFER) == 0)
-             {
-             snprintf(name,CF_MAXVARSIZE,"$(%s)",currentitem);
-             strcat(buffer,name);
-             }
-          
-          if (ExpandOverflow(buffer,ALLCLASSBUFFER))
-             {
-             FatalError("Can't expandvarstring");
-             }
-          strcat(buffer,ALLCLASSBUFFER);
-          break;
-          
-      case cfspc:
-          if (ExpandOverflow(buffer," "))
-             {
-             FatalError("Can't expandvarstring");
-             }
-          strcat(buffer," ");
-          break;
-          
-      case cftab:
-          if (ExpandOverflow(buffer," "))
-             {
-             FatalError("Can't expandvarstring");
-             }
-          strcat(buffer,"\t");
-          break;
-          
-      case cflf:
-          if (ExpandOverflow(buffer," "))
-             {
-             FatalError("Can't expandvarstring");
-             }
-          strcat(buffer,"\012");
-          break;
-          
-      case cfcr:
-          if (ExpandOverflow(buffer," "))
-             { 
-             FatalError("Can't expandvarstring");
-             }
-          strcat(buffer,"\015");
-          break;
-          
-      case cfn:
-          if (ExpandOverflow(buffer," "))
-             { 
-             FatalError("Can't expandvarstring");
-             }
-          strcat(buffer,"\n");
-          break;
-          
-      case cfdblquote:
-          if (ExpandOverflow(buffer," "))
-             { 
-             FatalError("Can't expandvarstring");
-             }
-          strcat(buffer,"\"");
-          break;
-      case cfquote:
-          if (ExpandOverflow(buffer," "))
-             { 
-             FatalError("Can't expandvarstring");
-             }
-          strcat(buffer,"\'");
-          break;
-          
-      case cfcolon:
-          if (ExpandOverflow(buffer," "))
-             { 
-             FatalError("Can't expandvarstring");
-             }
-          strcat(buffer,":");
-          break;
-          
-          
-      case cfdollar:
-          
-          if (!PARSING)
-             {
+             strcat(buffer,VFACULTY);
+             break;
+             
+             
+         case cfhost:
+             if (strlen(VUQNAME) == 0)
+                {
+                if (ExpandOverflow(buffer,VDEFAULTBINSERVER.name))
+                   {
+                   FatalError("Can't expand varstring");
+                   }
+                strcat(buffer,VDEFAULTBINSERVER.name);
+                }
+             else
+                {
+                if (ExpandOverflow(buffer,VUQNAME))
+                   {
+                   FatalError("Can't expand varstring");
+                   }
+                strcat(buffer,VUQNAME);
+                }
+             break;
+             
+         case cffqhost:
+             if (ExpandOverflow(buffer,VFQNAME))
+                {
+                FatalError("Can't expand varstring");
+                }
+             strcat(buffer,VFQNAME);
+             break;
+             
+         case cfnetmask:
+             if (ExpandOverflow(buffer,VNETMASK))
+                {
+                FatalError("Can't expand varstring");
+                }
+             strcat(buffer,VNETMASK);
+             break;
+             
+             
+         case cfipaddr:
+             if (ExpandOverflow(buffer,VIPADDRESS))
+                {
+                FatalError("Can't expand varstring");
+                }
+             strcat(buffer,VIPADDRESS);
+             break;
+             
+         case cfbinserver:
+             if (ACTION != links && ACTION != required)
+                {
+                yyerror("Inappropriate use of variable binserver");
+                FatalError("Bad variable");
+                }
+             
+             if (ExpandOverflow(buffer,"$(binserver)"))
+                {
+                FatalError("Can't expand varstring");
+                }
+             strcat(buffer,"$(binserver)");
+             break;
+             
+         case cfsysadm:
+             if (VSYSADM[0] == '\0')
+                {
+                yyerror("sysadm undefined variable");
+                }
+             
+             if (ExpandOverflow(buffer,VSYSADM))
+                {
+                FatalError("Can't expand varstring");
+                }
+             strcat(buffer,VSYSADM);
+             break;
+             
+         case cfdomain:
+             if (VDOMAIN[0] == '\0')
+                {
+                yyerror("domain undefined variable");
+                }
+             
+             if (ExpandOverflow(buffer,VDOMAIN))
+                {
+                FatalError("Can't expandvarstring");
+                }
+             strcat(buffer,ToLowerStr(VDOMAIN));
+             break;
+             
+         case cfnfstype:
+             if (ExpandOverflow(buffer,VNFSTYPE))
+                {
+                FatalError("Can't expandvarstring");
+                }
+             strcat(buffer,VNFSTYPE);
+             break;
+             
+         case cftimezone:
+             if (VTIMEZONE == NULL)
+                {
+                yyerror("timezone undefined variable");
+                }
+             
+             if (ExpandOverflow(buffer,VTIMEZONE->name))
+                {
+                FatalError("Can't expandvarstring");
+                }
+             strcat(buffer,VTIMEZONE->name);
+             break;
+             
+         case cfclass:
+             if (ExpandOverflow(buffer,CLASSTEXT[VSYSTEMHARDCLASS]))
+                {
+                FatalError("Can't expandvarstring");
+                }
+             strcat(buffer,CLASSTEXT[VSYSTEMHARDCLASS]);
+             break;
+             
+         case cfarch:
+             if (ExpandOverflow(buffer,VARCH))
+                {
+                FatalError("Can't expandvarstring");
+                }
+             strcat(buffer,VARCH);
+             break;
+             
+         case cfarch2:
+             if (ExpandOverflow(buffer,VARCH2))
+                {
+                FatalError("Can't expandvarstring");
+                }
+             strcat(buffer,VARCH2);
+             break;
+             
+             
+         case cfdate:
+             
+             if ((tloc = time((time_t *)NULL)) == -1)
+                {
+                snprintf(OUTPUT,CF_BUFSIZE*2,"Couldn't read system clock\n");
+                CfLog(cferror,"Couldn't read clock","time");
+                }
+             
+             if (ExpandOverflow(buffer,ctime(&tloc)))
+                {
+                FatalError("Can't expandvarstring");
+                }
+             else
+                {
+                strcat(buffer,Space2Score(ctime(&tloc)));
+                Chop(buffer);
+                }
+             
+             break;
+             
+         case cfyear:
+             if (ExpandOverflow(buffer,VYEAR))
+                {
+                FatalError("Can't expandvarstring");
+                }
+             else
+                {
+                strcat(buffer,VYEAR);
+                }
+             break;
+             
+         case cfmonth:
+             if (ExpandOverflow(buffer,VMONTH))
+                {
+                FatalError("Can't expandvarstring");
+                }
+             else
+                {
+                strcat(buffer,VMONTH);
+                }
+             break;
+             
+         case cfday:
+             if (ExpandOverflow(buffer,VDAY))
+                {
+                FatalError("Can't expandvarstring");
+                }
+             else
+                {
+                strcat(buffer,VDAY);
+                }
+             break;
+         case cfhr:
+             if (ExpandOverflow(buffer,VHR))
+                {
+                FatalError("Can't expandvarstring");
+                }
+             else
+                {
+                strcat(buffer,VHR);
+                }
+             break;
+             
+         case cfmin:
+             if (ExpandOverflow(buffer,VMINUTE))
+                {
+                FatalError("Can't expandvarstring");
+                }
+             else
+                {
+                strcat(buffer,VMINUTE);
+                }
+             break;
+             
+         case cfallclass:
+             if (strlen(ALLCLASSBUFFER) == 0)
+                {
+                snprintf(name,CF_MAXVARSIZE,"$(%s)",currentitem);
+                strcat(buffer,name);
+                }
+             
+             if (ExpandOverflow(buffer,ALLCLASSBUFFER))
+                {
+                FatalError("Can't expandvarstring");
+                }
+             strcat(buffer,ALLCLASSBUFFER);
+             break;
+             
+         case cfspc:
+             if (ExpandOverflow(buffer," "))
+                {
+                FatalError("Can't expandvarstring");
+                }
+             strcat(buffer," ");
+             break;
+             
+         case cftab:
+             if (ExpandOverflow(buffer," "))
+                {
+                FatalError("Can't expandvarstring");
+                }
+             strcat(buffer,"\t");
+             break;
+             
+         case cflf:
+             if (ExpandOverflow(buffer," "))
+                {
+                FatalError("Can't expandvarstring");
+                }
+             strcat(buffer,"\012");
+             break;
+             
+         case cfcr:
              if (ExpandOverflow(buffer," "))
                 { 
                 FatalError("Can't expandvarstring");
                 }
-             strcat(buffer,"$");
-             }
-          else
-             {
-             if (ExpandOverflow(buffer,"$(dollar)"))
+             strcat(buffer,"\015");
+             break;
+             
+         case cfn:
+             if (ExpandOverflow(buffer," "))
                 { 
                 FatalError("Can't expandvarstring");
                 }
-             strcat(buffer,"$(dollar)");
-             }
-          break;
-          
-          
-      case cfrepchar:
-          if (ExpandOverflow(buffer," "))
-             {
-             FatalError("Can't expandvarstring");
-             }
-          len = strlen(buffer);
-          buffer[len] = REPOSCHAR;
-          buffer[len+1] = '\0';
-          break;
-          
-      case cfrepos:
-          if (VREPOSITORY != NULL)
-             {
-             if (ExpandOverflow(buffer,VREPOSITORY))
-                {
-                FatalError("Can't expandvarstring");
-                }
-             strcat(buffer,VREPOSITORY);
-             }
-          break;
-          
-      case cflistsep:
-          if (ExpandOverflow(buffer,""))
-             {
-             FatalError("Can't expandvarstring");
-             }
-          len = strlen(buffer);
-          buffer[len] = LISTSEPARATOR;
-          buffer[len+1] = '\0';
-          break;
-          
-      default:
-
-          if ((env = GetMacroValue(CONTEXTID,currentitem)) != NULL)
-             {
-             if (ExpandOverflow(buffer,env))
-                {
-                FatalError("Can't expandvarstring");
-                }
-             
-             strcat(buffer,env);
-             Debug("Expansion gave (%s), len = %d\n",buffer,strlen(currentitem));             
+             strcat(buffer,"\n");
              break;
-             }
-          
-          Debug("Currently non existent variable $(%s)\n",currentitem);
-          
-          if (varstring == '}')
-             {
-             snprintf(name,CF_MAXVARSIZE,"${%s}",currentitem);
-             }
-          else
-             {
-             snprintf(name,CF_MAXVARSIZE,"$(%s)",currentitem);
-             }
-          strcat(buffer,name);
+             
+         case cfdblquote:
+             if (ExpandOverflow(buffer," "))
+                { 
+                FatalError("Can't expandvarstring");
+                }
+             strcat(buffer,"\"");
+             break;
+         case cfquote:
+             if (ExpandOverflow(buffer," "))
+                { 
+                FatalError("Can't expandvarstring");
+                }
+             strcat(buffer,"\'");
+             break;
+             
+         case cfdollar:
+             
+             if (!PARSING)
+                {
+                if (ExpandOverflow(buffer," "))
+                   { 
+                   FatalError("Can't expandvarstring");
+                   }
+                strcat(buffer,"$");
+                }
+             else
+                {
+                if (ExpandOverflow(buffer,"$(dollar)"))
+                   { 
+                   FatalError("Can't expandvarstring");
+                   }
+                strcat(buffer,"$(dollar)");
+                }
+             break;
+             
+             
+         case cfrepchar:
+             if (ExpandOverflow(buffer," "))
+                {
+                FatalError("Can't expandvarstring");
+                }
+             len = strlen(buffer);
+             buffer[len] = REPOSCHAR;
+             buffer[len+1] = '\0';
+             break;
+             
+         case cflistsep:
+             if (ExpandOverflow(buffer,""))
+                {
+                FatalError("Can't expandvarstring");
+                }
+             len = strlen(buffer);
+             buffer[len] = LISTSEPARATOR;
+             buffer[len+1] = '\0';
+             break;
+             
+         default:
+             
+             if ((env = GetMacroValue(CONTEXTID,currentitem)) != NULL)
+                {
+                if (ExpandOverflow(buffer,env))
+                   {
+                   FatalError("Can't expandvarstring");
+                   }
+                strcat(buffer,env);
+                Debug("Expansion gave (%s)\n",buffer);             
+
+                break;
+                }
+
+             Debug("Currently non existent variable $(%s)\n",currentitem);
+             
+             if (varstring == '}')
+                {
+                snprintf(name,CF_MAXVARSIZE,"${%s}",currentitem);
+                }
+             else
+                {
+                snprintf(name,CF_MAXVARSIZE,"$(%s)",currentitem);
+                }
+             strcat(buffer,name);
+         }
+      
+      sp += strlen(currentitem);
+      currentitem[0] = '\0';
       }
-
-   sp += increment;
-   currentitem[0] = '\0';
    }
-
-Debug("Returning varstring (%s)\n",buffer);
-return varstring;
+ 
+ return varstring;
 }
 
 /*********************************************************************/
@@ -923,7 +877,7 @@ struct Item *SplitVarstring(char *varstring,char sep)
   char before[CF_BUFSIZE],after[CF_BUFSIZE],result[CF_BUFSIZE];
   int i;
   
-Debug("SplitVarstring([%s],%c=%d)\n",varstring,sep,sep);
+Debug("SplitVarstring(%s,%c=%d)\n",varstring,sep,sep);
 
 memset(before,0,CF_BUFSIZE);
 memset(after,0,CF_BUFSIZE);
@@ -944,11 +898,10 @@ sprintf(format,"%%[^%c]",sep);   /* set format string to search */
 
 i = 0; /* extract variable */
 
-for (sp = varstring; *sp != '$' && *sp != '\0' ; sp++)
+for(sp = varstring; *sp != '$' && *sp != '\0' ; sp++)
    {
    before[i++] = *sp;
    }
-
 before[i] = '\0';
 
 ExtractOuterVarString(varstring,variable); 
@@ -962,23 +915,16 @@ if (strcmp(variable,"$(date)") == 0)        /* Exception! $(date) contains : but
  
 ExpandVarstring(variable,buffer,"");
 
-Debug("EXPAND |%s| -> |%s|, remain %s\n",variable,buffer,sp);
+Debug("EXPAND %s -> %s\n",variable,buffer);
 
-sp = varstring+strlen(variable);
-
-i = 0;;
-
-Debug("REMAIN |%s|\n",sp);
-
-while (*sp != '\0')
+sp += strlen(variable);
+ 
+while(*sp != '\0')
    {
    after[i++] = *sp++;
    }
 
-Debug("CONTINUE |%s| -> |%s|\n",sp,after);
- 
-
-for (sp = buffer+strlen(before); *sp != '\0'; sp++)
+for (sp = buffer; *sp != '\0'; sp++)
    {
    memset(node,0,CF_MAXLINKSIZE);
    sscanf(sp,format,node);
@@ -1009,22 +955,3 @@ for (sp = buffer+strlen(before); *sp != '\0'; sp++)
 return liststart;
 }
 
-/*********************************************************/
-
-int IsListVar(char *name,char sep)
-
-{ char test[CF_EXPANDSIZE];
-  char *sp;
- 
-ExpandVarstring(name,test,NULL);
-
-for (sp = test; *sp != '\0'; sp++)
-   {
-   if (*sp == sep)
-      {
-      return true;
-      }
-   }
-
-return false;
-}
